---
title: "Ama Verbs in Comparative Perspective"
authors: ["russelnorton.md"]
abstract: "Ama verbs are comparable with Nubian and other related languages in their clause-final syntax, CVC root shape, and some affixes. However, there is also considerable innovation in adjoined relative clauses, a shift from number to aspect marking traced by *T/K* morphology, and other changes in the order and meaning of affixes. These developments show a unique trend of concretization of core clause constituents, and internal growth in the complexity of verbs in isolation from other languages. On the other hand, Ama’s stable distributive pluractional represents a wider Eastern Sudanic category. The late loss of pronominal subject marking supports a hypothesis that the Ama language was used for inter-group communication with Kordofan Nubians."
keywords: ["Ama", "Northern East Sudanic", "comparative linguistics", "Nilo-Saharan", "Nyimang", "Afitti"]
---

# Preliminaries

Ama is a Northern East Sudanic language spoken in villages to the west and north-west of Dilling, near to where Kordofan Nubian languages are spoken in the north-western Nuba Mountains. “Ama” (*ámá* “people”) is the self-designated name of the language community identified by the ISO639-3 code [nyi] and replaces the name “Nyimang” in older sources,[^1] as “Ama” is the name used in local literature in the language created over the last three decades. Nyimang is an altered form of “Nyima,” one of the mountains in the Ama homeland, which is now used as the name of the branch of Eastern Sudanic consisting of Ama [nyi] and Afitti [aft]. I will assume that Nyima is one of a group of four extant northern branches of the Eastern Sudanic family, the others being Nubian, the Nara language, and Taman.[^2]

[^1]: Stevenson, *Grammar of the Nyimang Language* and “A survey of the phonetics and grammatical structure of the Nuba Mountain languages with particular reference to Otoro, Katcha and Nyimaŋ,” 40: p. 107.
[^2]: Rilly, *Le méroïtique et sa famille linguistique,* §4.

Ama examples unless otherwise stated are from the author’s fieldwork verified with leading Ama writers who oversee literacy in the language. For vowels, I distinguish five –ATR brassy vowels *ɪɛaɔʊ* and five +ATR breathy vowels *ieəou,* as represented fluently by Ama writers using five vowel letters {aeiou} and a saltillo {ꞌ} in breathy words. For tone, Ama’s nearest relative Afitti has been described as having two contrastive tone levels,[^3] but Ama has three levels, which play a role in the verb system as well as the wider lexicon as shown in **Table 1**.

[^3]: De Voogt, “A Sketch of Afitti Phonology,” p. 47.

|     |                  |    |                                   |     |                  |
|-----|------------------|----|-----------------------------------|-----|------------------|
| *kɛ́r* | "woman"            | *nɪ́* | "kill" [fact]({sc})                  | *ɕɪ́ɛ̄* | "do" [tr]({sc})  |
| *kɛ̄r* | "crane" (bird sp.) | *nɪ̄* | "kill" [prog 3]({sc})     | *ɕɪ̄ɛ̄* | "say"              |
| *kɛ̀r* | "around"           | *nɪ̀* | "kill" [prog 1/2]({sc}) | *ɕɪ̀ɛ̄* | "do" [itr]({sc})|

**~~Table 1: Level tone contrasts in Ama~~**

A brief overview of Ama morphosyntax can be gained by locating it in the typology of Heine and Voßen,[^4] which assesses African languages on the presence of nominal classification, nominal case, and verbal derivation. In Ama, the role of nominal classification is limited due to a remarkable lack of nominal number affixes, although there is some differentiated grammatical behavior of rational nominals.[^5] However, case is extensive in Ama,[^6] as is typical of Nilo-Saharan verb-final languages,[^7] and likewise verbal derivation is extensive.

[^4]: Heine & Voßen, “Sprachtypologie,” cited in Kröger, “Typology Put to Practical Use,” p. 159.
[^5]: Norton, “Number in Ama verbs,” pp. 75⁠–⁠76, 85; Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: pp. 175⁠–1⁠76.
[^6]: Stevenson, *Grammar of the Nyimang Language,* §§2–⁠10.
[^7]: Dimmendaal, “Africa’s Verb-final Languages,” §9.2.3.


|    | Feature                | Presence  | Categories                                        |
|----|------------------------|-----------|---------------------------------------------------|
| 1. | Nominal classification | limited   | rational                                          |
| 2. | Nominal case           | extensive | accusative, dative, genitive, ablative, locatives |
| 3. | Verbal derivation      | extensive | causative, applicative, reciprocal, directional   |

**~~Table 2. Ama morphosyntax~~**

In the remaining sections, we will examine Ama's verb syntax ([2](#syntax)), verb stems ([3](#3)) and verb affixes ([4](#4)) from a comparative perspective, followed by a conclusion ([5](#5)).

# The Syntax of Ama Verbs {#syntax}

Ama verbs follow a syntax that is partly familiar from other Nilo-Saharan languages. It has SOV word order, although as we shall see, Ama is not strictly verb-final. It also has coverbs that occur with an inflecting light verb. As in Tama,[^8] most Ama verbs take their own inflections but coverbs are also seen quite frequently. Many Ama coverbs fit Stevenson’s characterization that the coverb occurs before the light verb stem *ɕɪɛ* “do/say” and is either an ideophone (with marked phonology such as reduplication or non-mid tone) or a word marked by the suffix *-ɛ̄n* (typically a borrowed verb).[^9] The form of the Ama coverb suffix *-ɛ̄n* matches the Fur coverb suffix *-ɛn* ~ *-ɛŋ*.[^10] The transitivity of the predicate is distinguished in Ama by the tone on the light verb *ɕɪ̀ɛ̄/ɕɪ́ɛ̄*.

[^8]:	Dimmendaal, “Introduction” to *Coding Participant Marking,* pp. 6–7.
[^9]: Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 174.
[^10]: Waag, *The Fur Verb and Its Context*, p. 49; low tone is unmarked in the Fur two-tone system.

| Intransitive coverbs |               | Transitive coverbs |      |
| :---                  | :---           | :---                | :---  |
| *nʊ̄nʊ̄ɲ ɕɪ̀ɛ̄*            | "hop"           | *díɟí ɕɪ́ɛ̄*           | "work" |
| *ɟɪ̀ɟɪ̀ɡ ɕɪ̀ɛ̄*            | "speak angrily" | *ɟɛ̀rɟɛ̀r ɕɪ́ɛ̄*         | "scatter" |
| *àɽɪ̀mɛ̀ ɕɪ̀ɛ̄*            | "be angry"      | *t̪úūl ɕɪ́ɛ̄*           | "destroy" |
| *ōlɡ-ēn ɕɪ̀ɛ̄*           | "cry"           | *dɪ́ɡl-ɛ̄n ɕɪ́ɛ̄*        | "gather" (KN *ɖigil)[^11] |
| *tɔ̄ɡl-ɛ̄n ɕɪ̀ɛ̄*          | "tie oneself"   | *fɔ̄ɟ-ɛ̄n ɕɪ́ɛ̄*         | "make suffer" |
| *sɛ̀ɡ-ɛ̄n ɕɪ̀ɛ̄*           | "complain"      | *tɪ̄m-ɛ̄n ɕɪ́ɛ̄*         | "finish" |
|                      |               | *kɔ̄w-ɛ̄n ɕɪ́ɛ̄*         | "iron" (SA *kowa*) |
|                      |               | *rɛ̄kb-ɛ̄n ɕɪ́ɛ̄*        | "ride" (SA *rikib*) |
|                      |               | *mɪ̄skɪ̄l-ɛ̄n ɕɪ́ɛ̄*      | "give someone a missed call" (SA *miskil*) |

**~~Table 3. Ama coverbs~~**

[^11]: Jakobi, *Kordofan Nubian,* p. 159. Her data from Kordofan Nubian varieties shows high tone.

While Ama’s verb-final word order and use of coverbs are reminiscent of other Nilo-Saharan languages, relative clauses in Ama are of a globally rare type. Ama uses adjoined relative clauses at the end of the main clause, and these modify the last noun of the main clause.[^12]

[^12]: Stevenson, *Grammar of the Nyimang Language,* p. 178, shows cleft constructions with a similar core+adjoined structure, *wadang nɔ a nɛ* [*a meo tolun*] "This is the man [I saw yesterday].”

{{< gloss "(1)" >}}
{r} **Ama**
{g} *àɪ̀*,[1sg]({sc})|*bā*,[decl.ver]({sc})|	*ìr-ò*,elephant-[acc]({sc})|	*tɛ̀lɛ̄*,see|,[|*(ɪ̀n)*,[3sg]({sc})|*kwārāŋ-àʊ̀*,field-[loc]({sc})|*túŋ*,sleep:[prog]({sc}) ]|			
{r} “I definitely saw the elephant who was sleeping in a field.”
{{< /gloss >}}

{{< gloss "(2)" >}}
{g} ābɪ̄dɪ̄-ʊ̄ŋ,God-[gen]({sc})|*kwɛ̄ɪ̄*,man|*d̪ɛ̄*,[ev]({sc})|*ɪ̄rɪ̄d̪ā*,message|*wʊ̄ɔ̄*,keep:[prog]({sc})|*kɛ̄r-àʊ̀*,girl (*kɛ̄rà*)-[loc]({sc})|,[|*yʊ̄sʊ̄f-ɪ̄l*,Joseph-[loc]({sc})|*tɪ̄ŋ-ɛ́ɪ́*,choose-[med]({sc}) ]|
{r} “An angel from God had a message for a girl who was engaged to Joseph.”
{{< /gloss >}}

The adjoined relative clause strategy means that verbs tend not to occur in noun phrases in Ama, although for completeness we should observe that they are not entirely excluded. Since it is impossible to modify the subject of a transitive clause by an adjoined relative clause, as it is separated by another object or oblique noun, speakers consulted confirmed that it is grammatically acceptable to modify a subject noun by a progressive verb within the noun phrase as in (3), although they felt this is not used much, and I have not found examples in texts. However, verb participles marked by the suffix *-ɔ̀* (or *-ò* by vowel harmony) also occur in noun phrases, including in texts as in (4) and (5).

{{< gloss "(3)" >}}
{r} Unmarked relative clause in subject noun phrase (elicited)
{g} *ìr*,elephant|*nɔ̄*,this|,[|*mūɕ-èɡ*,run-[dir:prog]({sc}) ]|*bā*,[decl.ver]({sc})|*āŋ*,[1sg.acc]({sc})|*t̪ɛ̀lɛ̄*,see:[fact]({sc})|
{r} “This running elephant definitely saw me.”
{{< /gloss >}}

{{< gloss "(4)" >}}
{r} Participial subject relative clause
{g} *ə́níŋè*,when|,[|*wád̪à*,word|*kìr-d̪-ò*,cut-[pct-ptcp]({sc}) ]|*wàá*,people|*ɕɪ̀ɽāɡɪ́d̪ɪ́*,rule|*wāɡ-áʊ́*,keep-[pst.prog]({sc})|
{r} “When the judges (lit. ‘cut-word people’) were ruling,”
{{< /gloss >}}

{{< gloss "(5)" >}}
{r} Participial object relative clause
{g} *mʊ̄rd̪à*,horse|,[|*kʊ̄ɟɔ̄-ɔ̀*,saddle-[ptcp]({sc}) ]|*d̪ɛ̄*,[ev]({sc})|*ŋáŋà*,attention|*túɽāk*,warn:[prog]({sc})|
{r} “The saddled horse is warning, look out.”
{{< /gloss >}}

Nevertheless, the adjoined relative clause strategy is an innovative feature of Ama that tends to place information about participants outside the noun phrase where they are mentioned. A similar distribution applies to the expression of number. Within the noun phrase, there are no number affixes, although there is a plural specifier *ŋɪ̄* or *ɡɪ̄* that can be used with rational nouns as seen in (6). Speakers consulted assess this specifier the same way as unmarked relative clauses within the noun phrase: acceptable, but not used much. However, Ama also has a post-verbal quantifier *ɡàɪ̀* that can be used when there is a plural participant in the clause, as shown in (7).[^14]

[^14]: 	Stevenson, *Grammar of the Nyimang Language,* p. 176, claims that “GAI gives the idea of completion, going on till an act is finished,” although all his examples involve a plural subject "they.” His claim suggests that this quantifier may have a collective function, over all participants and/or over all the stages in the completion of the event. It can nevertheless appear in the same clause as distributive marking *-ɪ́d̪,* as in an example shown in Norton, “Number in Ama verbs,” p. 83, *wùd̪ēŋ bā dɔ̄rɛ̄ŋ t̪ɛ̀l-ɪ́d̪-ɛ̄ ɡàɪ̀* "the child saw each of the children [until she had seen them all].”

{{< gloss "(6)" >}}
{r} Plural noun phrase specifier (elicited)
{g} *ābā*,father|*dɪ̀à*,big|*ŋɪ̄*,[pl]({sc})|
{r} “grandfathers”
{{< /gloss >}}

{{< gloss "(7)" >}}
{r} Post-verbal plural quantifier
{g} *wàá*,people|*dū*,[top]({sc})|*fāɽāŋ*,drum|*fɪ̄l*,dance:[prog]({sc})|*ɡàɪ̀*,[pl]({sc})|
{r} “The people were all dancing to a drum.”
{{< /gloss >}}

We will return to this tendency to express relative clauses and number late in the clause after considering other evidence from verb stems.

# Ama Verb Stems {#3}

Stevenson discovered the existence of two stems of each Ama verb.[^15] The forms of the two stems are not fully predictable from each other in general, and their usage depends on aspect.

[^15]: Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 177.

## The Factative–Progressive Distinction

The aspectual functions of the two stems were described by Stevenson as definite and indefinite aspect, and relabeled as perfective and imperfective by more recent authors. However, the usage of the former stem meets the definition of “factative,”[^16] such that it has a past perfective reading when used for an active verb like “eat,” but a present continuous reading when used for a stative verb like “know.” The other stem has a present progressive reading, which is marginal for stative verbs (as indicated by "?") where the meaning contribution of progressive to an already continuous verb is highly marked.[^17] The factative–progressive analysis is helpful when we consider the history of these stems below.

[^16]: 	Welmers, *African Language Structures,* pp. 346, 348.
[^17]: 	Compare Mufwene, “Stativity and the Progressive,” where it is argued that progressive is a stativizing category in a number of European and Bantu languages, although progressive verb forms typically have a more transient interpretation, and lexical statives a more permanent interpretation.

|                        | active verb                 | stative verb |
| :---                    | :---                         | :---          |
| [fact]({sc})  | *t̪àl* “ate” (past perf.) | *t̪ʊ̄-máɪ́* “know” (pres. cont.) |
| [prog]({sc}) | *tām* “is eating”             | ?*máɪ́* “is knowing” |

**~~Table 4. Verb stems of active and stative verbs~~**

## Stem Formation and the Verb Root

Although factative aspect is broader in meaning and more heavily used in text, the progressive stem is generally more basic in form, often consisting only of the bare root. However, neither the factative stem nor the progressive stem is predictable from the other in general because: (i) factative stems belong to various theme vowel classes, and some belong to a class taking a formative prefix *t̪V-*; (ii) in some verbs the two stems have two different suppletive roots; and (iii) the progressive stems of some verbs require certain obligatory incorporated affixes. When the root is extracted from any additional formatives, CVC is the most frequent verb root shape.

| [fact]({sc})   | [prog]({sc}) | Gloss       | morphology other than [fact]({sc}) theme vowel |
| :---        | :---         | :---         | :--- |
| *sāŋ-ɔ̄*      | *sāŋ*         | search      | |
| *kɪ̄r-ɛ̄*      | *kɪ̄r*         | cut         | |
| *wāɡ-ā*      | *wʊ̄ɔ̄*         | keep        | suppletive roots |
| *t̪ī-ə̀*       | *túŋ*         | sleep       | suppletive roots |
| *t̪áw-ɔ̄*      | *ɡēd̪-ì*       | cook        | suppletive roots, final *-i* required after *d̪* |
| *ɟɛ́ɡ-ɛ̄*      | *ɟēɡ-īn*      | leave s.th. | applicative *-(ī)n* |
| *á-bɪ̄ɽ-ɪ̄ŋ-ɔ̄* | *á-bɪ̄ɽ-ɪ̄ŋ*    | invent      | causative *á-* and inchoative *-ɪ̄ŋ* |
| *t̪ī-ŋīl-ē*   | *ŋɪ̄l*         | laugh       | factative *t̪V-* |
| *t̪ū-mūs-ò*   | *mús-èɡ*      | run         | factative *t̪V-* ~ directional *-èɡ* |
| *t̪ɪ́-ɡɛ̄l-ɛ̄*   | *á-ɡɛ̄l*       | wash        | causative-factative *t̪V́-* ~ causative *á-* |
| *ɕɪ̀-ɛ̄*       | *á-ɕɪ̄*        | do (intr.)  | causative *á-* |

**~~Table 5. Examples of verb stems~~**

The CVC shape of verb roots is characteristic across Eastern Sudanic languages. In Gaahmg, for example, at least 90% of verb roots are CVC, whereas nouns are much more varied in shape.[^18] CVC is also the predominant shape in the following comparative data for verbs across Northern branches of Eastern Sudanic.[^19]

[^18]: Stirtz, *A Grammar of Gaahmg,* p. 40.
[^19]: Rilly, *Le méroïtique et sa famille linguistique,* annex.

| Gloss      | Nubian                  | Nara          | Taman            | Nyima            | Proto-NES |
| :---        | :---                     | :---           | :---              | :---              | :--- |
| be         | *\*-a(n)/\*-a-ɡV*         | *ne-/ge-* [pl]({sc}) | *\*an-/\*aɡ-*      | *\*nV*             | *\*(a)n/\*(a)ɡ* [pl]({sc}) |
| burn       | *\*urr*                   | *kál, war*      | *\*wer            | *\*wul* "boil"     | *\*wul,* [*\*wel*?] |
| buy        | *\*jaan*                  | *tol ~ dol*     | –                | *\*tar*            | *\*tol* |
| come       | *\*taar*                  | *til*           | *\*or,* [pf]({sc}) \*kun  | *\*t̪ar/\*kud̪*      | *\*tar,* [*\*kud*?] |
| cut        | *\*mer*                   | *ked*           | *\*kid*            | – (Ama *kɪr*)     | *\*kɛd* |
| dance      | *\*baan*                  | *bàl, bàr*      | –                | *\*bal/fal*        | *\*bal* |
| drink      | *\*nii*                   | *l-, líí-*      | *\*li*             | – (Ama *li*)      | *\*li* |
| eat        | *\*kal*                   | *kal*           | *\*ŋan*            | *\*t̪al/\*tam*      | *\*kal/\*kamb* [pl]({sc}) |
| give       | *\*tir* (2/3), *\*deen* (1) | *nin*           | *\*ti(n)*          | *\*t̪Vɡ, \*t̪ɔ́ŋ* (1) | *\*te(n)* [final C?], *\*den* |
| look       | *\*ɡuuɲ*                  | –             | *\*ɡun,* [pf]({sc}) *\*ɡud* | *\*t̪iɡol*          | *\*guɲ* [final C?] |
| love, want | *\*doll, \*oon*           | *sol*           | – (Tama *tar*)     | – (Ama *war*)     | *\*tor* |
| sit        | *\*ti(i)g/\*te(e)g*       | *dengi, daŋŋi* "wait" | *\*juk*      | *\*dɔɲ*            | *\*daŋ* |
| take, carry | *\*aar*                  | –             | *\*ar-i*           | *\*-ur*            | *\*ar* |
| take, gather | *\*dumm*                | *nem*           | – (Tama *tɔ-mɔɽ*)  | – (Ama *dum-*)     | *\*dɔm* |
| take, raise | *\*eɲ*                   | *hind*          | *\*eɲ*              | – (Ama *ɲɔn* "carry") | *\*meɲ ~ \*ɲeɲ* |

**~~Table 6. Verbs across Northern East Sudanic (NES)~~**

## T/K Morphology for Factative/Progressive {#tk}

An alternation between *t̪-* and *k-* cuts into the characteristic CVC shape in one class of Ama verbs as a marker of aspect along with the theme vowel.

| [fact]({sc}) | [prog]({sc}) | Gloss |
| :---            | :---              | :---   |
| *t̪-ùɡ-è*         | *k-ūɡ*             | build |
| *t̪-īw-ò*         | *k-íw*             | dig   |
| *t̪-ūɕ-ē*         | *k-úɕ-ín*          | light (fire) |

**~~Table 7. T/K marking on Ama verbs~~**

A longer list of examples of this alternation shown in **Table 8** was documented by Stevenson, Rottland & Jakobi, albeit with a different standard of transcription; they also detected the alternation in Afitti (*tosù/kosìl* “suckle”; *tòsù/kosìl* “light fire”).[^20]

[^20]: 	Stevenson, Rottland & Jakobi, “The Verb in Nyimang and Dinik,” p. 16. By convention, *t* is dental and mid tone is left unmarked in their data. Pertinent to the present alternation, I question the phonemic status of the *w* in *t/kw* alternations before rounded vowels.

| [fact]({sc}) | [prog]({sc}) | Gloss |
| :---            | :---              | :--- |
| *tuɡɛ̀*           | *kwò*              | build |
| *tàiɔ̀*           | *kaì*              | chop |
| *tìwò*           | *kìù*              | dig |
| *tìwò*           | *kèù*              | fall (of rain) |
| *twɛ̀*            | *kwài*             | rear, bring up |
| *twèr*           | *kweàɡ*            | grow [itr]({sc}) |
| *tɔwɛ̀*           | *kwɔ̀i*             | grow [tr]({sc}) |
| *tuwɛlɛ̀*         | *kwɛlì*            | guard |
| *tuɡudò*         | *kwoɡidì*          | mix up, tell lies |
| *toromɔ̀*         | *kwòròm*           | gnaw |
| *toso*           | *kwoʃì*            | suck (milk, of baby) |
| *tɔʃìɡ*          | *kwɔʃìɡ*           | suckle |
| *tosùn*          | *kwosùn*           | burn [itr]({sc}) |
| *tuʃè*           | *kwuʃìn*           | light fire |
| *tɛ̀nɛ̀*           | *kɛndìr*           | climb |
| *tɛnìɡ*          | *kɛndɛ̀ɡ*           | mount |

**~~Table 8. More verbs with T/K marking~~**

T and K are well-known markers of singular and plural in Nilo-Saharan languages,[^21] but in Ama and Afitti where there is no T/K morphology on the noun, essentially the same alternation (*\*t* becomes dental in the Nyima branch)[^22] is found on the verb. It also cuts into the characteristic CVC verb root shape, implying that it is an innovation on the verb. I therefore propose that this class of verbs attests the Nyima cognate of the wider Nilo-Saharan T/K alternation. This entails a chain of events in which the T/K alternation first moved from the noun (singular/plural) to the verb (singulactional/pluractional), and then shifted in meaning from verbal number to verbal aspect (factative/progressive).

[^21]: 	Greenberg, *The Languages of Africa,* pp. 115, 132; Bryan, “The T/K Languages"; Gilley, “Katcha Noun Morphology,” §2.5, §3, §4; ![Blench, this issue](article:blench.md).
[^22]: 	Rilly, *Le méroïtique et sa famille linguistique,* p. 299.

Both steps in this proposed chain are indeed plausible cross-linguistically. As to the first step, the possibility of nominal plural markers being extended to verbal pluractionals is familiar from Chadic languages, where the same formal strategies such as first-syllable reduplication or *a*-infixation may be found in plural nouns and pluractional verbs.[^23] In the Nyima languages, the productive innovation at this step appears to have been the extension of singulative T to a verbal singulactional marker. This is seen in the fact that *t̪-* alternates with other consonants as well as *k* in Ama (*t̪ān-ɛ̄/wɛ̄n* “talk,” *t̪ɛ̀l-ɛ̄/wɛ̄ɛ́n* “see,” *t̪àl/tām* “eat”), or is prefixed in front of the root (*t̪ʊ́-wár-ɔ̄/wār* “want,” *t̪ī-ŋīl-ē/ŋɪ̄l* “laugh,” *t̪ì-fìl-è/fɪ̄l* “dance,” *t̪ū-mūs-ò/mús-èɡ* “run,” *t̪ʊ̄-máɪ́/máɪ́* “know,” *t̪-īlm-ò/ɪ́lɪ́m* “milk”). There is also external evidence from Nubian and Nara cited in **Table 6** above that *\*k* is the original initial consonant in *\*kal* “eat” replaced by *t̪-* in Ama and Afitti.

[^23]: 	Frajzyngier, “The Plural in Chadic"; Wolff, “Patterns in Chadic (and Afroasiatic?) Verb Base Formations.”

As to the second step, the prospect of verbal number shifting to verbal aspect is supported by semantic affinity between pluractional and progressive. Progressive aspect often entails that a process that is iterated ("is coughing,” "is milking") over the interval concerned.[^24] In Leggbo,[^25] a Niger-Congo language, the progressive form can have a pluractional reading in some verbs, and conversely, verbs that fail to form the regular progressive *C# → CC-i* because they already end in *CCi* can use the pluractional suffix *-azi* instead to express progressive aspect. In Spanish,[^26] a Romance language, there is a periphrastic paradigm between progressive (*estar* “be” + gerund), frequentative pluractional (*andar* “walk” + gerund), and incremental pluractional (*ir* “go” + gerund). The two Spanish pluractionals have been called “pseudo-progressives,” but conversely one could think of progressive aspect as pseudo-pluractional. What is somewhat surprising in Ama is that progressive stems, being morphologically more basic (see **Table 5**), lack any devoted progressive affixes that would have formerly served as pluractional markers.[^27] However, some progressive marking is found in irregular alternations that reveal former pluractional stems.

[^24]: Newman, “Pluractional Verbs” notes a separate affinity between pluractional and habitual aspect found in Niger-Congo and Chadic languages. Smits, *A Grammar of Lumun, Vol. 2,* §13, identifies habitual pluractionals in a Niger-Congo language of the Nuba Mountains.
[^25]: Hyman & Udoh, “Progressive Formation in Leggbo.”
[^26]: Laca, “Progressives, Pluractionals and the Domains of Aspect.”
[^27]: See, however, §4.2 below which purports to recover the missing extension.

In *t̪àl/tām* “eat,” the final *l/m* alternation is unique to this item in available word lists, although *l/n* occurs elsewhere (*kɪ́l/kín* “hear,” *t̪ɛ̀l-ɛ̄/wɛ̄ɛ́n* “see”). The final *l/m* alternation is nevertheless also found in Afitti (*t̪ə̀lɔ̀/tə̀m* “eat”) and in Kordofan Nubian (*\*kol ~ kel/\*kam* “eat”).[^28] Kordofan Nubian *\*kam* is used with a plural object, a pluractional function, so in the Nyima branch the proposed shift pluractional → progressive derives the progressive function of final m found in Ama, just as it does for the initial *k* in *t̪/k* alternations or the *t* in *t̪àl/tām* “eat.” Furthermore, a final plosive in Old Nubian (ⲕⲁⲡ-[^29]; Nobiin *kab-*) suggests that the unique *m* in “eat” arose by assimilation of the final nasal (realized as *n* in the other Ama verbs mentioned) to a following *\*b*, that was fully assimilated or incorporated in Old Nubian.

[^28]: Rilly, *Le méroïtique et sa famille linguistique,* p. 478.
[^29]: Ibid; Old Nubian also attests the lateral in a hapax form ⲕⲁⲗ-.

Seen in this light, the significance of moving T/K morphology onto verbs in the Nyima branch is that it renewed an existing system of irregular singulational/pluractional alternations. We then have a tangible account of where Ama’s missing noun morphology went, because formerly nominal morphology is found on the verb instead.

## Concretization of Core Clause Constituents

We can also now tie together this finding with the findings on verb syntax in [2](#syntax). Both T/K number marking and relative clause modification have moved out of the noun phrase, and in these comparable changes we can observe a trend towards concretization of noun phrases, with number and clausal information about the participant being expressed later in the clause.

The trend towards concretization also affects the verb itself. T/K and other irregular stem alternations did not maintain their pluractional meaning, as this evolved into a more concrete construal of the predicate over an interval of time as progressive aspect. Since concretization affected the verb as well as noun phrases, it affected the entire core SOV clause, with plurality as well as relative clauses largely deferred to after the verb.

A role for concreteness in grammar was previously proposed in the Pirahã language of Brazil by Everett.[^30] Everett’s approach remains highly controversial,[^31] particularly, I believe, in its attempt to constrain grammar by culture directly in the form of a synchronic “Immediacy of Experience Constraint” on admissible sentence constructions and lexemes in Pirahã. My proposal here is deliberately less ambitious, appealing to concreteness as a diachronic trend in the Nyima branch, not as a constraint on the current synchronic grammar of Ama. Thus, Ama typically attests a separation between a concrete SOV clause and post-verbal modification, but this is not a strict division in the grammar, because it is not impossible to express number or relative clauses within the noun phrase, just infrequent. The concretization process in Ama must also have been specific enough not to have eliminated adjectives from the noun phrase. Ama has adjectives, as shown in examples (8)–(11), which occur as attributive modifiers of nouns in their unmarked form, whereas in predicates they are separated from the subject noun by a clause particle and occur as the complement of the inflecting copula verb *nɛ̄*. Ama adjectives include numerals and quantifiers, despite the limited role of number in the grammar.

[^30]: 	Everett, “Cultural Constraints on Grammar and Cognition in Pirahã.”
[^31]: Nevins, Pesetsky & Rodrigues, “Pirahã Exceptionality"; Everett, “Pirahã Culture and Grammar.”

{{< gloss "(8a)" >}}
{g} *kwɛ̄ɪ̄*,man|*tòɽū*,tall|
{r} “tall man”
{{< /gloss >}}

{{< gloss "(8b)" >}}
{g} *kwɛ̄ɪ̄*,man|*ā*,[decl]({sc})|*tòɽū*,tall|*nɛ̄*,be|
{r} “The man is tall.”
{{< /gloss >}}

{{< gloss "(9a)" >}}
{g} *kwɛ̄ɪ̄*,man|*ɡɔ̀ɽɛ̀*,old|
{r} “old man”
{{< /gloss >}}

{{< gloss "(9b)" >}}
{g} *kwɛ̄ɪ̄*,man|*ā*,[decl]({sc})|*ɡɔ̀ɽɛ̀*,tall|*nɛ̄*,be|
{r} “The man is old.”
{{< /gloss >}}

{{< gloss "(10a)" >}}
{g} *ŋɔ̄ɽɪ̄*,day|*mūl*,five|
{r} "five days"
{{< /gloss >}}

{{< gloss "(10a)" >}}
{g} *ŋɔ̄ɽɪ̄*,day|*ā*,[decl]({sc})|*mūl*,five|*nɛ̄-ɛ́d̪-ɪ̄*,be-[distr-th]({sc})|
{r} “The days are five.” (“There are five days.”)
{{< /gloss >}}

{{< gloss "(11a)" >}}
{g} *wàá*,people|*kàdúùŋ*,many|
{r} "many people"
{{< /gloss >}}

{{< gloss "(11b)" >}}
{g} *wàá*,people|*ā*,[decl]({sc})|*kàdúùŋ*,many|*nɛ̄-ɛ́d̪-ɪ̄*,be-[distr-th]({sc})|
{r} “The people are many.” (“There are many people.”)
{{< /gloss >}}

# Ama Verbal affixes {#4}

Research over the past century has also been gradually clarifying the complex morphological system of Ama verbs.[^32] Factative and progressive aspect are distinguished in the affix system as well as in stems, and there is an evolving portfolio of pluractional affixes.

[^32]: 	Stevenson, *Grammar of the Nyimang Language,* §XI; Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: pp. 171–183; Stevenson, Rottland & Jakobi, “The Verb in Nyimang and Dinik"; Norton, “Number in Ama Verbs”; Norton, “The Ama Dual Suffix"; Norton, "Classifying the Non-Eastern-Sudanic Nuba Mountain Languages.”

## Affix Selection and Order

Some verbal affixes are selected depending on factative or progressive aspect in Ama, just as verb stems are. For example, different suffixes for past tense or for directional movement are selected in the different aspects:

|             | Stem | [pst]({sc}) |
| :---         | :---  | :--- |
| **[fact]({sc})**   | *t̪àl*  | *t̪àl-ʊ̀n* |
| **[prog]({sc})** | *tām*  | *tām-áʊ́* |

**~~Table 9a. Affix selection according to aspect: "eat"~~**

|             | Stem   | [dir]({sc}) |
| :---         | :---    | :--- |
| **[fact]({sc})**   | *dɪ̀ɟ-ɛ̄*  | *dɪ̀ɟ-ɛ̄-ɡ* |
| **[prog]({sc})** | *dɪ̄ɟ-ɪ̄*  | *dīɟ-ír* |

**~~Table 9b. Affix selection according to aspect: "throw"~~**

The same is true of passive and ventive suffixes, but in factative aspect the suffixes replace the theme vowel, so that the affixes are the sole exponent of aspect in many verbs:

|             | Stem     | [pass]({sc}) |
| :---         | :---      | :--- |
| **[fact]({sc})**   | ásɪ̄d̪āy-ɛ̄ | ásɪ̄d̪āy-áɪ́ |
| **[prog]({sc})**  | ásɪ̄d̪āɪ̄   | ásɪ̄d̪āy-àɡ |

**~~Table 10a. Affix selection as sole exponent of aspect: "paint"~~**

|             | Stem     | [ven]({sc}) |
| :---         | :---      | :--- |
| **[fact]({sc})**  | ɪ̄r-ɛ̄     | ɪ̄r-ɪ́ɪ̄ɡ |
| **[prog]({sc})**  | ɪ̄r       | ɪ̄r-ɪ́d̪ɛ̄ɛ̀ɡ |

**~~Table 10b. Affix selection as sole exponent of aspect: "send"~~**

In passive and in past, affix order also varies according to aspect with respect to the dual suffix *-ɛ̄n*:

|             | Stem     | [du pass]({sc}) |
| :---         | :---      | :--- |
| **[fact]({sc})**   | ásɪ̄d̪āy-ɛ̄ | ásɪ̄d̪āy-áy-ɛ̄n |
| **[prog]({sc})**  | ásɪ̄d̪āɪ̄   | ásɪ̄d̪āy-ɛ̄n-àɡ |

**~~Table 11a. Affix order variation according to aspect: "paint"~~**

|             | Stem     | [du pst]({sc}) |
| :---         | :---      | :--- |
| **[fact]({sc})**   | sāŋ-ɔ̄    | sāŋ-ɛ̄n-ʊ̀n |
| **[prog]({sc})**  | sāŋ      | sāŋ-áw-ɛ̄n |

**~~Table 11b. Affix order variation according to aspect: "search"~~**

The origin of this affix order variation is revealed by further evidence. Passive marking comes after dual in progressive aspect, whereas past marking comes after dual in factative aspect, but the common feature of both suffixes *-àɡ, -ʊ̀n* placed after the dual is that they both bear low tone. Two more suffixes with low tone, directional *-ɛ̀ɡ ~ -ɡ* (the second allomorph is toneless) and mediocausative *-àw ~ -ɔ̀* (the second allomorph is used word-finally) appear after the dual, but if another low-tone suffix is added after the dual, they appear before the dual instead. Hence, there is only one more affix slot in Ama after the penultimate dual suffix.

|                          |                  |                      | |
| :---                      | :---              | :---                  |  :--- |
| **Gloss**                | throw            | throw to [du]({sc})       | elicit [du]({sc}) |
| **[fact]({sc})**           | dɪ̀ɟ-ɛ̄-ɡ          | dɪ̀ɟ-ɪ́-n-ɪ̄ɡ           | kɪ́l-ɛ̄n-ɔ̀ |
|                          | throw-[th-dir]({sc})     | throw-[ven-du-dir]({sc})     | hear-[du-medcaus]({sc}) |
| **[fact imp]({sc})** | dɪ̀ɟ-ɛ̀ɡ-ɛ̄-ɪ̀       | dɪ̀ɟ-ɪ́-ɡ-ɛ̄n-ɪ̀         | kɪ́l-àw-ɛ̄n-ɪ̀ |
|                          | throw-[dir-th-imp]({sc}) | throw-[ven-dir-du-imp]({sc}) | hear-[medcaus-du-imp]({sc}) |
| **[fact pst]({sc})**       | dɪ̀ɟ-ɛ̀ɡ-ɔ̄-ɔ̀n      | dɪ̀ɟ-ɪ́-ɡ-ɛ̄n-ʊ̀n        | kɪ́l-àw-ɛ̄n-ʊ̀n |
|                          | throw-[dir-th-pst]({sc}) | throw-[ven-dir-du-pst]({sc}) | hear-[medcaus-du-pst]({sc}) |

**~~Table 12. Inward displacement of suffixes by an imperative or past suffix~~**

Both types of affix alternation in **Tables 11 and 12** involve low-tone suffixes in the final slot. Therefore, the development of all affix order alternations can be attributed to a single historical shift of all low-tone suffixes to the final slot. However, this shift is not realized in verbs containing two low-tone suffixes, because only one of them can go in the final slot. The only final-slot suffix that does not alternate is the imperative *-ɪ̀,* which leaves imperative as original to the final slot. Other suffixes originate from more internal slots to the left of the dual.

As for the origin of affix selection according to aspect, this presumably arose as an extension of the systematic stem selection that occurs for every verb in Nyima languages. This question remains complex, however, because each of the categories affected (past, passive, directional, ventive) will have its own history as to how alternating affixes were acquired in these conditions. One modest proposal is that the NES plural copula *\*aɡ* shown earlier in **Table 6** is the likely source of the progressive passive suffix *-àɡ* in Ama,[^33] via the shift from pluractional to progressive \([3.3](#tk)\), and by a plausible assumption of a transition in passive marking strategy from use of a copula to morphological marking on the verb. This sourcing does not extend to the other passive suffix in factative aspect *-áɪ́,* however, which does not resemble the singular copula *\*an*. Some similar proposals that other progressive suffixes have pluractional origins are made in the course of §4.2 below.

[^33]:	The Tama plural copula *àɡ* is likewise listed with low tone in Rilly, *Le méroïtique et sa famille linguistique,* p. 451.

## Pluractional Affixes

Ama has extensions that fall within the family of pluractionals that associate plurality with the verb in different ways, that has emerged as an area of study in language description in recent years.[^34] These extensions are particularly comparable with Nubian and other related languages.

[^34]: Newman, “Pluractional Verbs.”

### Distributive Pluractional

Ama has a distributive suffix *-ɪ́d̪* that marks incremental distribution of an event over time or over participants (*àɪ̀ bā fʊ̄rā mʊ̄l t̪àl-ɪ́d̪-ɛ̀* "I ate until I had eaten five rabbits,” *wùd̪ēŋ bā dɔ̄rɛ̄ŋ t̪ɛ̀l-ɪ́d̪-ɛ̄* "The child saw each of the children").[^35] Called “plural” in earlier works, it is remarkable that this category was largely unaffected by the shift of pluractional → progressive analyzed in [3.3](#tk) above,[^36] indicating that we are dealing with two distinct pluractionals, a distributive pluractional and another former pluractional that is now progressive. Ama has a second distributive suffix *-r* used only on verbs with the theme vowel *-a* (*wāɡ-ā* "keep,” distributive *wāɡ-ɪ́d̪-ā-r*).[^37] Ama’s immediate relative Afitti has a “verbal plural” suffix *-tər,*[^38] which corresponds to Ama *-ɪ́d̪* and *-r* combined, reminiscent of their use in that order in Ama on verbs with the theme vowel *-a,* but regularized to all verbs in Afitti. The Ama suffix *-ɪ́d̪* also closely resembles a “plural action” suffix *-(ɨ)t̪* in the nearby Eastern Sudanic language Temein,[^39] and a “plurality of action” suffix *-íd* in Midob.[^40] The distributive suffix *-ij* in Mattokki (Kunuz Nubian) is also similar.[^41]

[^35]: 	Norton, “Number in Ama Verbs,” pp. 77, 83.
[^36]: 	I say the distributive is “largely” unaffected by the shift from pluractional to progressive because a dental plosive appears to have been co-opted in the progressive ventive suffix, as in *dɪ̀ɟ-ɪ́-n-ɪ̄ɡ/dɪ̀ɟ-ɪ́d̪-ɛ̄n-ɛ̀ɡ* (throw-[ven-du-dir]({sc})) "threw to"/"is throwing to” as the dental plosive is the only difference with the factative ventive suffix *-ɪ́*.
[^37]: 	Norton, “Number in Ama Verbs,” p. 81.
[^38]: 	De Voogt, “Dual Marking and Kinship Terms in Afitti,” p. 903, which also shows a similar plural object suffix *-to*.
[^39]: 	Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 187, where *ɨ* is used in the same way as contemporary *ɪ*. Tone was not recorded.
[^40]: 	Werner, *Tìdn-áal,* p. 52.
[^41]:	Abdel-Hafiz, *A Reference Grammar of Kunuz Nubian,* p. 117. Tone was not recorded.

Distributive pluractionals are characterized by optionality with a plural participant (distributivity implies plurality but is distinct from it),[^42] which distinguishes them from plural-object pluractionals found in many Nubian languages that mark, and are thus obligatory with, plural objects.[^43] Distributives are also characterized by non-occurrence with dual participants (to be non-trivial, distribution requires at least three targets).[^44] The Ama distributive has the first property of optionality in transitive (but not intransitive) verbs, and the second property of non-duality with respect to subjects (but not objects).[^45] This second property is shared by the Afitti suffix *-t(ə)r* which likewise does not occur with dual subjects.[^46] This is shown in Afitti field data below,[^47] where the suffix *-t(ə)r* contrasts in this respect with plural pronominal affixes [1pl]({sc}) *ko-*, [2pl]({sc}) *o-*, and [3pl]({sc}) *-i* which do occur with dual subjects.

[^42]: 	Corbett, *Number,* p. 116.
[^43]: ![Jakobi, this issue](article:jakobi.md)
[^44]: 	Corbett, *Number,* pp. 115–116.
[^45]: 	Norton, “Number in Ama Verbs,” pp. 78, 79, 91.
[^46]:	De Voogt, “Dual Marking and Kinship Terms in Afitti,” p. 903.
[^47]: I am grateful to Alex de Voogt for sharing this data in personal communication from his field research on Afitti.

| 1 | Gloss         | 2 | Gloss          | 3 | Gloss |
| :---        | :---           | :---        | :---            | :---        | :---   |
| ɡə́-ɡaɲal   | I milk        | é-ɡaɲal    | you [sg]({sc}) milk | kaɲál      | he/she milks |
| kó-ɡaɲal   | we [du]({sc}) milk | ó-ɡaɲál    | you [du]({sc}) milk | ɡaɲál-i    | they [du]({sc}) milk |
| kó-ɡaɲa-tr̀ | we [pl]({sc}) milk | ó-ɡaɲa-tr̀  | you [pl]({sc}) milk | ɡaɲá-tər-i | they [pl]({sc}) milk |

**~~Table 13. Afitti pluractional *-t(ə)r* not used with dual subjects~~**

Beyond the Nyima branch, the Temein “plural action” suffix *-(ɨ)t̪* shares the first property of optionality as it “is by no means always added with plural objects.”[^48] It actually marks a distributive effect of the verb on the object (*ŋɔŋɔt-ɨt̪-ɛ dʉk* "I break the stick into pieces"), as also found with the Mattokki distributive suffix *-ij* (*duɡuːɡ ɡull-ij-ossu* ‘She threw the money here and there’).[^49] Information on non-occurrence with dual subjects is not reported in these languages, but it appears that this is because non-duality is a feature of incremental-distributive marking as found in Nyima, and not distributive-effect marking as found in Temein and Mattokki which can even occur with a singular object, as in the Temein example.

[^48]: Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 187.
[^49]: 	Abdel-Hafiz, *A Reference Grammar of Kunuz Nubian,* p. 118.

The confirmation of distributive markers across Nubian, Nyima, and Temein implies that a distributive pluractional was present in Eastern Sudanic from an early stage, with a form like *\*-id.* In Nubian the consonant is palatal,[^50] and although palatals are a difficult area for establishing wider sound correspondences,[^51] the palatal arises in the plausible conditioning environment of a high front vowel.

[^50]: 	![Jakobi, this issue](article:jakobi.md). Jakobi points that the other very similar suffix *-íd* in Midob cannot be reconstructed to proto-Nubian from just one Nubian language, so appears to be an innovation, and her observation of its similarity to the Ama suffix clearly suggests borrowing into Midob from Ama’s ancestor or another related language. Hence, the reconstructable pluractional **[i]ɟ* is more viable as the historic cognate of the Ama suffix.
[^51]: 	Rilly, *Le méroïtique et sa famille linguistique,* pp. 303–304.

### Second Historic Pluractional

Ama’s second distributive suffix *-r* corresponds to the Nubian plural object marker *\*-er,*[^52] and since this suffix is much less productive in Ama, it may well have been bleached of its original meaning. In the Kordofan Nubian language Uncu, the cognate extension *-er* has the same function as the irregular pluractional stem *(kol/)kom* “eat,” as both occur with plural objects.[^53] Similarly in Ama, some trills shown below occur in the same category as the irregular progressive stem *(t̪àl/)tām* “eat,” providing evidence that the trill originally marked the second Nyima pluractional that is now progressive.

[^52]: ![Jakobi, this issue](article:jakobi.md).
[^53]: Comfort, “Verbal Number in the Uncu Language.”

The Ama suffix *-ar* can be added to a progressive verb as a mirative that marks unexpected events (*swāy-ɔ́* “was cultivating” → *swāy-ɔ̄r-ɔ́* “was unexpectedly cultivating,” where the vowel has harmonized to the following vowel). However, this suffix is also used to disambiguate progressive verb forms from otherwise indistinguishable factatives (*sāŋ-ɛ̄n/sāŋ-ɛ̄n, sāŋ-ār-ɛ̄n* “search [du]({sc})”),[^54] providing what looks like an alternate progressive stem to take the dual suffix. Similarly, the negative imperative construction in Ama requires a progressive stem with *-ar* after the negative particle *fá* as shown in **Table 14** below. Inflections occurring in this construction are a plural subject marker *à-* on the particle, and dual or distributive marking on the verb. Only the dual suffix can occur without *-ar*, where in my data the dual suffix adds to the longer stem with *-ar* unless the short stem is suppletive (*t̪ī-ə̀/túŋ* “sleep,” t̪àl/*tām* “eat”) and can take the dual suffix without ambiguity with factative aspect.

[^54]: 	Norton, “Number in Ama Verbs,” p. 40.

| [sg]({sc}) | [du]({sc}) | [distr pl]({sc}) | Gloss |
| :---      | :---  | :---                 | :---   |
| fá kɪ̄r-ār | à-fá kɪ̄r-ār-ɛ̄n | à-fá kɪ̄r-ɪ́d̪-ār | don’t be cutting! |
| fá sāŋ-ār | à-fá sāŋ-ār-ɛ̄n | à-fá sāŋ-ɪ́d̪-ār | don’t be searching! |
| fá túŋ-ār | à-fá túŋ-ɛ̄n    | à-fá túŋ-ɪ́d̪-ār | don’t be sleeping! |
| fá tām-ār | à-fá tām-ɛ̄n    | à-fá tām-ɪ́d̪-ār | don’t be eatingǃ |

**~~Table 14. Ama negative imperative paradigms~~**

Another trilled suffix *-ir* marks motion in progress.[^55] It can be added to a progressive verb (*dɪ̄ɟɪ̄* “is throwing” → *dīɟ-ír* “is throwing (motion in progress)”), but on several motion verbs it is documented as part of the progressive stem, as in the examples in **Table 15** below from Stevenson, Rottland, and Jakobi.[^56] The motion meaning of *-ir* simply agrees with the semantics of the roots, all of which define motion along some schematic scale, so that the aspectual meaning of *-ir* assumes greater significance. Hence, *-ir* approximates a progressive stem formative for this class of verbs. The final example in **Table 15**, due to Kingston,[^57] shows still another trilled suffix *-or* in the progressive stem of a caused motion verb.

[^55]: I defer description of tone on this affix to another time.
[^56]: Stevenson, Rottland & Jakobi, “The Verb in Nyimang and Dinik.”
[^57]:	This verb appears in unpublished data collected by Abi Kingston.

| [fact]({sc}) | [prog]({sc}) | Gloss |
| :---       | :---         | :---   |
| bwìɡ      | buɡìr       | overtake |
| nɪfɛ̀ɡ     | nɪfìr       | fall |
| tɛnɛ̀      | kɛndìr      | climb |
| tɪjɛ      | jeìr        | shoot |
| ánasa     | ánasor      | take down |

**~~Table 15. Progressive stems ending in a trill~~**

The trill thus fuses with certain vowels that behave like theme vowels for creating extended progressive stems. As a progressive element, the trill most probably derives from the shift of pluractional → progressive, identifying it as the missing extension of the second Nyima pluractional. We then have an Ama distributive pluractional suffix *-ɪ́d̪* that resembles the Nubian distributive pluractional *\*-(i)ɟ,* and Ama “pseudo-pluractional” progressive suffixes of the shape *-Vr* that resemble the Nubian plural-object pluractional *\*-er*.

### Innovative Dual-Participant Pluractional

A late addition to Ama’s pluractional portfolio is its unique dual suffix *-ɛ̄n*.[^58] The older form of the Ama dual suffix is *-ɪn,*[^59] which has been noted to resemble reciprocal suffixes in other Eastern Sudanic languages, such as Kordofan Nubian *-in*, Daju *-din*, Temein *-ɛ*, and also Ik *-in* of the Kuliak group.[^60] In Ama, its function has evolved to dual reciprocal and other dual participant readings, so for example *wʊ̀s-ɛ̄n* “greet [du]({sc})” can refer to when two people greeted each other, or someone greeted two people, or two people greeted someone.[^61] The dual suffix is regularly used in Ama folktales to link two primary characters.[^62] Although such dual participant marking is extremely rare globally, it becomes possible in Nyima languages in particular where the incremental-distributive pluractional leaves a paradigmatic gap for dual subjects, as still seen in Afitti in **Table 13** above, which Ama has filled in.

[^58]: 	Norton, “Number in Ama Verbs,” §3.
[^59]: 	Stevenson, Rottland & Jakobi, “The Verb in Nyimang and Dinik,” p. 28.
[^60]: 	Norton, “The Ama Dual Suffix,” p. 121.
[^61]: 	Ibid., p. 120.
[^62]: 	Norton, “Number in Ama Verbs,” pp. 84, 87.

# Conclusion: Ama as a Matured Northern East Sudanic Language {#5}

Ama verbs show a number of connections to Nubian and other Eastern Sudanic languages in their clause-final syntax, CVC root shape, and certain affixes. However, these connections are more in form than meaning, as the semantics is highly innovative in such notable shifts as plural → pluractional → progressive and reciprocal → dual, and in the drive towards concretization that has moved the expression of both relative clauses and number out of noun phrases to after the verb. In addition, the movement of low-tone suffixes to the final suffix slot, while itself a formal development, has further advanced the morphologization of aspect, so that stem selection, affix selection, and affix order all vary with aspect in Ama verbs. Next to these considerable changes, Ama’s stable distributive pluractional stands out as indicative of a wider Eastern Sudanic verbal category.

An explanation for the innovations found in Ama will not be found in influence from other languages of Sudan, because several of its innovations are extremely rare (adjoined relative clauses, dual verbal number, tone-driven affix order alternation). Instead of an influx of new forms, we have unusual internal evolution of existing forms, implying relative isolation. Ama then exemplifies what both Dahl and Trudgill call “mature phenomena,”[^63] found in languages of isolated small communities where the language has time to evolve based on an abundance of specific shared information in a closed society of intimates. Languages spoken by isolated societies of intimates are more likely to conventionalize complex morphological paradigms, unusual categories, and unusual syntax (maturation), whereas larger, multilingual social networks encourage simpler grammars in the sense of smaller paradigms, and pragmatically well-motivated categories and syntax that are found widely in language (pidginization). Aforementioned verbal features in Ama of dual number, irregular allomorphy (in suppletive roots and in the use of a second distributive suffix), fusion (in affixes like passive and ventive that mark aspect as well), polyfunctionality (of the progressive suffix *-ar* for mirativity or long stem formation), and multiple exponence (of aspect by stem selection, affix selection, and affix order), plus the unusual syntax of adjoined relative clauses, all look like mature language phenomena.[^64]

[^63]: 	Dahl, *The Growth and Maintenance of Linguistic Complexity*; Trudgill, *Sociolinguistic Typology*.
[^64]:	Maturity could also describe further properties of Ama verbs whose description is in preparation by the author, including further instances of allomorphy, fusion, polyfunctionality, and several kinds of tonal morphology.

Ama nominals, similarly, are known for their relatively rich case systems, but similar case paradigms are found in Nubian and other Northern East Sudanic languages, implying that the case system largely matured at an earlier stage and the resulting complexity is retained in all these languages. Thus, it is the verb system rather than the nominal system that provides evidence of maturation in the Nyima branch in particular.

The conclusion that Ama verbs (and post-verbal syntax) have matured as a result of Nyima’s isolated position, away from the river systems that hosted speakers of other languages in the Sudan region in the past, faces the possible difficulty that contacts have in fact been proposed between Nyima and other Nuba Mountain groups. Thus, it is proposed that the Niger-Congo Nuba Mountain group Heiban borrowed accusative marking and basic vocabulary from Nyima.[^65] Such contact would have put a brake on maturation in Nyima, because the use of proto-Nyima for inter-group communication between first-language Nyima users and second-language Heiban users would not have supported further growth in complexity.[^66] However, it is not realistic that such contacts lasted for a large proportion of Nyima history, but rather were fairly temporary periods punctuating Nyima’s longer isolation. Thus, the Heiban group has now developed separately in the eastern Nuba Mountains for something approaching two millennia (given the internal diversity of the ten Heiban languages found there) since its contact with Nyima.

[^65]: 	Norton, “Classifying the Non-Eastern-Sudanic Nuba Mountain Languages.”
[^66]: 	 Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 175, notes the similarity of Ama’s nominal plural *ŋi* to a similar plural clitic *ŋi* [sic] in Heiban, which here might be interpreted as a pidginization effect in which the universally well-motivated category of nominal plurality was renewed in Nyima during inter-group communication after the earlier loss of number affixes. However, Stevenson is unusually in error in this passage as the Heiban form is actually *-ŋa* as he himself documented (ibid, p. 28). Subsequent lowering to a in Heiban cannot be ruled out (he notes Heiban’s relative Talodi has *ɛ* here), but it is also quite possible that *ŋi* was sourced internally, as the high front vowel is also the common element in the plural pronouns *ə̀ŋí/ɲí/ə̀ní* [1pl/2pl/3pl]({sc})).

Some time after the contact with Heiban, Rottland and Jakobi note the likelihood of contact of Kordofan Nubian with Ama and Afitti in the north-west Nuba Mountains before the arrival of Arabic as a *lingua franca* in the Nuba Mountains.[^67] Ama and Afitti are more lexically divergent than Kordofan Nubian and therefore were probably already separate communities when the Kordofan Nubians arrived. However, the innovation of dual marking on Ama verbs in the period after separation from Afitti still shows the hallmarks of maturation. It adds an extremely rare category, increases the occurrence of morphologically complex verbs by using a verbal marker in dual participant contexts that were not previously marked, and adds redundancy when agreeing with noun phrases containing two referents. This mature feature of Ama again suggests that any language contact with Kordofan Nubian occurred for only part of the time since Ama separated from Afitti.

[^67]: Rottland & Jakobi, “Loan Word Evidence from the Nuba Mountains.”

This period nevertheless also reveals one significant example of simplification in Ama verbs that supports the idea that language contact occurred. Afitti has pronominal subject markers on the verb, seen earlier in **Table 13**, which are absent in Ama. The pronominal prefixes are not the same in form as personal pronoun words in Afitti ([1sg]({sc}) *oi* but [1sg]({sc}) prefix *kə-*),[^68] therefore they are not incorporated versions of the current pronoun words, but rather predate them. Some of the Afitti pronoun words ([1sg]({sc}) *oi,* [2sg]({sc}) *i*)[^69] are similar to Ama ([1sg]({sc}) *àɪ̀,* [2sg]({sc}) *ī*) and must be retentions from proto-Nyima, hence the older pronominal prefixes must also be retentions in Afitti, but lost in Ama. Their loss in Ama is remarkable against the larger trend of growth in complexity of Ama verbs that we have examined in this paper. The predicted cause of this surprising reversal is pidginization under contact. That is, their loss is evidence that the Ama language was used for inter-group communication, presumably with the Kordofan Nubians, during which (and for which) Ama SOV sentences were simplified by dropping verbal subject marking. If Kordofan Nubians spoke Ama, then borrowing from Ama into Kordofan Nubian is also likely. In verbs, the obvious candidate for borrowing into Kordofan Nubian is the reciprocal suffix *-in*, as this is not attested elsewhere in Nubian.[^70] The following two-step scenario would then account for the facts: Ama was learned and used by Kordofan Nubians, during which Ama dropped verbal subject marking and its reciprocal suffix was borrowed into Kordofan Nubian; next, Ama returned to isolation in which the reciprocal suffix developed its dual function that is unique to Ama today.

[^68]: 	 Stevenson, Rottland & Jakobi, “The Verb in Nyimang and Dinik,” pp. 34–38.
[^69]: 	 Stevenson, “A Survey of the Phonetics and Grammatical Structure of the Nuba Mountain Languages,” 41: p. 177.
[^70]: ![Jakobi, this issue](article:jakobi.md).

# Abbreviations

* [1, 2, 3]({sc}) – 1st, 2nd, 3rd person;
* [acc]({sc}) – accusative;
* [decl]({sc}) – declarative;
* [dir]({sc}) – directional;
* [distr]({sc}) – distributive;
* [du]({sc}) – dual;
* [ev]({sc}) – event;
* [fact]({sc}) – factative;
* [gen]({sc}) – genitive;
* [imp]({sc}) – imperative;
* [itr]({sc}) – intransitive;
* KN – Kordofan Nubian;
* [loc]({sc}) – locative;
* [med]({sc}) – mediopassive;
* [medcaus]({sc}) – mediocausative;
* [pass]({sc}) – passive;
* [pct]({sc}) – punctual;
* [pf]({sc}) – perfect;
* [pl]({sc}) – plural;
* [prog]({sc}) – progressive;
* [pst]({sc}) – past;
* [ptcp]({sc}) – participle;
* SA – Sudanese Arabic;
* [sg]({sc}) – singular;
* [th]({sc}) – theme;
* [top]({sc}) – topic;
* [tr]({sc}) – transitive;
* [ven]({sc}) – ventive;
* [ver]({sc}) – veridical

# Bibliography

Abdel-Hafiz, Ahmed. ![*A Reference Grammar of Kunuz Nubian.*](bib:ad02c9ac-0882-49db-880e-ed52beb6a0aa) PhD Thesis. Buffalo: State University of New York, 1988.

Bryan, Margaret A. ![“The T/K languages: A New Substratum.”](bib:16560c89-8752-499a-880b-439171c31936) *Africa* 29 (1959): pp. 1–21.

Comfort, Jade. ![“Verbal Number in the Uncu Language (Kordofan Nubian).”](bib:47ef508d-dcd4-4edb-a5e7-0d8ed83d4d86) *Dotawo: A Journal of Nubian Studies* 1 (2014): pp. 145–163.

Corbett, Greville. ![*Number.*](bib:e55ce3fa-75cd-431c-b32f-76f020d74421) Cambridge: Cambridge University Press, 2000.

Dahl, Östen. ![*The Growth and Maintenance of Linguistic Complexity.*](bib:fa85ce3a-26ea-4eef-b83c-c064741d96b0) Amsterdam: John Benjamins, 2004.

Dimmendaal, Gerrit. ![“Africa’s Verb-Final Languages.”](bib:c0ae4f6f-5acf-40d6-86cf-a409df0b71c0) In *A Linguistic Geography of Africa,* edited by Bernd Heine and Derek Nurse. Cambridge: Cambridge University Press, 2008: pp. 272–308.

Dimmendaal, Gerrit. ![“Introduction.”](bib:8d06150a-e825-4f0a-bcd5-4dd73b374d0e) In *Coding Participant Marking: Construction Types in Twelve African Languages,* edited by Gerrit J. Dimmendaal. Amsterdam: John Benjamins, 2009: pp. 1–22.

Everett, Daniel. ![“Cultural Constraints on Grammar and Cognition in Pirahã: Another Look at the Design Features of Human Language.”](bib:d2683616-fe5d-4e39-82ce-c90afac291c8) *Current Anthropology* 46, no. 4 (2005): pp. 621–646.

Everett, Daniel. ![“Pirahã Culture and Grammar: A Response to Some Criticisms.”](bib:be2fe6d9-0d3f-4bf8-8c33-febab6e158bd) *Language* 85, no. 2 (2009): pp. 405–442.

Frajzyngier, Zygmunt. ![“The Plural in Chadic.”](bib:1af2150f-9e58-43de-b67d-3b3e11eccbf1) In *Papers in Chadic Linguistics,* edited by Paul Newman & Roxana Ma Newman. Leiden: Afrika-Studiecentrum, 1977: pp. 37–56.

Gilley, Leoma. ![“Katcha Noun Morphology.”](bib:e31ac0b3-4fec-4bdc-89a8-d75c16c8ce96) In *Nuba Mountain Language Studies,* edited by Thilo Schadeberg and Roger Blench. Cologne: Rüdiger Köppe, 2013: pp. 501–522.

Greenberg, Joseph. [*The Languages of Africa.*](bib:df1c2298-341c-4367-a9cf-37452f7e3068) Bloomington: Indiana University Press, 1963.

Heine, Bernd & Rainer Voßen. “Sprachtypologie.” In *Die Sprachen Afrikas,* edited by Bernd Heine, Thilo Schadeberg, and Ekkehard Wolff. Hamburg: Helmut Buske, 1981: pp. 407–444.  

Hyman, Larry & Imelda Udoh. ![“Progressive Formation in Leggbo.”](bib:7e75d6d0-9dca-45f6-8b18-bf90435447ae) In *Globalization and the Study of Languages in Africa,* edited by Ozo-mekuri Ndimele. Port Harcourt: Grand Orbit Communications and Emhai Press, 2005: pp. 297–304.

Jakobi, Angelika. *Kordofan Nubian: A Synchronic and Diachronic Study.* Unpublished manuscript, 2013.

Kröger, Oliver. ![“Typology Put to Practical Use: A Participatory Approach to Initial Grammar Research.”](bib:59d14e2a-d67c-47b2-a685-0abd714c217b) In *Proceedings of the 6th World Congress of African Linguistics, Cologne 17–21 August 2009,* edited by Matthias Brenzinger & Anne-Marie Fehn. Cologne: Rüdiger Köppe, 2012: pp. 155–168.

Laca, Brenda. ![“Progressives, Pluractionals and the Domains of Aspect.”](bib:53ad1b83-8641-4257-b6dc-f5fba10b4ed7) In *Domaines, Journées d’Études linguistiques.* Nantes: Université de Nantes, 2004: pp. 87–92.

Mufwene, Salikoko S. ![*Stativity and the Progressive.*](bib:6f7190ef-4900-4d62-b053-7cd686a11b49) Bloomington: Indiana University Linguistics Club, 1984.

Nevins, Andrew, David Pesetsky & Cilene Rodrigues. ![“Pirahã Exceptionality: A Reassessment.”](bib:a7981395-75e4-4b88-accd-f4c831e7a722) *Language* 85, no. 2 (2009): pp. 355–404.

Newman, Paul. ![“Pluractional Verbs: An Overview.”](bib:3c0968aa-be51-42ba-8614-cb90a585075e) In *Verbal Plurality and Distributivity,* edited by Patricia Cabredo Hofherr and Brenda Laca. Berlin: de Gruyter, 2012: pp. 185–209.

Norton, Russell. ![“Classifying the Non-Eastern-Sudanic Nuba Mountain Languages: Evidence from Pronoun Categories and Lexicostatistics.”](bib:17985725-27ae-41e1-b124-b0bf84df06c0) In *Nuba Mountain Language Studies: New Insights,* edited by Gertrud Schneider-Blum, Birgit Hellwig and Gerrit Dimmendaal. Cologne: Rüdiger Köppe, 2019: pp. 417–446.

Norton, Russell. ![“Number in Ama Verbs.”](bib:1892def2-7fbf-46ac-88ad-8dbb288c7e5a) *Occasional Papers in the Study of Sudanese Languages* 10 (2012): 75–94.

Norton, Russell. ![“The Ama Dual Suffix: An Internal Reconstruction.”](bib:fdf23efe-67f6-4e7b-9dfc-caa2a281a38c) In *Nilo-Saharan: Models and Descriptions,* edited by Angelika Mietzner & Anne Storch. Cologne: Rüdiger Köppe, 2015: pp. 113–122.

Rilly, Claude. ![*Le méroïtique et sa famille linguistique.*](bib:2ca95718-79e8-40cd-939a-5dd0e3bbd07e) Louvain: Peeters, 2010.

Rottland, Franz & Angelika Jakobi. ![“Loan Word Evidence from the Nuba Mountains: Kordofan Nubian and the Nyimang Group.”](bib:a1bae62f-a503-409c-b07d-1d2240ba0b05) *Afrikanistische Arbeitspapiere,* Sondernummer (1991): pp. 249–269.  

Smits, Heleen. ![*A Grammar of Lumun: A Kordofanian Language of Sudan, Vol. 2*](bib:11283ee4-f4b1-42bc-8d99-cea67650843a) Utrecht: LOT, 2017.

Stevenson, Roland C. ![“A Survey of the Phonetics and Grammatical Structures of the Nuba Mountain Languages, with Particular Reference to Otoro, Katcha and Nyimaŋ.”](bib:b8411bbc-e923-4876-bc7e-cbe3773812ed) *Afrika und Übersee* 40 (1956): pp. 73–84, 93–115.

Stevenson, Roland C. ![“A Survey of the Phonetics and Grammatical Structures of the Nuba Mountain Languages, with Particular Reference to Otoro, Katcha and Nyimaŋ.”](bib:859327ba-fe96-4c70-ae84-d441abadb867) *Afrika und Übersee* 41 (1957): pp. 27–65, 117–152, 171–196.

Stevenson, Roland. ![*Grammar of the Nyimang Language (Nuba Mountains).*](bib:5d589571-e485-4ed7-8c2e-01b2091c0349) Unpublished typescript, 1938.

Stevenson, Roland, Franz Rottland & Angelika Jakobi. ![“The Verb in Nyimang and Dinik.”](bib:976903a7-940f-4513-913f-aa8c060cfed1) *Afrikanistiche Arbeitspapiere* 32 (1992): pp. 5–64.

Stirtz, Timothy. ![*A Grammar of Gaahmg: A Nilo-Saharan Language of Sudan.*](bib:723db61e-8c66-4df7-8683-d4cdfa4598df) Utrecht: LOT, 2011.

Trudgill, Peter. *Sociolinguistic Typology: Social Determinants of Linguistic Complexity.* Oxford: Oxford University Press, 2011.

Voogt, Alex de. ![“A Sketch of Afitti Phonology.”](bib:7896653d-dbab-4dff-ae35-cc503c963e48) *Studies in African Linguistics* 38, no. 1 (2009): pp. 35–52.

Voogt, Alex de. ![“Dual Marking and Kinship Terms in Afitti.”](bib:1b02f408-997f-4a0b-adf3-37d6fbc6c96d) *Studies in Language* 35, no. 4 (2011): pp. 898–911.

Waag, Christine. ![*The Fur Verb and Its Context.*](bib:7ca3b062-3d4f-4553-85a1-79bc9927ba05) Cologne: Rüdiger Köppe, 2010.

Welmers, William. ![*African Language Structures.*](bib:ed6a1277-74e2-4f9e-8fd3-bfe86e635606) Berkeley: University of California Press, 1973.

Werner, Roland. ![*Tìdn-áal: A Study of Midob (Darfur Nubian).*](bib:56735ece-24da-4960-9101-ba484f7e57f7) Berlin: Dietrich Reimer, 1993.

Wolff, Ekkehard. ![“Patterns in Chadic (and Afroasiatic?) Verb Base Formations.”](bib:2f6fb9b6-658f-4292-b19b-06deebb73fc3) In *Papers in Chadic Linguistics,* edited by Paul Newman & Roxana Ma Newman. Leiden: Afrika-Studiecentrum, 1977: pp. 199–233.
