---
title: "Personal Markers and Verbal Number in Meroitic"
authors: ["clauderilly.md"]
abstract: "Thanks to the use of linguistic comparison and analyses of new inscriptions, Meroitic, the extinct language of the kingdom of Meroe, Sudan, has become increasingly well known. The present article deals with the identification of personal markers and verbal number. It shows how Meroitic, like many other languages, used a former demonstrative, *qo*, as a 3rd person independent pronoun. An in-depth analysis of the royal chronicles of the kings and princes of Meroe, compared with their Napatan counterparts written in Egyptian, further yields the [1sg]({sc}) dependent pronoun *e-* (later variant *ye-)*, which can be compared with [1sg]({sc}) found in related languages. A stela of Candace Amanishakheto found in Naga is the starting point for identifying the [2sg]({sc}) and [2pl]({sc}) independent pronouns *are* and *deb*. These two morphemes are linked with the most recent reconstructions of Proto-Nubian pronouns and confirm the narrow genetic relation between Nubian and Meroitic. Finally, the reassessment of the so-called “verbal dative” *‑xe/‑bxe* shows that this morpheme is simply a former verbal number marker with integrated case endings. This makes it a rare instance of transcategorisation in the cross-linguistic typology of verbal number."
keywords: ["Meroitic", "Meroe", "Kush", "Napata", "pronouns", "Egyptian", "decipherment", "verbal morphology", "pronominal morphology", "person", "comparative linguistics", "Old Nubian", "Nobiin", "Andaandi", "Ama", "Nara", "Taman", "Mattokki", "Karko"]
---

# Introduction {#intro}

Meroitic was the language spoken by the elite of the successive kingdoms of Ancient Sudan since at least the second millennium BCE.[^x0] Only from the third century BCE was it written with a script borrowed from Demotic. Later, a second script, using the same writing system but with hieroglyphic signs, was created for the sacred texts, particularly the wall inscriptions of the temples. The two scripts were deciphered in 1911.[^x1] Approximately 2,000 texts have been published so far. The main issue with regard to Meroitic inscriptions is the understanding of their content. The language disappeared in the early Middle Ages without descendants.

[^x0]: I am grateful to Abbie Hantgan-Sonko for checking the English text.
[^x1]: Griffith, *Karanòg.*

Internal methods have been used since 1911 to investigate the meaning of the texts, with remarkable success in the realm of the funerary inscriptions, which are many and highly stereotypical. In addition to these philological methods, a comparative approach has become possible now that the linguistic affiliation of Meroitic, a hotly debated issue for decades, was settled by the present author.[^x2] Meroitic belongs to the Northern East Sudanic (NES) language family, a branch of the Nilo-Saharan phylum. This family further includes:

[^x2]: Rilly, *Le méroïtique et sa famille linguistique.*

* Nubian–Nara
    *  Nubian, comprising Nobiin, Andaandi (Dongolawi), and Mattokki (Kenzi) spoken in Egypt in Sudan; Midob, (nearly) extinct Birgid, and the Kordofan Nubian (Ajang) languages in Sudan;
    * Nara, a small language spoken in Western Eritrea;
* Taman, comprising Tama and Mararit, in Darfur and Chad;
* Nyima, comprising Ama and Afitti in the Nuba Mountains in central Sudan.

Nubian and Nara are closest to Meroitic, yet unfortunately neither is close enough to allow for a quick and straightforward comparison of vocabulary and morphology. The split between the different branches of NES is supposed to have occurred in early third millennium BCE,[^x3] so that the chronological depth between the NES sister-languages is comparable to the time gap that separates Indo-European languages. For that reason, the comparative method must not be used alone, but in combination with internal methods.

[^x3]: Rilly, "The Wadi Howar Diaspora and Its Role in the Spread of East Sudanic Languages from the Fourth to the First Millenia BCE.”

The present paper deals with personal markers that can be identified in Meroitic inscriptions. This topic was not investigated until now, mainly because the Meroitic morphology was — and mostly remains — a *terra incognita.* The texts that have been found so far rarely offer a situation of uttering[^1] in which the subject can be easily identified. For example, the royal chronicles include reports of military campaigns where the verb *ked* “cut in pieces, kill” frequently occurs. However, in most cases, the verbal form is simply *ked,* without any pronoun or affix that could indicate which person is the subject.

[^1]: For the definitions of the key terms in the Theory of Enunciative Operations, see https://feglossary.sil.org/page/definitions-key-terms-theory-enunciative-operations?language=en.

In addition, when the situation of uttering is clear and verbal affixes are present, they often vary from one text to another and are distorted by assimilative phenomena, so that it is extremely difficult to isolate the personal markers and assign them an accurate value. For example, in funerary inscriptions, a textual category that makes up a third of the corpus, the situation of uttering is clear: These texts are prayers to the gods of the afterlife, uttered by a fictive enunciator who probably represents the funerary priest or the family of the deceased. He invokes the gods at the beginning and beseeches them in the last sentences to provide the deceased with water and food. The final verb is expectedly a optative or imperative form. It is not preceded by a 2nd person plural pronoun, but it includes a prefixed element *pso-, psi-* (or many other variants) and two suffixes. The first is *-x* or *-xe* (“verbal dative”) and is located immediately after the verbal stem. The second suffix is a compound *-kte, -kete, -ketese, -kese,* which can be reduced to *-te* as a result of assimilation with the first suffix. Until Fritz Hintze published his *Beiträge zur meroitischen Grammatik,* no scholar managed to find which of these complex affixes marked the person of the verb. Thanks to his morphological study of the verb in funerary benedictions,[^2] it is now clear that the final compound suffix is the marker of the 2nd person plural on the verb. Further analyses of old data can provide better insights into other personal markers, particularly the 3rd person singular and plural pronouns and possibly the first person singular subject marker, as can be seen in the following sections. Furthermore, some textual material recently discovered can be used to identify new personal markers, namely the 2nd person singular and plural possessive pronouns and the 2nd person singular subject pronoun.  

[^2]: Hintze, *Beiträge zur meroitischen Grammatik,* pp. 63–87. Nevertheless, he regards the 2nd person plural as an address to the visitors of the tomb. The interpretation of Inge Hofmann in her *Material für eine meroitische Grammatik,* p. 194, according to which the prayer is addressed to the gods of the afterlife, is much more convincing. See Rilly, *La langue du Royaume de Méroé,* pp. 163–166, for a detailed review of the numerous hypotheses that were advanced since the decipherment of the scripts.

# Preliminary Remarks about the Conventions of the Meroitic Writing System {#i}

Morphological issues in Meroitic cannot be addressed without taking into account the conventions of the writing system, because this is the only way we have to reconstruct the actual pronunciation of the words. The traditional transliteration of the texts, which follows the rules established by Griffith in 1911, is convenient because it is a direct reflection of the Meroitic signs (the default vowel /a/ is not written), but it is not a faithful rendering of the pronunciation. For instance, the Meroitic transcription of Greek Καῖσαρ (Latin *Caesar*) is written *kisri* but was pronounced /kaisari/. The Meroitic script is an alphasyllabary (**Fig. 1**), like Indic scripts or the Ethiopian abugida.[^3] There were actually two scripts, the cursive script and the hieroglyphic script, but they followed the same principles and differ only by the forms of the signs, like capital and lowercase letters in Latin script, with the difference that the two registers are never mixed in the same text.

[^3]:  This distinctive feature of the Meroitic writing-system was first evidenced in Hintze 1973. For an extensive study of the rules of Meroitic script, see Rilly, *La langue du Royaume de Méroé,* pp. 277–314.  

![The Meroitic alphasyllabary](../static/images/meroitic.jpg "The Meroitic alphasyllabary")

**~~Figure 1. The Meroitic alphasyllabary.~~**

The script includes nineteen syllabic signs. Fifteen of them have the value “consonant + /a/.” The default vowel /a/ can be modified by adding one of the three vocalic signs *e, i,* and *o.* Like in English, the sign e has three values: /e/, /ə/ (schwa), and zero. The zero value is used to write consonant clusters or final consonants, for instance *qore* "ruler,” pronounced /kʷur/. The sign *o* is used for /u/ and /o/. Four additional syllabic signs have a fixed vocalic value: three of them represent “consonant + *e*” (*ne, se, te,* with the three values of *e*), one represents “consonant + *o*” (*to*). For initial vowels, there is a single sign transliterated a, which represents /a/, /u/, and probably /o/ and /ə/. Initial /e/ and /i/ were written *e* and *i* until the first century CE. In later times, they were written *ye* and *yi* with a dummy *y,* which was not pronounced. Finally, the texts include a word-divider, made of two dots like our modern colon, which is used (more or less regularly) between words or more commonly between the different clauses of a sentence.

The sound values of the Meroitic signs are generally known,[^x4] but there remains a few unclear points. Until recently, it was supposed that the sign 𐦭, transliterated formerly *ḫ,* and *x* according to the revised conventions,[^4] had only the value [χ], a velar fricative like Egyptian *ḫ.* A second sign, which can replace *x* in several variant spellings, is *h,* formerly *ẖ*. I suggested that *h* was a labialized version of *x,* in IPA [χʷ], because it mainly occurs before or after labiovelar vowels [o] or [u]. These two values [χ] and [χʷ] are evidenced by the use of *x* and *h* in Meroitic transcriptions of Egyptian words. The same distribution can be observed between *k* and *q,* the latter being a labialized velar consonant [kʷ]. However, in the Old Nubian alphabet, the Meroitic sign 𐦭 *x* was borrowed, not for the velar fricative consonant [χ], for which the Coptic sign ϩ was used, but for the velar nasal consonant /ŋ/, written ⳟ. Furthermore, in several Egyptian transcriptions of Meroitic royal names that include *x* or *h,* the scribes used a digraph *nḫ.*[^5] My impression is therefore that the signs *x* and *h* had a double set of values: [χ] and [χʷ] in loanwords from Egyptian and [ŋ], and [ŋʷ] in native words. This assumption is supported by strong arguments but still needs to be checked word by word.   

[^x4]: Rilly, *La langue du Royaume de Méroé,* pp. 359–407.
[^4]: See Rilly \& Francigny, “Excavations of the French Archaeological Mission in Sedeinga, Campaign 2011,” p. 67, no. 10.
[^5]: For further details, see Rilly, “Upon Hintze's Shoulders,” pp. 28–29.

A last peculiarity, pertaining rather to phonetic changes than to spelling conventions, needs to be mentioned here because it will be found in some of the following quotations from Meroitic texts. From the first century CE onwards, the sequence /s/ + /l/ (written *se* + *l*), which was frequent in Meroitic due to the use of the article *-l* at the end of noun phrases, merged into /t/. For example, the sentence written *kdise-l-o* “she is the daughter” became *kdit-o*. This phonetic development is known as “Griffith’s law.”[^6]

[^6]:  Formerly known as “Hestermann’s law,” see Rilly, *La langue du Royaume de Méroé,* pp. 415–420.

# The Third Person Markers {#ii}

Among the possible markers of the third person, only pronouns are known so far, namely *qo/qe* and variants for singular and *qoleb* for plural. No verbal ending that could be connected with the third person, such as Latin *-t/-nt* or Egyptian *=f/=sn,* has been spotted in the texts. The case of the “verbal dative” will be later investigated, but this morpheme is probably to be classified as a clitic pronoun.

In the paradigm of personal pronouns, the 3rd person has a special place. Whereas the 1st and 2nd persons refer to the protagonists of the uttering situation (see n. 6), the 3rd person refers to people and things that are outside this situation. According to the relevant categorization of Arab grammarians, the 3rd person is “the absentee.”[^7] From this perspective, 3rd person pronouns are close to demonstratives. This is particularly obvious when it comes to morphology. In many languages, these pronouns are derived from demonstratives. In Romance languages for example, they stem from the Latin distal demonstrative *ille* “that,” for instance French *il* “he,” Spanish *él,* Romanian *el.* Some languages even use the same word for the demonstrative and the 3rd person pronoun.[^8] In Latin, the proximal demonstrative *is, ea, id* “this” was used as a 3rd person pronoun. In Turkish, a language that displays a full range of typological similarities with Meroitic,[^9] the same demonstrative *o* is used as a demonstrative adjective, a demonstrative pronoun and a 3rd person pronoun.[^y3] This seems also to be the case in Meroitic, which has apparently the same word, *qo/qe,* for “this” (adjective), “this” (pronoun), and “he,” “she,” “it.”[^ex2]

[^y3]: Creissels, *Syntaxe générale 1,* 2006: p. 91.
[^7]: In Arabic *ghâ‘ib,* cf. Cotte, *Langage et linéarité,* p. 130.
[^8]: In addition to Latin, this feature can be found in Korean, Hindi, Panjabi, Marathi, Mongolian, etc. See Jacquesson, *Les personnes,* pp. 103–105.
[^9]: These similarities are due to common typological features and do not originate from a common genealogical origin. Turkish is, like Meroitic or Nubian, an agglutinative language, with no grammatical gender and an SOV word-order, cf. Rilly, *La langue du Royaume de Méroé,* pp. 497–502.
[^ex2]: In (2), Malutuna is traditionally transcribed “Maloton.” This viceroy of Lower Nubia (*peseto*), living at the end of the 3rd century CE, is famous for his beautiful *ba* statue kept in the Nubian Museum in Aswan.

## Demonstrative Pronoun or Independent Third Person Pronoun Object? {#ii1}

{{< gloss "(1)" >}}
{r} **Meroitic**
{g} *Arilnemkse*,Arilanemakas|***q(o)***-*o*,this-[cop]({sc})|
{r} “This is Arilanemakas.” (REM 0239A, epitaph)
{{< /gloss >}}

{{< gloss "(2)" >}}
{g} *Mloton*,Malutuna|***q(o)***-*o-wi :*,this-[cop-emp]({sc})|
{r} “This is Malutuna.” (REM 0277, epitaph)
{{< /gloss >}}

{{< gloss "(3)" >}}
{g} ***qo*** *:*,this|*Atqo*,Ataqu|***q(o)***-*o-wi :*,this-[cop-emp]({sc})|
{r} “This (one), this is Ataqu.” (REM 1057, epitaph)
{{< /gloss >}}

The pronoun *qo* was among the first elements that Griffith singled out in the funerary inscriptions after his decipherment of the script.[^x5] The word occurred in final position in the “nomination” of the deceased, either bare (1) or followed by an optional particle *-wi* “for emphasis” (2).[^11] Quite often, another *qo* preceded the name of the deceased (3). Griffith suggested that this first *qo* was an epithet meaning “honorable” or “noble” and the final *qo* was a grammatical tool “to introduce the name of the deceased.” In his *Beiträge zur meroitischen Grammatik,* Hintze was the first to regard *qo* as a demonstrative pronoun.[^x505] According to him, the original form of this word was *qe* and the predicative compound *qo(wi)* was composed of *qe* + copula *-o* ± particle *-wi.* Actually, *qe* is a variant spelling of *qo* and the two forms were pronounced /ku/,[^12] so that *qo(wi)* can be analysed also as *qo* + copula *-o* ± particle *-wi* with a merger of the two consecutive *o*’s. The additional *qo* at the beginning (3), found in 10% of the epitaphs, is used as a topic “this one, this is….”[^13] It emphasizes the deixis that connects the inscription and the deceased, since these texts were inscribed on offering-tables or stelae that were placed at the entrance and inside the funerary chapels respectively.

[^x5]: Griffith, *Karanòg,* p. 120.
[^x505]: Hintze, *Beiträge zur meroitischen Grammatik,* pp. 53–56.
[^11]: The function of this particle is not yet identified (Rilly, *Le méroïtique et sa famille linguistique,* pp. 386–387).
[^12]: The frequent variants *qe/qo* here and in other words (for example *Aqedise/Aqodise* “Moon-god” in the texts from the Lion temple in Naga) is best explained by the labialized articulation /kʷ/ of the sign *q*: see Rilly, *La langue du Royaume de Méroé,* pp. 374–379.
[^13]: See Rilly, *La langue du Royaume de Méroé,* p. 547. The literal translation “this one, this is...,” which is used above, is somewhat unnatural in English. In spoken French, the topicalization of the subject is overwhelmingly frequent and sentences such as *celui-ci, c’est…* or even *ça, c’est…,* literally “this, this is” are very common.

{{< gloss "(4)" >}}
{g} *kdi*,woman|***qo***:,this|*Mitslbe*,Mitasalabe|*q(o)-o-wi :*,this-[cop-emp]({sc})|
{r} “This woman, this is Mitasalabe.” (REM 0087, epitaph)
{{< /gloss >}}

{{< gloss "(5)" >}}
{g} *wle*,dog|***qo***,this|*p-xn*,[caus]({sc})-yield(?)|*tlt*,talent|*3*,3|*Netror-se-l-o*,Natarura-[gen-det-cop]({sc})|
{r} “May this dog yield(?) three talents, it is Natarura’s.” (REM 1165, beside graffito of a greyhound)
{{< /gloss >}}

Another function of *qo,* which confirms the demonstrative status of this word, is adjectival. Like in English or German, the same word is used for the adjective and the pronoun. In (4), also drawn from a funerary text, the topic found in (3) is extended: *qo* “this one” becomes *kdi qo* “this woman,” “this lady.” This interpretation, which I first advanced with some reservations,[^x6] was since then confirmed: (5), (6), and (7) are captions of pictures, respectively the graffito of a dog hunting a hare in the Great Enclosure of Musawwarat, the drawing of a gazelle on a wooden board found in the temple of Amun in Qasr Ibrim and a pair of feet engraved in the temple of Isis in Philae. The deictic nature of *qo* is perfectly obvious here. Its use as a 3rd person pronoun in Meroitic is therefore an extension of his function, because the other way round, namely that a personal pronoun could become a demonstrative, is cross-linguistically highly improbable.    

[^x6]: Rilly, *La langue du Royaume de Méroé,* p. 98.

{{< gloss "(6)" >}}
{g} *abese*,gazelle|***qo-li***,this-[det]({sc})|
{r} “This gazelle…” (REM 1198 and 1199) The rest of the sentence cannot yet be translated.
{{< /gloss >}}

{{< gloss "(7)" >}}
{g} *ste*,foot|***qo-leb***,this-[det.pl]({sc})|*Addo*[.]-*se*,Adadu[.]-[gen]({sc})|
{r} “These feet (are) Adadu[.]’s.” (REM 0113)
{{< /gloss >}}

Examples (6) and (7) show that the demonstrative adjective *qo* is compatible with the use of the determiner (article), singular *-l(i),* plural *-leb,* unlike English or French, but like Greek[^15] or Hungarian. It is, however, absent in some instances, such as (5) above.

[^15]: Ancient Greek οὖτος ὁ ἀνήρ “this man,” literally “this the man.”

In these examples, the determiner is apparently attached, not to the demonstrative, but to the noun phrase as a whole, as is normal in Meroitic.[^x7] However, a plural form *qoleb*[^16] can be found independently as a pronominal object, but, from the instances found so far, it is difficult to decide if it is a demonstrative or a personal pronoun. This form is particularly attested in royal chronicles.[^ex8]

[^x7]: Rilly, *La langue du Royaume de Méroé,* p. 511.
[^16]:  From the textual material so far available, the adjunction of the plural determiner *-leb* seems to be the only way to build the plural of nouns. For an alternative plural *qebe-,* see [3.2](#ii2).
[^ex8]: In (8), the titles *ssmrte* and *wtotrse* cannot yet be translated. The former is probably an early form of the title *ssimete* frequently attested in later texts and which is connected to the cult of the gods in several instances. The second one is a hapax legomenon. It is presumably a compound word (*wto-tr-se*) including possibly an indirect genitive with postposition *-se*.

{{< gloss "(8)" >}}
{g} *Atnene :*,Atanene|*ssmrte-l :*,(title)-[det]({sc})|*Imlotror :*,Imalutarura|*wtotrse-l :*,(title)-[det]({sc})|***qoleb*** *:*,[3pl]({sc})|*Amnp :*,(to) Amanap|*i-de-bx :*,[1sg.s]({sc})-give(?)-[vnm.pl]({sc})|
{r} “Atanene, the *ssmrte* (and) Imalutarura, the *wtotrse*, I gave(?) them to Amanap.” (REM 1044/25–26)
{{< /gloss >}}

Example (8) is quoted from the great stela of king Taneyidamani kept in Boston. Engraved around 150 BCE, it is the earliest royal chronicle written in Meroitic. The excerpt deals with the assignment to the temple of Amanap (Amun of Napata) of two officials, Atanene and Imalutarura. Their names and titles are enumerated and followed by *qoleb.* The context is utterly different from (7), where the deixis is obvious, since it is engraved beside the image of two feet. As in (3) and (4), we are doubtlessly dealing with a topicalized construction. The topic is formed by the names and the description of the two officials, whereas *qoleb* is an anaphoric pronoun that refers to these two persons, but operates as the actual object of the verb.[^18] In anaphoras referring to animate antecedents as shown in (8), most languages where demonstratives and 3rd person pronouns are clearly distinct, a personal pronoun is used. In Meroitic, it seems that *qoleb,* at least when it is the object of the verb, can function as a personal pronoun. Unfortunately, there are no similar instances, namely in sentences with verbs, with the singular *qo,* but the non-verbal sentence in (3) suggests that it would function similarly. In the latter example, the first *qo* plays the role of a deictic whereas the second *qo* assumes the function of an anaphoric.     

[^18]: The final element *-bx* in (8), which could be considered as the object of the verb, is discussed in [3.3](#ii3).

## The Third Person Possessive Pronoun {#ii2}

Whereas Hintze regarded *qe/qo* as a demonstrative, Hofmann held it as a personal pronoun because it is the basis of the 3rd person possessive marker, *qese* and variants.[^x8] It is found mainly after the kinship terms, as in (9) below, drawn from a funerary stela where two brothers are commemorated.[^ex9]

[^x8]: Hofmann, *Material für eine meroitische Grammatik,* pp. 334–338.
[^ex9]: In (9), the kinship term *yetmde* is applied to younger members of the same maternal line (Rilly, *La langue du Royaume de Méroé,* pp. 526–527). It mostly designates “nephews” and “nieces,” who are referring to a prestigious uncle in the descriptive part of their epitaph, but in rare cases such as this one, it can be applied to a younger brother.

{{< gloss "(9)" >}}
{g} *Qoreqore-l-o-wi* [:,Qurqurla-[cop-emp]({sc})|*y*]*etmde*,relative|***qese*** *:*,[3sg.gen]({sc})|*Qoretkr*,Qurtakara|*q(o)-o-wi :*,this-[cop-emp]({sc})|
{r} “(This) is Qurqurla; this is his elder Qurtakara.” (REM 0273/2–4, funerary stela)
{{< /gloss >}}

The possessive of the 3rd person singular includes the pronoun *qo/qe,* followed by the genitival postposition *-se* and means literally “of him/her.”[^x9] Once again, it can be compared with Latin demonstrative *is, ea, id,* whose genitive *eius* is also used as a 3rd person singular possessive. Three variants are known: *qose,* very rare, *eqese* in REM 1003, and *aqese,* much more common.[^20] Unexpectedly, the 3rd person plural possessive is not *\*qolebse,* but *qebese,* as can be seen in (10), drawn from an epitaph from Gebel Adda that was written for a deceased whose relatives were administrators and scribes from the temple of Isis. Like (3) and (4) above, the sentence includes a topicalized constituent. The genitival phrase (i.e., the officials of the temple) is the topic and is referred to in the predication by the anaphoric possessive *qebese* (their nephew).

[^x9]: Rilly, *La langue du Royaume de Méroé,* pp. 550–551.
[^20]:  The initial *a* in *aqese* and in the variants of the 3rd plural possessive, *aqebese* and *aqobese* are unexplained. It is possible that this *a* is etymological and that, in this case, the forms *qese* and *qebese* result from apheresis (a widespread development in Meroitic, see Rilly, *La langue du Royaume de Méroé,* pp. 290–291). In some instances, however, a non-etymological *a* is added at the beginning of a word for unknown reasons, for example *Ams-i* “oh (sun-god) Masha” in REM 0091C instead of expected *Ms-i.*    

{{< gloss "(10)" >}}
{g} *perite :*,agent|*Wos-se-leb :*,Isis-[gen-det.pl]({sc})|*qorene*,royal scribe|*Wos-se-leb :*,Isis-[gen-det.pl]({sc})|*yetmde*,nephew|***qebese***-*l-o-wi :*,[3pl.gen-det-cop-emp]({sc})|
{r} “He was the nephew of agents of Isis and royal scribes (?) of Isis.” (GA. 04, epitaph)
{{< /gloss >}}

The possessive *qebe-se* includes *qebe-,* a plural form of *qo* that is more conservative than *qoleb,* but is, unlike the latter, never attested in isolation. It includes the plural suffix *-b* that can also be found on the plural determiner:[^x10]

[^x10]: Rilly, *Le méroïtique et sa famille linguistique,* p. 389.

* Determiner:  singular *-l* → plural *-le****b***  
* Pronoun: singular *qo-/qe-* → plural *qe****b****e-*

*Qebese* has several variants, *aqebese,* *aqobese* (see n. 32) *eqebese,* and especially *bese,* which is frequent. This last form, in all likelihood, is not an abbreviated variant but is based on a still earlier form of the 3rd person pronoun, *-b,* which will be considered below [3.3.6](#ii36).

## The “Verbal Dative” as Possible Enclitic Pronoun or Verbal Number Marker {#ii3}

The funerary inscriptions from the Karanog and Shablul cemeteries were the first texts published by Griffith, after his decipherment of the script. He was able to get a rough understanding of their content, but could not yet deliver a detailed analysis of the verbal compounds that end the benedictions. The first two benediction formulae, commonly named A and B, are prayers to Isis and Osiris, asking them to provide the deceased with water and bread respectively, as can be seen in (11)–(14).[^21]

[^21]:  A third formula for “a good meal” is oftentimes added. A dozen of additional formulae are known, but they are less frequent. See Rilly, *La langue du Royaume de Méroé,* pp. 163–183; Rilly, *Le méroïtique et sa famille linguistique,* pp. 68–74.

{{< gloss "(11)" >}}
{r} Formula A, singular beneficiary
{g} *ato*,water|*mhe*,plentiful|*pso-he-(xe)-k(e)te*,[caus]({sc})-drink-[vnm.sg-opt.2pl]({sc})|
{r} “May you cause him/her to drink plentiful water!”
{{< /gloss >}}

{{< gloss "(12)" >}}
{r} Formula A, plural beneficiary
{g} *ato*,water|*mhe*,plentiful|*pso-he-bxe-k(e)te*,[caus]({sc})-drink-[vnm.pl-opt.2pl]({sc})|
{r} “May you cause them to drink plentiful water!”
{{< /gloss >}}

{{< gloss "(13)" >}}
{r} Formula B, singular beneficiary
{g} *at*,bread|*mhe*,plentiful|*psi-xr-(xe)-k(e)te*,[caus]({sc})-eat-[vnm.sg-opt.2pl]({sc})|
{r} “May you cause him/her to eat plentiful bread!”
{{< /gloss >}}

{{< gloss "(14)" >}}
{r} Formula B, plural beneficiary
{g} *at*,bread|*mhe*,plentiful|*psi-xr-bxe-k(e)te*,[caus]({sc})-eat-[vnm.pl-opt.2pl]({sc})|
{r} “May you cause them to eat plentiful bread!”
{{< /gloss >}}

Meroitic is an agglutinative language, but it has a strong propensity to assimilative processes that blur the boundaries between successive morphemes.[^22] However, Griffith managed to identify the element *-bx* or *-bxe* as a “plural ending in the funerary formulae,” which appeared each time several individuals were commemorated in the same epitaph.[^23] In his *Beiträge,* Hintze was the first to suggest a plausible segmentation of these verbal compounds.[^24] He showed that *-bxe* (which, meanwhile, had been termed “dative infix”) had a singular counterpart *-x* or *-xe*[^25] that was theoretically present in the verbal compound, but concealed by a nearly systematic assimilation to the following suffix.[^26] Only in the archaic versions of formulae A and B (15)–(16) was this singular “infix” visible.

[^22]: See Comrie, *Language Universals and Linguistic Typology,* pp. 43–19 for an updated interpretation of this old classification of languages.
[^23]:  Griffith, *Karanòg,* p. 14 and n. 1, pp. 25–26, 45.
[^24]:  Hintze, *Beiträge zur meroitischen Grammatik,* pp. 65–66, 73–74.
[^25]:  The form *-x* (= /xa/ or /ŋa/) and *-bx* (= /baxa/ or /baŋa/) are early. They later became *-xe* (= /x/ or /ŋ/) and *-bxe* (= /bax/ or /baŋ/). It is noted that the sign transliterated *e* can have a zero-vowel value (see [3](#i) for the principles of the Meroitic script).
[^26]:  The suffixes *-xe* and *-bxe* end with the consonant /x/, which assimilated to the subsequent suffix *-ke.* However, similar assimilation is rare with the plural suffix *-bxe.* In early texts, the suffixes were *-x* and *-bx,* with default vowel /a/. This final vowel explains why there was no assimilation with the following suffix.

{{< gloss "(15)" >}}
{r} Formula A (archaic)
{g} *ato*,water|*mlo*,good|*el-x-te*,give-[vnm.sg-opt.2sg]({sc})|
{r} “May you give him/her plentiful water!” (REM 0427)
{{< /gloss >}}

{{< gloss "(16)" >}}
{r} Formula B (archaic)
{g} *at*,bread|*mlo*,good|*el-x-te*,give-[vnm.sg-opt.2sg]({sc})|
{r} “May you give him/her plentiful bread!” (REM 0427)
{{< /gloss >}}

The same wording occurs in the prayers to the gods that were engraved near their figures in votive stelae (17) or in Meroitic temples (18). In the latter example, cited from the Lion temple in Naga, the beneficiaries are the king, his mother, and the prince.

{{< gloss "(17)" >}}
{g} *A*[*pe*]*dem*[*k-i*],Apedemak-[voc]({sc})|*Tneyidmni*,Taneyidamani|*pwrite*,life|*el-x-te*,give-[vnm.sg-opt]({sc})|
{r} “O Apedemak! May you give life to Taneyidamani!” (REM 0405)
{{< /gloss >}}

{{< gloss "(18)" >}}
{g}*Apedemk-i*,Apedemak-[voc]({sc})|*pwrite :*,life|*l-bx-te*,give-[vnm.pl-opt]({sc})|
{r} “O Apedemak! May you give life to them!” (REM 0018)
{{< /gloss >}}

### Earlier Hypotheses {#ii31}

In an early analysis of these sentences,[^x11] I interpreted this “dative infix” as an applicative suffix, with reference to Kanuri, a Saharan language. Applicatives are used to encode a beneficiary of the action in the verb, instead of adding an adposition or a case ending to the noun. They are quite common among African languages and are for example found in Nubian.[^27] However, this can hardly apply to the Meroitic construction. The applicative is a voice, such as passive and causative, and the affixes it uses cannot convey the notions of singular or plural. Example (19) from a Bantu language, Tswana, shows that the same applicative suffix *-el* is used regardless of the beneficiaries’ number.[^28]

[^x11]: Rilly, *La langue du Royaume de Méroé,* pp. 553–554.
[^27]:  Jakobi, “Verbal Number and Transitivity in Karko,” pp. 121–122 and n. 3. Nile Nubian (Nobiin and Mattokki/Andaandi) uses applicative suffixes that are nothing but a grammaticalized forms of the two verbs “to give,” *deen* and *tir.* In other languages, they may result from the incorporation of adpositions in the verbal compound, as is the case in Amharic (Creissels, *Syntaxe générale 2,* p. 39).
[^28]:  Adapted from Creissels, *Syntaxe générale 2,* pp. 74, 76. In (19c), the added gloss “3:1.s” means “subject 3rd person, Bantu nominal class 1.”

{{< gloss "(19a)" >}}
{r} **Tswana**
{g} *ke*,[1sg.s]({sc})|*rek-a*,buy-[fin]({sc})|*ditlhako*,shoes|
{r} “I am buying shoes.”
{{< /gloss >}}

{{< gloss "(19b)" >}}
{g} *ke*,[1sg.s]({sc})|*rek-el-a*,buy-[appl-fin]({sc})|*bana*,children|*ditlhako*,shoes|
{r} “I am buying shoes.”
{{< /gloss >}}

{{< gloss "(19c)" >}}
{g} *Lorato*,Lorato|*o*,[3:1.s]({sc})|*tlaa*,[fut]({sc})|*kwal-el-a*,write-[appl-fin]({sc})|*Kitso*,Kitso|*lokwalo*,letter|
{r} “Lorato writes a letter to Kitso.”
{{< /gloss >}}

In (19b), the beneficiary is plural (*bana* “children,” [sg]({sc}) *ngwana*), whereas in (19c), *lokwalo* “letter” is singular. In both cases, the applicative suffix is *-el.* The Meroitic suffixes *-x* and *-bx,* by contrast, agree in number with the beneficiary.

In addition, this morpheme was first identified as a beneficiary marker from the instances found in the benedictions of the epitaphs, hence its name “dative infix.” However, in royal chronicles and biographical passages of several funerary texts — which have been little studied to date — the suffix obviously refers to a direct object, as can be seen in (20) drawn from the funerary stela of viceroy of Nubia Abratoye.[^x12]

[^x12]: Carrier, "La stèle méroïtique d’Abratoye.”

{{< gloss "(20)" >}}
{r} **Meroitic**
{g} *kdi*,woman|*mdxe*,virgin|*35*,35|*anese*,donkey|*25 :*,25|*kelw :*,also|∅-*arohe-bx*,[1sg.s]({sc})-take.control-[vnm.pl]({sc})|
{r} “I took control of 35 virgins and 25 donkeys.” (REM 1333/16)
{{< /gloss >}}

For these two reasons, in a later analysis,[^13] I considered *-x(e)* and *-bx(e)* to be object personal pronouns that had been incorporated into the verbal compound as clitics. A similar enclisis can be found, for instance, in the imperative forms of Romance languages,[^x14] especially in Spanish: *dámelo* “give it to me,” *presentémonos* “let us introduce ourselves.”

[^x13]: Rilly, *Le méroïtique et sa famille linguistique,* pp. 395–398.
[^x14]: Jacquesson, *Les personnes,* pp. 297–298.

This analysis, however, does not account for the location of these so-called clitic personal markers inside the verbal compound. In the examples from Spanish above, they occur in final position, as is expected for external elements that were later added to a fully inflected form. In Meroitic, as can be seen in (11)–(18), they are directly attached to the verbal stem and followed by the subject person marker and tense–aspect–mood (TAM) endings. For that reason it was termed “infix” and not “suffix.”

### Verbal Number Markers in Northern East Sudanic {#ii32}

The unexpected location of *-x(e)* and *-bx(e)* in the verbal complex can be compared with that of the verbal number marker in two groups of the NES linguistic family, Nyima and Nubian. In these languages, the plurality of the subject in intransitive constructions and of the object in transitive constructions (“ergative pattern”) is realized by the same verbal suffix which is added directly to the verbal stem, before the TAM suffixes. The clearest instances of this construction are found in the Nyima language Ama and involve an ergative-pattern verbal plural marker[^29] *-(ì)d̪ì* as shown in (21)–(22).

[^29]:  An in-depth analysis of this construction in Ama can be found in Norton, "Number in Ama Verbs.” This author prefers to speak of “distributive” rather than “plural” (ibid., p. 78). His stance is supported by a series of five examples, which can be nonetheless analysed as a particular case of plural construction. In her study of verbal plural in Nubian, Jakobi states that “verbal number — realized by distinct singular and plural verb stems — can have both aspectual and morphosyntactic functions. On the one hand these stems may encode habitual, progressive, iterative, repetitive, distributive, or even single events, on the other hand these stems may encode the participants affected by these events” (Jakobi, “Verbal Number and Transitivity in Karko,” p. 117).

{{< gloss "(21a)" >}}
{r} **Ama**
{g} *kùd̪ū*,goat|*t̪èbīò*,black|*bà*,[asp]({sc})|*nɛ̀*,be.[impfv]({sc})|
{r} “The goat is black.”
{{< /gloss >}}

{{< gloss "(21b)" >}}
{g} *kùd̪ū*,goat|*t̪èbīò*,black|*bà*,[asp]({sc})|*nɛ̀-d̪ì*,be.[ipfv-vnm]({sc})|
{r} “The goats are black.”
{{< /gloss >}}

{{< gloss "(22a)" >}}
{g} *á*,[1sg]({sc})|*bá*,[asp]({sc})|*dámì-ɔ̄*,egg-[acc]({sc})|*tàm*,eat.[ipfv]({sc})|
{r} “I am eating an egg.”
{{< /gloss >}}

{{< gloss "(22b)" >}}
{g} *á*,[1sg]({sc})|*bá*,[asp]({sc})|*dámì-ɔ̄*,egg-[acc]({sc})|*tàm-īd̪ì*,eat.[ipfv-vnm]({sc})|
{r} “I am eating an egg.”
{{< /gloss >}}

In Old Nubian and Nobiin, this suffix is *-(i)j.* A related marker *-j-* is found in Midob.[^y2] In Kordofan Nubian, a similar suffix *-c* is attested along with others suffixes, such as *-Vr,* which is much more frequent. Recent publications showed that the Nubian suffixes function according to the same ergative pattern as the Ama suffix.[^31] Example (23) illustrates the use of the suffix to mark subject plurality with intransitive verbs, whereas examples (24)–(25) show the suffix marking object plurality with transitive verbs.[^ex23]

[^y2]: Werner, *Tìdn-áal,* p. 49.
[^30]:  *-V* stands here for “vowel.” See Jakobi, “Verbal Number and Transitivity in Karko,” pp. 117–122 for Old Nubian, Nobiin, and Mattokki–Andaandi. In the latter group, *-(i)j* is only a pluractional marker whereas the plural marker (only for objects) is *-ir.* For *-c* as a verbal number marker in Tagle, a Kordofan Nubian language, see Jakobi, Ibrahim \& Ibrahim Gulfan, “Verbal Number and Grammatical Relations in Tagle,” exx. 5–6, 19, 20.   
[^31]:  The suffix *-(i)j* is mentioned in Van Gerven Oei, *A Reference Grammar of Old Nubian,* §13.1 who calls it "pluractional" and in Werner 1989: 173–175, who speaks of “plural object extension” but not of plural subject marking. Recent and more explicit studies are Khalil, “The Verbal Plural Marker in Nobiin”; Jakobi, “Verbal Number and Transitivity in Karko”; and Jakobi et al., forthcoming.  
[^ex23]: Examples from Khalil, “The Verbal Plural Marker in Nobiin,” p. 65, ex. 9; p. 64, exx. 3, 4.

{{< gloss "(23)" >}}
{r} **Nobiin**
{g} *ter*,[3pl]({sc})|*balee-la*,wedding-[loc]({sc})|*kar-j-is-an* [kaccisan],came-[vnm-prt1-3pl]({sc})|
{r} “They came to the wedding.”
{{< /gloss >}}

{{< gloss "(24)" >}}
{g} *ay*,[1sg]({sc})|*tii-ga*,cow-[acc]({sc})|*aag*,[prog]({sc})|*jurr-il*,milk-[prs.1sg]({sc})|
{r} “I am milking the cow.”
{{< /gloss >}}

{{< gloss "(25)" >}}
{g} *ay*,[1sg]({sc})|*tii-guu-ga*,cow-[pl-acc]({sc})|*aag*,[prog]({sc})|*jurr-ij-il*,milk-[vnm-prs.1sg]({sc})|
{r} “I am milking the cows.”
{{< /gloss >}}

It is noteworthy that, unlike in the Ama examples above, the plural marking operated by the suffix *-(i)j* is redundant, since plurality is already marked by the subject pronoun *ter* “they” in (23) and the plural nominal suffix *-guu* in (25). In Ama, apart from rare instances of replacive patterns such as *wīd̪ɛ́ŋ* “child”/*dŕīŋ* “children,” and a plural suffix *-gí/-ŋì* which can be attached to kinship terms, plurality in unmarked in nouns. This makes it necessary, either to mark it by determiners (“several,” “many,” etc.) or to encode it in the verb by a specific marker, as showed in (20b) and (21b) above.

Considering that the nominal plural suffixes that can be found in the NES languages are so diverse that no protoform can be reconstructed, it is plausible that Proto-NES had no plural nominal markers, but only a few replacive patterns and collective nouns with singulatives forms marked by a suffix *\*-tV*.[^x15] It was therefore necessary to encode the plurals of the participants in the verbal compound. Proto-Nubian seems to have been in this regard close to its ancestor Proto-NES.[^x16] Later on, for unknown reasons — but areal influence probably played a major role in it — each Nubian group worked out its own plural markers for all the nouns. This novelty of course competed with the earlier plural marking by verbal suffixes. However, both of them survived to this day, but they often follow economy principles. Khalil notes that “the *j*-suffix appears sporadically in the intransitive clause” and that “In the transitive clause […], when the object noun phrase is modified by a numeral or a quantifier such as *mallee* [many] or *minkellee* [how many], the plural marker on the object noun phrase becomes optional and subsequently the suffixation of *-j* becomes optional, too.”[^x17]

[^x15]: Rilly, *Le méroïtique et sa famille linguistique,* p. 350.
[^x16]: Ibid., p. 272.
[^x17]: Khalil, “The Verbal Plural Marker in Nobiin,” pp. 64–65.

A third use of verbal plural markers in NES languages is to encode in ditransitive verbs the plurality of the indirect object, i.e., the beneficiary or recipient of the action. In this construction, the plural verbal suffix refers to the indirect object and not to the object in Old Nubian[^x50] and Nobiin[^32] and probably in Ama. For the latter language, I have unfortunately no clear example of this point in my limited fieldwork data, but an example provided by Norton illustrates this point for dual, which operates exactly like plural, but with the suffix *-ɛ̄n/-ēn* (the macron stands for mid tone).[^x51]

[^x50]: Van Gerven Oei, *A Reference Grammar of Old Nubian,* §13.1.3.
[^32]:  In Kordofan Nubian language Karko, unlike in Nobiin, the verbal number marker refers to the direct object even in ditransitive construction (Jakobi, “Verbal Number and Transitivity in Karko,” pp. 164–165). The example she gives (“Dry the pots for the woman”), compared with the Nobiin example (28) above, shows that at least in this language, the participant hierarchy is not connected with the degree of animacy of the two objects, direct and indirect. See, however, n. 59 below.
[^x51]: Example from Norton, "Number in Ama Verbs,” p. 86, ex. 35.

{{< gloss "(26)" >}}
{r} **Ama**
{g} *àɪ̀*,[1sg]({sc})|*bā*,[ver]({sc})|*əm̄ōr-ì*,friend-[dat]({sc})|*āmɪɛ̄r̄*,pen|*t̪ɛɡ̄-ɛn̄ɪ̀*,give-[du]({sc})|
{r} “I gave a pen to two friends.”
{{< /gloss >}}

Here, the verbal number marker refers to the beneficiary (“friend”) and not to the object (“pen”), as it does in monotransitive constructions, although this beneficiary is already marked as a dative by the case ending *-ì.* The same feature is observed in Nobiin as shown in (27) and (28).[^ex27]

[^ex27]: Examples from Khalil, “The Verbal Plural Marker in Nobiin,” p. 64, exx. 6, 7.

{{< gloss "(27)" >}}
{r} **Nobiin**
{g} *ay*,[1sg]({sc})|*torbar-ka*,farmer-[acc]({sc})|*aŋŋaree-nci-ga*,bed-[pl-acc]({sc})|*kaay-a-tis*,make-*a*-[appl.prt1.1sg]({sc})|
{r} “I made the farmers a bed.”
{{< /gloss >}}

{{< gloss "(28)" >}}
{g} *ay*,[1sg]({sc})|*torbar-ii-ga*,farmer-[pl-acc]({sc})|*aŋŋaree-g*,bed-[acc]({sc})|*kaay-a-tic-c-is*,make-*a*-[appl-vnm-prt1.1sg]({sc})|
{r} “I made the farmers a bed.”
{{< /gloss >}}

### Plural Object Marking in Meroitic {#ii33}

The verbal number marking in these languages follows a syntactic hierarchy: it refers to the subject if there is no object, to the object if there is no beneficiary and to the beneficiary if there is one. This brings us back to Meroitic, in which the so-called “verbal dative” again has close parallels with the Ama and Nobiin verbal number marker. Unfortunately, no clear instance of *-x(e)/-bx(e)* can be found with intransitive verbs, mainly because none has been so far translated with certainty. Unlike Ama (21a–b), Meroitic does not use a real verb “to be,” but a copula which is inflected for plural with a different suffix. Nonetheless, transitive and ditransitive constructions display the same hierarchy for the use of the verbal plural suffix as Ama and Nobiin.  

Examples (29) and (30) are prayers to Amun, said by a fictive enunciator, in favour of king Amanakhareqerema (end of 1st c. CE). The first is engraved upon the base of ram statues from the entrance of the king’s temple in El-Hassa (REM 0001 and 1151[^x18]) and the second is a wall inscription from Temple 200 in Naga.[^x19] The long epithet of Amun, which is irrelevant to the present discussion, is omitted. Example (31) is one of the four columns of text engraved on the shaft of each of the sandstone columns in the Amun Temple in Naga (REM 0034A).[^ex31] Each of these inscriptions is a prayer to Amun, that he may give to the royal family the cardinal point it is facing (here “north”). The three members of the royal family are King Natakamani, Queen-Mother Amanitore, and Prince Arakakhataror. The epithet of Amun is again omitted here for convenience.

[^x18]: cf. Rilly, *Le méroïtique et sa famille linguistique,* p. 90.
[^x19]: Rilly, “The Meroitic Inscriptions of Temple Naga 200.”
[^ex31]:  Aritene and Makedeke/Makedoke, “the Great God,” are two of Amun-Re’s numerous hypostases. The name Aritene is obviously a nominal compound and is consequently followed by the article *-l,* though scribes frequently omitted it. This determiner is mandatory here because the name is a direct genitive (Rilly, *La langue du Royaume de Méroé,* pp. 520–523). The meaning of Aritene is uncertain. It might be a Meroitic transcription *Ar-i-tene* of Egyptian *Harakhty* (Ḥr-ꜣḫt.y) “Horus of the Horizon,” where the “horizon” is reinterpreted as the “west”: cf. Meroitic *tene-ke-l* “west,” Nobiin *tin-o,* Ama *t̪êŋ* and words for “evening” or “night” in NES languages (Rilly, *Le méroïtique et sa famille linguistique,* p. 141).

{{< gloss "(29)" >}}
{r} **Meroitic**
{g} *Amni* (…),Amun|*Mnxreqerem*,Amanakhareqerema|*qore :*,ruler|*Mni*,Amun.[gen]({sc})|*tke-l :*,beloved-[det]({sc})|*pwrite :*,life|*l-x-te :*,give-[vnm.sg-opt.2sg]({sc})|
{r} “O Amun (…), to Amanakhareqerema, ruler beloved of Amun, may you give life!”
{{< /gloss >}}

{{< gloss "(30)" >}}
{g} *Amni* (…),Amun|*Mnxreqerem*,Amanakhareqerema|*qore :*,ruler|*Mni*,Amun.[gen]({sc})|*tke-l :*,beloved-[det]({sc})|*pwrite :*,life|*ntke :*,strength|*kesekene*,also|*l-x-te :*,give-[vnm.sg-opt.2sg]({sc})|
{r} “O Amun (…), to Amanakhareqerema, ruler beloved of Amun, may you give life and strength!”
{{< /gloss >}}

{{< gloss "(31)" >}}
{g} *Amni* (…),Amun|*Ntkmni*,Natakamani|*Amni*,Amun.[gen]({sc})|*mdese-l :*,descendant-[det]({sc})|*Mnitore*,Amanitore|*Aritene-l*,Aritene-[det.gen]({sc})|*mdese-l*,descendant-[det]({sc})|*Arkxtror*,Arakakhataror|*Mke-deke-l*,God-great-[det.gen]({sc})|*mdese-l :*,descendant-[det]({sc})|*hr-l :*,north-[det]({sc})|*alose :*,entirely|*l-bx*-∅-*te :*,give-[vnm.pl-2sg-opt]({sc})|
{r} “O Amun (…), to Natakamani, the descendant of Amun, to Amanitore, the descendant of (the) Aritene, to Arakakhataror, the descendant of the Great God, may you give the north entirely!”
{{< /gloss >}}

In (29), the singular suffix *-x* is added to the stem *l-* “give.” It refers to a single beneficiary, king Amanakhareqerema. Admittedly, the object, namely *pwrite* “life, vital strength,” is also singular, so that evidence of the agreement with the beneficiary is to be sought in examples (30) and (31). In (30), the object is plural, *pwrite ntke* “life and strength,” since there is no dual in Meroitic. However, the suffix remains in the singular. In (31), the object is again singular, *hrl alose* "the north entirely,” but the beneficiary is now a plural, namely the three members of the royal family. In this case, the plural form *-bx* of the suffix is used,[^34] just as we have seen in Ama and Nobiin.

[^34]: Example (8) above, which is two centuries earlier than (29)–(31), is apparently a counterexample. Admittedly, the contextual elements are much clearer and the meaning of the verb is better established in examples (29)-(31) than in (8). However, it may be that the marking of the direct/indirect object is governed by the degree of animacy/definiteness, as it is in Old Nubian (Van Gerven Oei, *A Reference Grammar of Old Nubian,* §13.1.3). According to Dimmendaal, "Tama,” p. 324, this hierarchy is the following:

    - Animacy: Human > animate > inanimate:

    - Definiteness: Personal pronoun > proper name > definite NP > indefinite specific NP > non-specific NP.

    In (8), the beneficiary is a god designated by his proper name, Amun of Napata (*Amnp*). The logical direct object is the two men, also designated by their names. But they are referred to by a personal pronoun (*qoleb*) which is the grammatical object of the verb. The personal pronoun is higher in the definiteness hierarchy than the proper name, and this might explain why it is encoded in the verbal compound by the plural suffix.

### The Verbal Plural Marker in NES Languages and in Meroitic {#ii34}

The Meroitic plural suffix *-bx(e)* shares three significant features with the verbal number markers in Ama and Nobiin: its direct adjunction to the stem within the verbal compound; its function as a plural marker of direct/indirect object; and its dependency on the hierarchy between participants of the action (cf. n. 59). Nonetheless, some important divergences can be observed. First of all, the Meroitic plural suffix is not a single morpheme like Ama *-(ī)d̪ì* and Nobiin *-(i)j* (where /i/ is a epenthetic vowel) but the plural form of a singular suffix *-x(e).* In languages where verbal number is an operative category, the most frequent situation contrasts unmarked singular and marked plural. Nonetheless, the growing literature on verbal number/pluractionality records some languages where there is an opposition between marked verbal singular and marked verbal plural. In her study of verbal number in Karko, a Kordofan Nubian language, Jakobi gives some instances of such verbs (**Table 1**).

| Gloss      | Sg. Object | Pl. Object |
| :---       | :---       | :---       |
| hang up    | kúʃ-ɛ́ɛ́r    | kùj-ùk |
| split wood | kák-ɛ̀ɛ́r    | kàk |
| pull out   | ɖúʃ-ɛ̀ɛ́r    | ɖùj |
| kindle     | ʃíl-ɛ̀ɛ́r    | ʃìl-ìk |
| wake up    | fɛ́ʃ-ɛ̀ɛ́r    | fɛ̀j-ɛ̀k |

**~~Table 1. Transitive verbs in Karko, singular stems marked by *-ɛɛr,* plural stems either unmarked or extended by *-Vk.*[^35]~~**

[^35]: Data from Jakobi, “Verbal Number and Transitivity in Karko,” p. 126, t. 6. Only three of these verbs have specific markers both in singular and plural (“hang up,” “kindle,” “wake up”). In Karko, most of the verbs operate according to a pattern “unmarked singular/marked plural.” As in many languages where verbal number is present, the plural form can be a different verb (ibid., pp. 128–129). Several cases of replacive verbal forms for plural object marking are attested in Ama, see Norton, “Number in Ama Verbs,” p. 77.  

In Maba, a language of Ouaddai (Eastern Chad) belonging to the Nilo-Saharan phylum, Weiss recorded instances of singular verbal suffix *-n* versus plural verbal suffix *-k.*[^36]

[^36]: Example from Weiss, *Phonologie et morphosyntaxe du maba,* p. 270, ex. 699.

{{< gloss "(32a)" >}}
{r} **Maba**
{g} *ɛ́njìː*,water|*à-wáː*-***k***-*ì*,[1sg]({sc})-pour-[vnm.pl-decl]({sc})|
{r} “I pour out a lot of water, I pour out water regularly.”
{{< /gloss >}}

{{< gloss "(32b)" >}}
{g} *ɛ́njìː*,water|*à-wáː*-***n***-*ì*,[1sg]({sc})-pour-[vnm.sg-decl]({sc})|
{r} “I pour out a bit of water.”
{{< /gloss >}}

However, these examples are utterly different from the Meroitic verbal number system. In each case, the singular and plural verbal suffixes are independent. In Meroitic, the plural marker *-b-x(e)* is morphologically the plural of the singular marker *-x(e),* which might be termed not the “dative” suffix, because it also encodes the direct object, but the “objective” verbal suffix. As in the related language groups Nubian and Taman, Meroitic merges the accusative and the dative nominal cases in an “objective” case marked by the same case endings.

The second discrepancy between the Meroitic plural suffix and “canonical” number markers such as the Nubian plural suffix *-(i)j* is the range of their functions. Unlike Western European languages, where plurality of events is conveyed by lexical derivation (Latin *sal-t-a-re* “dance” from *sal-i-re* “jump”) or adverbs (“repeatedly,” “often,” “again and again,” etc.), with plurality of participants being encoded by verbal agreement and nominal or pronominal plural markers, verbal number is a category that includes equally all these pluralities. As this category falls between stem derivation and aspect, it is morphologically marked, either by modification of the verbal stem (syllable reduplication, vocalic or tonal change, etc.) or by affixes directly appended to the verbal stem. Consequently, in languages such as Nubian, where verbs are inflected by suffixation, verbal number markers are directly appended to the stem, before TAM or person markers.

### Plural Object Marker or Plural Event Marker {#ii35}

The Meroitic suffix *-bx(e)* is therefore located in the right place, but, contrary to its Nubian counterparts, its use, as much as we can judge in the limited corpus available, seems restricted to plural object marking and does not extend to the plurality of events. The following examples of frequentative forms are attested in Nobiin (33) and Karko (34).[^37]

[^37]: Examples from Werner, *Grammatik des Nobiin,* p. 173; Jakobi,“Verbal Number and Transitivity in Karko,” p. 130, ex. 16. The original gloss [plr]({sc}) “verbal plural stem” has been replaced by [vnm]({sc}) “verbal number marker” in accordance with the conventions of the present article.

{{< gloss "(33)" >}}
{r} **Nobiin**
{g} *ay*,[1sg]({sc})|*neer-j-ir*,sleep-[vnm-1sg]({sc})|
{r} “I sleep several times.”
{{< /gloss >}}

{{< gloss "(34)" >}}
{r} **Karko**
{g} *súk*,market.[loc]({sc})|*ʃɛ̀-ʈɛ̀g*,go.[vnm-frq.imp]({sc})|
{r} “Go [pl]({sc}) to the market frequently!”  
{{< /gloss >}}

It may, however, be mentioned that in Nubian languages, few instances of the use of the same morpheme for the frequentative (plurality of events) and the verbal number (plurality of participants) are attested. Nobiin and Old Nubian are the only Nubian languages where *-(i)j* is attested as both a plural event and participant marker, as shown in (33).[^x20] Still, it is uncertain whether this was also the case in Proto-Nubian. In (34) from Karko, the plurality of participants is indicated by the vowel *ɛ̀* in the verbal stem *ʃɛ̀-* (the singular stem is *ʃù-*), whereas the plurality of events is marked independently by the suffix *-tɛ̀g.* It may happen that a verb exhibits three different stems in Karko: one for a singular participant, one for a plural participant, and one for plurality of action.[^x21] A conspicuous instance is the verb “call,” which is *òg-* with singular object, *ògór* for plural object, and *òʃór* for plural action, i.e., a distributive meaning “call one by one.” The suffix *-(V)ʃ* is a frequent number marker in Karko[^y4] and other Kordofan Nubian languages, and is doubtlessly a reflex of Proto-Nubian suffix *\*-(i)j*. Another verbal number marker, the most frequent, is *-Vr,* with a vowel that is subject to vowel harmony. It is obvious that *òʃór* is an assimilated compound derived from *\*og-ʃ-Vr.* The two verbal plural suffixes *-(V)ʃ* and *-Vr* are used successively in the same stem to express plurality of object and plurality of events respectively. A similar distribution of these two verbal extensions is paralleled in Andaandi, where *-(i)j* is used for frequentatives, whereas the suffix *-ir* is used to mark the plurality of participants (only objects in this language).[^38] The markers *-(i)j* and *-ir* are clearly the Mattokki–Andaandi cognates of Kordofan Nubian *-(V)j* and *-Vr,* so that their use as specialized verbal plural markers might go back to Proto-Nubian.

[^38]:  See Jakobi, Ibrahim & Gulfan, “Verbal Number and Grammatical Relations in Tagle,” §2, with further references, particularly Armbruster, *Dongolese Nubian: A Grammar,* §§2880f, 3031f.
[^y4]: Ibid., p. 128.
[^x20]: See also Khalil, “The Verbal Plural Marker in Nobiin,” p. 37.
[^x21]: Jakobi, “Verbal Number and Transitivity in Karko,” pp. 130–132.

A distinct marker *-k* is found in Nubian for the plurality of events,[^x22] e.g., Nobiin *jòog* “grind” → *\*joog-k* > *jòkk* “chew.” This suffix dates back to Proto-NES, or at least to its eastern branch, because it is also found in Nara and Meroitic.[^39] In Nara, it differentiates verbal forms such as *ishayto* (< *\*ishag-to*) “he asked” from *ishakkito* (< *\*ishag-k-i-to*) “he asked them” or “he asked several questions,” but is rarely used.[^x23] This suffix is also attested in Meroitic,[^40] as shown in the following example:  

[^x22]: Jakobi, “Verbal Number and Transitivity in Karko,” p. 122 with further references.
[^x23]: Thompson, "Nera,” p. 491.
[^39]:  The morphology of event plurality marking in Tama seems complex (Dimmendaal, “Tama,” p. 316) and needs a specific study. In the closely related language Mararit, it seems reduplication, which is cross-linguistically a very common way to form verbal plurals, is used (El-Nazir, *Major Word Categories in Mararit,* p. 55). In Ama, the same suffix *-īd̪ì* (see exx. 21–22) is used for plurality of participants and plurality of events.
[^40]:  Several cases of “fossilized” suffix *-k* are attested in Meroitic, in which basic verb has disappeared whereas the form with *-k* has been preserved, but has lost its pluractional meaning. Examples are the verbs *erik-* “beget” and probably *tk-* “love” or “revere” in *Amni-tke-l* “beloved of Amun” (Rilly, *Le méroïtique et sa famille linguistique,* pp. 90–91). The former verb is still attested in Ajang (Kordofan Nubian) in both its forms: *ír-í* “give birth,” pluractional *ír-k-í* “give birth to one child after the other” (Jakobi, *Kordofan Nubian,* p. 114). The second might be an assimilated form /takk/- of *\*tar-k-*, cf. Old Nubian ⲧⲁⲣⲟⲩ-, ⲧⲁⲣⲓ- “praise, bless,” Tama *tár-* “love.”  

{{< gloss "(35)" >}}
{r} **Meroitic**
{g} *abr-se-l :*,man-each-[det]({sc})|*e-ked :*,[1sg.s]({sc})-kill|*kdi-se-l :*,woman-each-[det]({sc})|*e-(e)r-k :*,[1sg.s]({sc})-take-[plc]({sc})|
{r}  “I killed each man; I (repeatedly) took each woman.” (REM 1044/4–5)
{{< /gloss >}}

Although it encodes the plurality of events, it seems that this suffix cannot be used in combination with the plural object marker *-bx(e),* unlike the verbal form *òʃór* in Karko, where the plural event suffix is combined with the plural object suffix. Examples (36) and (37) are drawn from Queen Amanirenas and Prince Akinidad’s stela REM 1003 and describe military campaigns against two different tribes in nearly identical terms. The first uses the pluractional suffix *-k,* but no plural object marker is present, probably because the distributive value of *tk-k* “seize one by one” implies the plurality of the object. Conversely, in the second sentence, the verbal plural marker *-bx* is present, but not the pluractional suffix *-k.*[^ex36]

[^ex36]: In (36), “their” refers to the women and the men, who are quoted in the previous sentence. One may wonder whether the term *apote,* which is borrowed from Egyptian *wpwtj,* “envoy, ambassador,” does not mean something like “tribal chief” in this particular context.

{{< gloss "(36)" >}}
{g} *abr :*,man|*100 :*,100|*kdi*,woman|*1*[.]*2* :,1[.]2|*qo-leb :*,this-[det.pl]({sc})|*apote*,envoy|*be-se :*,[3pl-gen]({sc})|*tk-k :*,seize-[plc]({sc})|
{r} “(I) seized 100 men, 1[.]2 women (and) their envoy.” (REM 1003/10)
{{< /gloss >}}

{{< gloss "(37)" >}}
{g} *abr :*,man|*58 :*,58|*kdi*,woman|*223* :,223|*qo-leb :*,this-[det.pl]({sc})|*apote*,envoy|*qebe-se :*,[3pl-gen]({sc})|*ye-tk-bx-i :*,[1sg.s]({sc})-seize-[vnm.pl-tam]({sc})|
{r} “I seized 58 men, 223 women (and) their envoy.” (REM 1003/12–13)
{{< /gloss >}}

The difference between Meroitic, where the pleonastic use of the two plurality markers is avoided and Karko, where it is allowed, shows how verbal number marking can vary within the same language family. This flexibility may be due to the rivalry between these markers and other ways to express plurality, according to Gerrit Dimmendaal:

> These typological properties suggest that such systems are subject to a considerable degree of communicative dynamism, and hence to historical change or reinterpretation. There may be a number of reasons for the relative instability of such systems, compared to some other grammatical domains in these languages, such as noun-class systems in Niger-Congo languages, or gender marking in Afroasiatic languages. One reason, as argued in the present contribution, may derive from construction-level effects of number marking across categories. As shown below, pluractional marking, as a derivational phenomenon describing event structure, interacts with plural argument marking.[^x24]

[^x24]: Dimmendaal, "Tama,” p. 130.

### A New Hypothesis Concerning the Origin of *-bx(e)* {#ii36}

The plural object marker *-bx(e)* displays an astonishing feature, which has yet to be noted. One may expect the plural of *-x(e)* to be *\*-x(e)b,* with a suffixed plural marker *-b,* as is the cases with other morphemes. The plural of the article *-l* is *-leb* and the possessive *qe-se* “his/her” (lit. “of him/her”) becomes *qe-be-se* “their” (lit. “of them”) when the possessor is in the plural (see [3.2](#ii2)). The unexpected initial location of the plural marker in the compound *-b-x(e)* is best explained by supposing that the plural morpheme *-b* was the basic element of this group. The object marker *-x(e)* was later added to it, and not the opposite. In this case, we can surmise that, originally, the verbal plural marker was simply *-b.* As is obvious from comparative pairs such as Proto-Nubian *\*nogu* ~ Meroitic *nob* /nuba/ “slave”; Proto-Nubian *\*aŋgur* ~ Meroitic *abore* /abur/ “elephant,” the Meroitic reflex of Proto-NES *\*g* followed or preceded by a labiovelar vowel is /b/.[^x25] The original verbal plural marker was therefore *\*gu.* In Old Nubian and Nobiin, this element is preserved as a nominal and pronominal plural marker: ⲙⲁⲛ /man/ “that,” ⲙⲁⲛⲛ̄-ⲅⲟⲩ /manin-gu/ “those.”

[^x25]: Rilly, *Le méroïtique et sa famille linguistique,* p. 373.

It is nevertheless unclear whether the Old Nubian and Nobiin verbal plural marker *-(i)j* (see [3.3.2](#ii32)) is a cognate of *\*gu.* The Proto-Nubian phoneme *\*ɟ* cannot be reconstructed in Proto-NES, but principally derived from *\*g,* when followed or preceded by the palatal vowels *\*i* and *\*e*.[^x26] The Nubian verbal plural marker might accordingly result from a protoform *\*-ig.* Similarly, its Ama counterpart *-(ī)d̪ì* probably derived from *\*(-i)gi.* The Ama dental stops *t̪* and *d̪* are the regular reflexes of Proto-NES *\*k* and *\*g* with back vowels,[^x27] but there are some instances of the same development with palatal vowels, such as *kwɔ̀dŕ*  “strong” < Proto-NES *\*kugir*[^x280] or *tɛd̪i-ŋ* “under” < Proto-NES *\*tago-* “belly.”[^x28] To sum it up, the Meroitic suffix derives from *\*gu,* whereas the Ama and Nubian suffixes derive from *\*(i-)gi.* Because Ama and Nubian belong to two separate groups within the NES languages, it is plausible that *\*(i-)gi* is the Proto-NES etymon, whereas *\*gu* is a secondary protoform restricted to the eastern branch of NES (Nubian/Meroitic and Nara).

[^x26]: Ibid., pp. 303–304.
[^x27]: Ibid., p. 329, n. 4.
[^x28]: Ibid., p. 523, no. 190
[^x280]: Ibid., p. 456, no. 72.

Like *-(i)j* in Old Nubian and Nobiin, the verbal plural marker *-b* was once used for plurality of events or plurality of object. The name of the Napatan king Amani-nataki-lebte,[^42] who ruled during the second half of the 6th century BCE, does not make sense if the suffix *-b* marks the plurality of object. It would mean “Amun, give them strength,” with no clue as to who these multiple beneficiaries could be. Actually, the suffix marked the plurality of events and emphasised the repetition of the gift: “give again and again,” “give continuously,” or “keep giving.”[^43]

[^42]: For this ruler, see *FHN* II, pp. 293–296. The name is known in Egyptian transcription only (first line of (38)), since the Meroitic script was invented only three centuries later.
[^43]:  In the inscriptions of the temple of Apedemak in Naga, the verbal form *lbxte* “give them” is attested in REM 0003, where the beneficiary is the sole queen and in REM 0004, where it is the king alone. In her publication of these texts, Karola Zibelius (*Die Löwentempel van Naq‘a in der Butana (Sudan). IV,* pp. 45–52) explains this plural form as an iterative. However, at this time (mid-1st c. CE), the verbal plural suffix *-bx* was already specialized to exclusively mark the object plurality. It never occurs in benedictions involving a single person, where only *lxte* is used at least since the 2nd c. BCE (REM 1044A, REM 1151). The plural marker in REM 0003 and 0004 refers to the three members of the royal family, who constitute an indissoluble trinity, even when the queen and the king are figured alone (cf. ex. 31 above).  


{{< gloss "(38)" >}}
{g} **Egyptian transcription**,**Meroitic (reconstituted)**,**Gloss**|*Jmn-*,*Amni-*,Amun|*ntk-*,*ntki-*,strength|*lbt*,*l-b-te*,give-[vnm-opt.2sg]({sc})|
{r} “Amun, may you keep giving strength!”
{{< /gloss >}}

At first sight, the addition of the object marker *-x(e)* to the verbal plural suffix *-b,* i.e., the suffixation to a suffix, makes no sense grammatically. This would be only possible if this suffix, at a moment in the history of the Meroitic language, was interpreted as a pronoun. The following example from the Old Nubian legend of Saint Mina can illustrate how this transcategorization of the verbal plural marker occurred.[^x56]

{{< gloss "(39)" >}}
{r} **Old Nubian**
{r} ⳟⲥ̄ⲥⲟⲩ ⲙⲏⲛⲁ-ⲛ ⲕⲥ̄ⲥⲉⲗⲁ ⲧ̄ⳝⳝⲁⲛⲁⲥⲁ
{g} *ŋissou*,holy|*mēna-n*,Mina-[gen]({sc})|*kisse-la*,church-[dat]({sc})|*tij-j-ana-sa*,give>2/3-[o.pl-imp.2/3pl-purp]({sc})|
{r}  “So that we give it to them in the church of Saint Mina.” (M 9.3–4)
{{< /gloss >}}

In his analysis of the text, Van Gerven Oei notes that the “plural object marker -ⳝ  [is] referring to the recipients of the egg, which remain unexpressed.”[^x55] Nevertheless, even if the plural object marker is not *stricto sensu* a pronoun, it operates in this sentence as an anaphoric element and is accordingly translated “to them” by the editor of the text. It is probably via a similar process that its Meroitic counterpart *-b* became a 3rd person plural enclitic pronoun. This explains the strange location of this morpheme, which is directly appended to the stem, before the TAM suffixes.

[^x56]: Example from Van Gerven Oei, *A Reference Grammar of Old Nubian,* §8.3.2.2.
[^x55]: Van Gerven Oei \& El-Guzuuli, *The Miracle of Saint Mina,* p. 99. He later refers to the same suffix as "pluractional" (Van Gerven Oei, *A Reference Grammar of Old Nubian,* §13.1.)

Once it was considered to be a pronominal marker, *-b* was inflected by the objective case ending. This morpheme is attested after noun phrases in two variants; *-xe* (40) and *-w* (41).

{{< gloss "(40)" >}}
{r} **Meroitic**
{g} *atepoke :*,offering(?)|*dot-l*-***xe***,large(?)-[det-obj1]({sc})|*pisi-tk-bxe-kese* (< *-kete-se*),[caus]({sc})-offer-[vnm.pl-opt.2pl.impp]({sc})|
{r}  “May you [pl]({sc}) present them with a large(?) offering(?)" (REM 1063)
{{< /gloss >}}

{{< gloss "(41)" >}}
{g} *x(re)*,food|*mlo-l*-***w***,good-[det-obj2]({sc})|*hol-kete*,serve-[opt.2pl]({sc})|
{r}  “May you [pl]({sc}) serve him a good meal” (REM 0059)
{{< /gloss >}}

The difference between the two suffixes is unclear. The previous examples are drawn from benediction formulae used at the end of the funerary texts, formula J in (40) and formula C’ in (41).[^45] They can co-occur in the same text.[^46] The Proto-NES ending for the objective case can be reconstructed as *\*-gV,*[^47] which is preserved in Nubian and vestigially in Nara. In the Taman language group and in Ama, the vowel *V* was dropped and the final *\*-g* became *-ŋ.* We have seen in [2](#i) that the value of the grapheme *-x* in local words was most likely /ŋ/. The following *e* probably had a zero value, so that *-xe* was simply a final /ŋ/ like the Taman and Ama marker.

[^45]:  See Rilly, *La langue du Royaume de Méroé,* pp. 171–172 (formula C’) and pp. 176–177 (formula J).
[^46]:  The two suffixes are therefore used at the same period, but a dialectal difference is possible, since the Meroitic scribes had a marked taste for variety and commonly used dialectal variants in the same text (cf. Rilly, *La langue du Royaume de Méroé,* p. 42).
[^47]: Rilly, *Le méroïtique et sa famille linguistique,* pp. 390–395.

This “objective case” in Nubian and in Tama undergoes some restrictions governed by economy principles. In his analysis of Tama, Dimmendaal speaks of “differential object marking.”[^48] In Meroitic, the objective case has become so rarely marked that the absence of case ending was more a rule than an exception. Example (41) is the benediction formula C’. It is the royal and princely counterpart of formula C which is used for private people. The only difference was the presence of the objective case-ending in C’, whereas it was missing in the C formula.[^x30] It probably gave the royal benediction a more formal wording, worthy of the lofty position of the deceased.

[^x30]: Rilly, *Le méroïtique et sa famille linguistique,* p. 394.
[^48]: Dimmendaal, "Tama,” pp. 323–328 after Bossong, “Differential Object Marking in Romance and Beyond.”

Similarly, the objective case ending may be omitted, as can be seen in the second of two consecutive sentences from King Taneyidamani’s stela. In (43), the expected verbal compound, parallel to the singular form *ekedeto* in (42), should be *ekedbxto.* However, maybe because of the presence of the object pronoun *qoleb,* the objective case ending *-x* is absent.  

{{< gloss "(42)" >}}
{g} *Nhror*,Nakharura|*wide-l :*,brother-[det]({sc})|*e-kede-to :*,[1sg.s]({sc})-kill-[tam]({sc})|
{r}  “I killed the brother, Nakharura” (REM 1044/143–144)
{{< /gloss >}}

{{< gloss "(43)" >}}
{g} *qoleb :*,[3pl]({sc})|*axro*,?|*tewideb-wit*,?|*e-ked-b-to*,[1sg.s]({sc})-kill-[vnm-tam]({sc})|
{r}  “I killed them, ???” (REM 1044/148–150)
{{< /gloss >}}

In conclusion, the suffixes *-x(e)* and *-bx(e)* operate in the verbal compound as enclitic object pronouns. It originally consisted of a verbal plural marker *-b,* similar to its counterparts in Nubian and Ama. Between the 6th and the 2nd century BCE, this suffix underwent a transcategorization and became an enclitic object pronoun inflected with the objective case ending *-x(e).* In parallel, a singular counter­part, *-x(e),* without the plural marker *-b,* was created. However, they cannot be termed “personal pronouns” unless different forms for the 1st and the 2nd persons are identified, so as to constitute a full paradigm. Considering the formation of this morpheme, it is altogether unlikely that it also marked person.  

# The First Person Singular Marker {#iii}

If the wording of the Meroitic inscriptions was identical to the Egyptian texts of the same genre, we should expect to find first person singular markers in the captions accompanying the divine figures in the temples and in the royal chronicles. However, the Meroitic culture, though deeply influenced by the Egyptian civilisation, still preserved many of its own peculiarities. The gods, for instance, never speak for themselves in religious texts. In an Egyptian or a Napatan temple, the caption inscribed beside an image of Amun would begin with the sentence: “Utterance of Amun. I have given all life and all power to you.”[^49] In the Meroitic texts of the temples of Naga, Meroe, Amara, and others, the god is not speaking himself. Rather, a fictive enunciator is inviting him to shower his blessings upon the ruler and his family: “O Amun! May you give X life and strength,” as shown in (17)–(18) and (29)–(31). For that reason, no first person marker can be expected in these inscriptions.

[^49]: See for instance the speech of Amun-Re in Anlamani’s stela from Kawa (*FHN* I: pp. 217–218).

## Person in Egyptian Royal Texts {#iii1}

The Egyptian royal chronicles, the so-called *Königsnovellen,*[^50] alternatively use the first person pronoun and the phrase *ḥm=f* “his Majesty” to designate the king — the hero of the narrative. This is for instance the case in the famous poem of Kadesh, where passages in the first person and the third person freely intertwine to describe the battle that Ramesses II fought against the Hittites. In Kush, the earliest and the most sophisticated *Königsnovelle* is the Victory Stela of King Piankhy (*FHN* I: pp. 62–118), engraved around 720 BCE and erected in the dynastic temple of Amun in Jebel Barkal. Apart from the passages including the king’s speech, which are in the first person, the narrative uses *ḥm=f* “his Majesty” to refer to Piankhy. The same usage is found in the stelae erected in the temple of Kawa by king Taharqo and, later, in the inscriptions of the early Napatan kings Anlamani and Aspelta.[^51]

[^50]: See Loprieno, "The King's Novel" and Spalinger, “Königsnovelle and Performance.” For an annotated edition of the poem of Kadesh, see Kitchen, *Ramesside Inscriptions Translated and Annotated: Notes and Comments, II.*
[^51]: Taharqo’s stelae, Kawa IV: *ḥm=f* with a long speech of the king in the 1st person (*FHN* I: pp. 135–145), Kawa V: *ḥm=f,* with a long narrative told by the king in the second half of the text (*FHN* I: pp. 145–158), Kawa VI: *ḥm=f,* with a long speech told by the king in the second half of the text (*FHN* I: pp. 164–176), Kawa VII: *ḥm=f,* with a speech told by the king in the second half of the text (*FHN* I: pp. 176–181); Anlamani’s stela, Kawa VIII: *ḥm=f,* but the raid against the Blemmyes uses the 3rd person plural ("soldiers") because the king stayed in Napata (*FHN* I: pp. 216–228); Aspelta’s stelae from Jebel Barkal, Election stela: *ḥm=f* (*FHN* I: pp. 232–252), Banishment stela: *ḥm=f* (*FHN* I: pp. 252–258), Adoption stela (king hardly mentioned): *ḥm=f* (*FHN* I: pp. 259–268), stela for the mortuary cult of Prince Khaliut: *ḥm=f* (*FHN* I: pp. 268–279).

In the mid-5th c. BCE, a dramatic shift occurred. The inscriptions of the late Napatan king Amannote-erike (*FHN* II: pp. 400–428) still use the time-honored phrase *ḥm=f,* but the two subsequent royal stelae, erected in the temple of Amun in Jebel Barkal by kings Harsiotef (*FHN* II: pp. 438–464) and Nastasen (*FHN* II: pp. 471–501), are written in the first person, even in the reports of military campaigns in which the ruler did not take part in person. This shift was not an isolated novelty, but took place among several divergences from the Egyptian/Early Napatan pattern. In Nastasen’s inscription, for example, the time scale by regnal years is replaced by vague adverbial phrases such as *kt ꜥn* “another matter again” in the war reports.[^52] This chronological vagueness was to become systematic in the royal stelae written in Meroitic, where no regnal year is ever mentioned. The reasons for these changes are unclear but the influence of local oral epics may have played a role.

[^52]: Cf. *FHN* II: p. 487 (l. 46), p. 488 (l. 50), p. 489 (l. 52), p. 490 (l. 54, 56), p. 491 (l. 60), p. 492 (l. 64).

In Harsiotef’s stela, after the titles and the eulogy, where the king is referred to in the third person, the text abruptly shifts to the first person, without any kind of transition (*FHN* II: p. 441, l. 4). In Nastasen’s stela, the main text similarly begins with the titles of the king and a long eulogy, after which the narrative is introduced by the clause *dd=f* “he says,” referring, of course, to the king. This addition, lacking in Harsiotef’s stela, makes clear that, from this point on, the narrator is the ruler.[^53] The following passage from Nastasen’s chronicle (ll. 54–56) illustrates this novel use of the first person in Napatan war reports.[^54] Conspicuously, the monarch is not acting in person, but through his warriors, hence the use of the factitive verb *dj* “make, cause to.”  

[^53]:  *FHN* II: p. 475 (l. 4). This infringement of the Egyptian tradition puzzled the editor of the text, who appropriately translated “he says,” but erroneously corrected in n. 151: “For ‘I say’.”  

{{< gloss "(44)" >}}
{r} **Egyptian**
{r} *k.t ꜥn*
{r}"And another thing again.
{r}*dj=ı͗ sj=f pd.t ḥr sby.t Mḫ Šrḫrtj*
{r}I had a battalion of archers to go against the enemy tribe of the Makho of Sharakharti.
{r}*dj=j ḫꜣy ꜥꜣ*
{r}I caused a great bloodbath.
{r}*dj=j ṯꜣ pꜣ wr pꜣ nty jw=f r s.ꜥnḫ jr.t n-jm=f nb ḥmt nb.t*
{r}I had the chief seized, (together with) all that on which he [= they] would feed, and all the women.
{r}*dj=j* <*s*>*w ẖr=j x*[*ꜥ*]*q jwꜣ 203,146 mnmn 33,050*
{r}I put in my possession a booty (of) 203,146 oxen and 33,050 head of livestock.”
{{< /gloss >}}

[^54]: Reading and translation by the author. See *FHN* II: p. 490 and Peust, *Das Napatanische,* pp. 42, 60, 64.

The first preserved royal text in Meroitic, namely the great stela of king Taneyidamani from the temple of Amun in Jebel Barkal, was inscribed a century and a half later. In the meantime, the Egyptian-language donation stelae of king Aryamani, Kawa XIV and XV, are admittedly written in the first person, but the texts — at least what is left of them — are speeches to Amun and contain no narrative.[^55] On the other end of the Meroitic period, a century after the fall of Meroe, the wall inscription of the Nobadian ruler Silko in Kalabsha, though written in Greek, also is in the first person.[^56] It is therefore highly probable that the Meroitic royal chronicles fall in this long-lasting tradition and include events and war reports narrated by the ruler in the first person, like the late Napatan royal stelae and the post-Meroitic inscription of king Silko.

[^55]:  See *FHN* II: pp. 522–532. The stelae, which are in very bad state of preservation, are dated to the late 4th or the early 3rd c.
[^56]: *FHN* III: pp. 1147–1153; Rilly, “Histoire du Soudan, des origines à la chute du sultanat Fung,” pp. 385–388.

## The Verbal Affix *(y)e-* in Meroitic Royal Texts {#iii2}

Although the major part of the Meroitic royal inscriptions remains untranslatable, the passages that enumerate the spoils of war are now fairly well understood.[^57] They include, on the one hand, verbs such as *ked* “kill”; *are* and *er* “take hold of”; *tk* “seize”; and *kb* “seize, plunder,” sometimes followed by the pluractional marker *-k* (*er-k, tk-k*), and, on the other hand, nouns such as *abr* “man”; *kdi* “woman”; *ar* “boy”; *anese* “donkey”; *mreke* “horse”; and *d* “house,”[^58] all of them being parts of the booty and therefore, cited with figures or more summarily followed by *-se-l* “each.” Examples (20), (35), (36), (37), (42), and (43) above are instances of booty lists from royal inscriptions.

[^57]: Cf. Rilly, *Le méroïtique et sa famille linguistique,* pp. 74–80.
[^58]:  The word appears in REM 1003/14 and in graffito MS 57 from Musawwarat. Its translation is inferred from the context of these two occurrences and from the comparison with Andaandi *daa* “residence” and Nara *dà* “village.” See Rilly, “Graffiti for Gods and Kings.”

In his publication of the so-called Akinidad stela from Hamadab (REM 1003), Griffith was the first to deal with these passages. Thanks to his then recent translation of *kdi* “woman” and *abr* “man,” he correctly identified the first two clauses (*abrsel yekedi: kdisel: arseli: tkk*) as the outcome of military campaigns and tentatively translated them as “slaying men, enslaving women.”[^59] By using participles, he eluded the thorny issue of the subject of the verbs. After Griffith, few scholars addressed this particular question. In her analysis of the same passages, Inge Hofmann dealt with the meaning of the verb *ked,* but ignored the problem of its subject.[^60] As for Millet, in a first study of Kharamadoye’s royal inscription REM 0094, he suggested that *ked* was a noun meaning “slayer.”[^x31] Later, in a revised analysis of the same article, he assumed that *ked* was a verb in the third person singular,[^x32] but did not explain how this third person was morphologically expressed.

[^x31]: Millet, “The Kharamadoye Inscription,” p. 38.
[^x32]: Millet, “The Kharamandoye Inscription (MI 94) Revisited,” p. 67.
[^59]:  Griffith, “Meroitic Studies IV,” p. 167. Note that Griffith mistook the noun phrase *ar-se-li* “all the boys” for the verbal form he translated “enslaving,” which verb was actually *tkk.*
[^60]:  Hofmann, *Material für eine meroitische Grammatik,* pp. 294–297. For a critical review of her translation of *ked,* see Rilly, *Le méroïtique et sa famille linguistique,* pp. 76–78.

It is necessary first to summarize the different forms that the verbs “kill” and “seize” (*vel sim.*) can take in different royal, princely, and viceregal inscriptions. **Table 2** includes a list of these forms with reference to the texts which are quoted in chronological order:

* Great stela of king Taneyidamani from Barkal (REM 1044, ca. 150 BCE);
* Graffito of prince Akinidad in the temple of Dakka (REM 0092, ca. 25 BCE);
* Stela of Amanirenas and Akinidad from Hamadab (REM 1003, ca. 20 BCE);
* Funerary stela of viceroy Abratoye from Tomas (originally Karanog, REM 1333, ca. 270 CE);
* Late inscription of the Blemmyan kinglet Kharamadoye from the temple of Kalabsha (REM 0094, ca. 420 CE).

Note that only the passages where at least the verb *ked* is present are taken into consideration here.

| Text        | Lines       | Example     | "kill"         | "seize" (*vel sim.*)   |
| :---        | :---        | :---        | :---           | :--- |
| REM 1044    | 5           |             | e-ked          | erk (< e- + er-k) |
|             | 130–131     |             | e-ked-td       | er-td (< e- + er-td) |
|             | 143         | (42)        | e-kede-to     | |
|             | 144         |             | e-kede-to     | |
|             | 149–151     | (43)        | e-kede-b-to   | |
| REM 0092    | 6–8         |             | kede-to       | are-de-to |
|             | 12–14       |             | kede-to       | are-de-to |
| REM 1003    | 4–5         | (35)        | ye-ked-i       | tk-k; yerki (< ye- + er-k-i)  |
|             | 9           |             | ye-ked-i       | erk (< e- + er-k) |
|             | 11          | (36)        | ye-ked         | tk-k |
|             | 14          |             | ye-ked         | tk-k |  
| REM 1333    | 6           |             | ye-ked         | |
|             | 13          |             | ked            | |
|             | 14          |             | ked            | kbxelo (< kb-bxe-l-o) |
|             | 16–17       | (20)        | ked            | arohe-bx; tk-bxe-l-o |
|             | 18          |             | ye-ked         | |
|             | 20          |             | ked            | |
|             | 24          |             | kede-bx       | |
| REM 0094    | 11          |             | kede-bxe      | |
|             | 20–21       |             | kede-bx       | kb-b-te |

**~~Table 2. Forms of the verbs "kill" and "seize" (*vel. sim*) in REM 1044, 0092, 1003, 1333, and 0094.~~**

The verbal forms listed above show a great diversity of suffixes. The plural verbal marker *-bx(e)* in REM 1333, variant *-b* in REM 1044/149–150 and 0094, and the pluractional suffix *-k* in REM 1044/5 and 1003, which were studied both in [3.3.6](#ii36), are irrelevant in the quest for personal markers. The suffixes *-td* (only in REM 1044), *-to* in REM 1044 and 0092, *-te* in REM 0094 are probably tense or aspect markers, which are in final position in all the other NES languages.[^61] The morpheme *-i* in REM 1003 is obviously optional, as it can be present or absent in identical sequences such as *abr-se-l: ye-ked-i* “I killed each man” in l. 4 vs. *abr-se-l ye-ked* in l. 11.[^62] The vocalic sign *-e* appended to the stem in *(e)-kede-to* (REM 1044 and 0092) is probably an epenthetic vowel inserted before the suffix *-to.* In the other verbal forms ending with this suffix that occur in the same texts, the vowel *-e* is generally absent, but no obvious rule, as for now, can predict its appearance. Finally, the forms ending with *-l-o* in REM 1333 are very probably periphrastic, as they include participles followed by the article *-l* and the copula *-o.* The multiplicity of tense or aspect markers that occur in these narrative texts is by no means unexpected or dubious, but is a further aspect of the *varietas* that is so peculiar to the Meroitic texts, when compared with their formulaic Egyptian counterparts.[^63] A similar variety in narrative tenses can be found in many languages. In French, for example, historical records can of course use simple past and imperfect, but present is possible (*présent de narration*) and even future, in this case referring to past events (*futur historique*).

[^61]:  Wolfgang Schenkel, in his analysis of the verbal affixes in the Meroitic royal text ("Meroitisches und Barya-Verb"), assumes that *-td* is a durative suffix, which he compares with the durative ending *-ter/-der* in Nara. Note that this suffix is attested only in Reinisch’s description of the language, which used second-hand material and is not entirely reliable (Reinisch, *Die Barea-Sprache,* p. 57). Schenkel suggests that the suffix *-to* includes an aorist marker *-t* followed by a 1st person singular *-o,* with similar comparisons with Nara. For a critical review of his hypotheses, see Hofmann, *Material für eine meroitische Grammatik,* pp. 214–216. Note that the suffix *-te* in REM 0094 (also frequent with other verbs in REM 1003) is not identical with the 2nd person plural suffix of the optative, which is also written *-te* (see [5.2](#iv2) below).
[^62]: This morpheme may be the same as the particle *-wi* that is added *ad libitum* to the singular copula *-o* (cf. Rilly, *Le méroïtique et sa famille linguistique,* p. 186). The consonant *w-* could be either an epenthetic glide inserted between *o* (pronounced /u/) and *i,* or a dummy sign used to write the hiatus /u/ + /i/ according to the rules of the alphasyllabic Meroitic writing system (Rilly, *La langue du Royaume de Méroé,* pp. 294–295).    
[^63]:   This is particularly true for the funerary texts. See Rilly, *La langue du Royaume de Méroé,* pp. 202, 565.

Coming back to **Table 2**, the only marker that can actually refer to the person is the prefix *(y)e-,* since it has no alternative, unlike the diverse suffixes that are listed above. As explained in [2](#i), the form *ye-* is just a later spelling of *e-.* Both were similarly pronounced /e/. In early inscriptions such as Taneyidamani’s stela (REM 1044), the prefix is spelled *e-* everywhere. In classical Meroitic texts such as Akinidad’s stela (REM 1003), *e-* (in *erk*) and *ye-* (in *yerki*) are alternately used for the same verb. Finally, in the late stela of viceroy Abratoye (REM 1333), the only spelling is *ye-.* One may wonder why this personal marker was not identified earlier. Actually, there were two difficulties. First, the prefix is missing in several clauses in REM 1003 and is completely absent in REM 0092 and 0094; second, a prefix *ye-* is attested in the final benedictions of the funerary texts, in a context where only the 2nd person plural is expected.

## The Distribution of the Prefix *(y)e-* and Homonymy {#iii3}

The first difficulty can be easily resolved. Once again, this issue is connected with the chronology of the inscriptions. In the early text REM 1044, the prefix is present everywhere, before *ked* “kill” as well as before the verbs meaning “take” in the following clauses, except for *tk-to* in l. 151. In the classical Meroitic stela REM 1003, it is always present in the first clause (“kill”) and can be omitted in the second clause (“take”), especially when the verb *tkk* is used. In the late inscription REM 1333, *(y)e-* is present before *ked* in the first instance of this verb, that is, at the beginning of the narrative part of the funerary stela. It is omitted in the subsequent occurrences of *ked* until l. 18, at which point it appears again. Furthermore, it is never present before the verbal forms of the second clause (“take” *vel sim.*). Curiously, the prefix *(y)e-* is lacking in REM 0092, which is contemporaneous with REM 1003, as they both mention Prince Akinidad. It is also absent from the occurrences of “kill” and “take” in the very late inscription of kinglet Kharamadoye (REM 0094).

How can we account for these variations in the distribution of the prefix *(y)e-* in the royal and princely inscriptions? In the early stela REM 1044, the prefix is systematically present on all the verbal forms. In REM 1003, a century and a half later, the prefix is used with the first verbal form (“kill”) but is omitted in the following clause (“take”) for reasons of economy, since the subject is the same as in the previous clause. In the late stela REM 1333, the first occurrence of the verb *ked* includes the prefix *ye-,* but the next three occurrences of the same verb are again subject to ellipsis, as are all the verbs of the second clauses (“take” *vel sim.*). In l. 18, the personal prefix is resumed, as a reminder for the two last occurrences of *ked,* where it is omitted again. In the very late inscription of the post-Meroitic kinglet Kharamadoye, the prefix is totally missing in the forms meaning “kill” or “take.” However, a previous sequence in l. 8, *yetolxe,* could be a verbal form with prefix *ye-.*[^64] Finally, the inscription REM 0092, though written at the same time as REM 1003, shows no prefix in the verbal forms for “kill” and “take.” However, in a previous passage in l. 5, the verb is illegible because the stone is damaged in this place. This lacuna possibly contained the prefix *e-,* whose lower stroke seems partly visible on some photographs taken prior to the relocation of the temple of Dakka when the Aswan dam was built.

[^64]:  Millet, “The Kharamandoye Inscription (MI 94) Revisited,” pp. 62, 70, considered this sequence a noun group *yeto-l-xe* “on (?) the river.” The variant *yeto* for *ato* “water” is, however, attested only in REM 0307.

It seems that, in the course of time, the personal marker *(y)e-* shifted from compulsory verbal affix to quasi-independent subject pronoun. On the one hand, it could be present or absent if implicit, just like personal pronouns in English *he came and saw*. On the other hand, it was never separated from the verb by an intermediary element such as an object noun group or an adverbial phrase. Its close connection with the following verbal form is also showed by the total absence of a word-divider (*:*) between them in all the texts. In addition, ellipsis was likely more frequent in everyday speech than in the literary inscription. This could explain the difference in the use of the prefix between the contemporaneous texts REM 0092 and 1003: REM 0092 is a simple graffito carelessly engraved in the temple of Dakka during the visit of prince Akinidad, whereas REM 1003 was an official stela erected at the entrance of the temple of Amun in Hamadab.  

The second difficulty is that a homonymous prefix *ye-* is attested in verbal compounds of the funerary benedictions, which are clearly in the 2nd person plural since these passages are prayers to Isis and Osiris. This rare alternative prefix can replace the element *p(V)s(V)-* that is generally found at the beginning of the complex verbal forms of the benedictions A and B.[^65] It is altogether the most frequent in the rare benediction D.[^66] The suffixes of the verbal compounds of the benedictions are now relatively well understood (see [5.1](#iv1)), though their prefixes still remain puzzling. Both *ye-* and *p(V)s(V)-* can best be interpreted as causative markers, as they always appear before the verbal stems meaning “drink” (*he* in benediction A) and “eat” (*xr* in benediction B), but are optional before the verb “offer, present” (*hol* in benediction C). The deities invoked in the funerary texts would be invited to “make” the deceased “drink” and “eat,” but they could either “present them with a good meal” or “have them presented with a good meal.” Prefixes are extremely rare in NES languages and only the Taman group has verbal prefixes, used exclusively for marking the person (a point to which we return below).

[^65]:  See Rilly, *La langue du Royaume de Méroé,* pp. 559–567. It accounts for 2% of the verbal forms used in the benedictions funerary texts according to Schenkel, “Zur Struktur des Verbalkomplexes in den Schlußformel der meroitischen Totentexte,” p. 8.
[^66]: Rilly, *La langue du Royaume de Méroé,* pp. 172–174. Only twenty occurrences are known so far.

The most plausible solution would be to regard *ye-* and *p(V)s(V)-* as causative verbs, such as “make” or “have” in English. In the case of *p(V)s(V)-,* a possible cognate could be Old Nubian ⲡⲉⲥ- “tell, speak, say.” The gods of the underworld could in this case could be invited, literally, to “tell” that the deceased eat and drink, that is, to make them eat and drink. As for the alternative verb *ye-* in these passages, it could be linked with Old Nubian ⲉⲓ- and Nobiin *ií-* “say,” especially because *ye-* has a variant *yi-* which is three times more frequent in funerary texts.[^67] This solution may be semantically acceptable, but it faces a major obstacle: Meroitic, like all the NES languages, is a head-final language, in which the verb is placed at the end of sentences and the auxiliary is expected to occur after the verb. In addition, the absence of TAM markers after *p(V)s(V)-,* and *ye-/yi-* points to a serial verb construction, where only the last verb is inflected for TAM. However, this is cross-linguistically attested only for consecutive verbs that share a common subject.[^68] For all these reasons, the verbal compound of the funerary benedictions requires further study. Nevertheless, the element *ye-* in these benedictions has nothing to do with the prefix *ye-* we found in the royal texts. It is just a further instance of the many homonymous morphemes that are attested in Meroitic.

[^67]:  The frequency of *yi-* is 6,2% according to Schenkel, “Zur Struktur des Verbalkomplexes in den Schlußformel der meroitischen Totentexte,” p. 8. For Nobiin *ií-*, more commonly used with a causative suffix in the compound *ií-gìr,* see Werner, *Grammatik des Nobiin,* p. 356. Note that “say” is frequently used as a light verb (but not as a causative auxiliary) in the languages of Sudan, regardless of the linguistic family. For Andaandi, see El-Guzuuli, "The Uses and Orthography of the Verb 'Say' in Andaandi"; for Ama, see Stevenson *Grammar of the Nyimang Language,* p. 147 (my copy of the manuscript, an annotated version transmitted by Roger Blench, has the light verb *she* on pp. 146–146a and 147. Page 146a is handwritten and the page numbers on p. 147 and 148 have been corrected manually) and Rilly, *Le méroïtique et sa famille linguistique,* p. 210; for Beja, see Vanhove, *Le bedja,* pp. 146–147.
[^68]: See Haspelmath, "The Serial Verb Construction,” esp. pp. 409–411 (with possible exception in ex. 31, where two different subjects are found).

Finally, another element *ye-* is attested in several kinship noun phrases, also in funerary inscriptions. The “filiation” part of these texts specifies the mother and father of the deceased, who is said to be “the person born of X” and “the person begotten by Y.” In the major part of the inscriptions, these two compounds are *te-dxe-l* (or *t-dxe-l*) and *t-erike-l.* They include a prefixed element *t(e)-,* the participles *dxe* “born” and *erike* “begotten,” and the final article, which has a nominalizing role. Several texts include a variant with a first element *y(e)-,* namely *ye-dxe-l* and *y-erike-l.* The forms including *y(e)-* and *t(e)-* can even be found together in the same inscription, giving a further example of the aforementioned *varietas* sought by Meroitic scribes. Another kinship term, *yetmde* “younger in the maternal line, i.e., nephew/niece,” may provide the key to the element *ye-* in filiation clauses. It includes the word *mde* which refers to the mother’s family in this matrilineal society. The first element is *yet-* (pronounced /eta/ or /eda/), but has many variants: *yete, yed, yen* (with assimilation before ­*mde*). The elements *te-* and *ye-* in filiation are probably two eroded forms of *yet-,* which can be compared with Proto-Nubian *\*id,* Proto-Taman *\*at* “person,” and Nara *eítá* “body.”[^x33] “The person born” and “the person begotten” are therefore accurate translations of *ye-dxe* and *y-erike*. The element *ye-* in these contexts is therefore originally a noun and has nothing to do with the homonymous prefix found in royal inscriptions.

[^x33]: Rilly, *Le méroïtique et sa famille linguistique,* p. 496, no. 141.

## Comparative Evidence from NES Languages {#iii4}

In light of the above, it seems certain, first, that the verbs in the narratives of the royal inscriptions are in the first person singular and, second, that the prefix *(y)e-* is the personal subject marker of the verbs “kill” and “take.” Consequently, *ye-ked* (archaic *e-ked*), can be translated “I killed” or “I have killed” and *yerki* (archaic *erk*) as “I took,” “I have taken,” or the like. Given the meaning of these passages, the basic tense/aspect using simple stems like *ked, tkk,* and so on, must be a perfective. Alternative tenses with suffixes also are attested, as shown in **Table 2**, but for now, it is impossible to explain them. The first person singular marker *(y)e-* is probably the Meroitic reflex of the Proto-NES pronoun *\*a(-i),*[^69] reconstructed from Proto-Nubian *\*a-i,*[^70] Nara *\*a(-ga)*,[^71] and Proto-Nyima *\*a-i.* The stem of this pronoun is *\*a,* to which a suffix *\*-i* has been appended. This ending was probably a deictic particle and can be found at the end of persons’ and gods’ names in Meroitic and in Old Nubian.[^72] The Meroitic form seems to have undergone crasis[^73] /a/ + /i/ > /e/, which is also found for this pronoun in several Ajang dialects.[^74]

[^69]:  Cf. Rilly, *Le méroïtique et sa famille linguistique,* pp. 467–468, no. 92. The Proto-Taman is curiously *\*wa,* which can result from *\*o* through vowel-breaking. The Proto-NES genitive of the [1sg]({sc}) pronoun seems to have been *\*on* and might have triggered an analogical shift for the nominative in Proto-Taman.  
[^70]:  Reconstructed *\*ay* in Proto-Nubian according to Jakobi, “The Nubian Subject Pronouns,” tab. 2. The glide *y,* IPA [j], has no phonological status in Proto-Nubian according to my own research (Rilly, *Le méroïtique et sa famille linguistique,* p. 269). For this reason, I am inclined to reconstruct this word as vowels in hiatus.  
[^71]:  In the Nara group, the ancient accusative form (with regular *\*-ga* ending) of this pronoun has replaced the nominative when the distinction between both cases was lost: see Rilly, *Le méroïtique et sa famille linguistique,* p. 391 and n. 471. There is no way to know if the original nominative form was also *\*a-i*.
[^72]:  In Meroitic, this particle is spelled *-i* in names of gods, for example *Amn-i* “Amun” or *Atr-i* “Hathor” and *-ye* in the names of people, for example *Abrato-ye,* name of a famous viceroy of Nubia. In Old Nubian, for example, Jesus is written ⲓ̈ⲏⲥⲟⲩⲥ-ⲓ. This particle may be connected to the Meroitic vocative ending *-i*: *Wos-i* “oh Isis!”
[^73]: Fusion of two consecutive vowels into one.
[^74]:  For instance Karko *ê* "I" (Jakobi, *Kordofan Nubian,* p. 42) from Proto-Nubian *\*a-i.*

If the form of the Meroitic marker matches its cognates in other NES languages, its syntactic use shows a substantial difference to them. In all these languages, the subject pronoun is located at the beginning of the sentence and the verb at the end (SOV word order) as in these examples from Nobiin and Ama.[^ex46]

[^ex46]: Example (46) is based on Werner, *Grammatik des Nobiin,* p. 291.

{{< gloss "(46)" >}}
{r} **Nobiin**
{g} *ày*,[1sg]({sc})|*tùuɲì-n*,boys-[gen]({sc})|*mèdrèsá-l*,school-[loc]({sc})|*júù-r*,go-[1sg]({sc})|
{r}  “I go to the boys’ school.”
{{< /gloss >}}

{{< gloss "(47)" >}}
{r} **Ama**
{g} *à*,[1sg]({sc})|*ɲúfà-ŋ*,father.[2sg.gen-dat]({sc})|*ēlò-ɔ̀*,milk-[acc]({sc})|*têg*,give.[ipfv]({sc})|
{r}  “I give (some) milk to your father.”
{{< /gloss >}}

The only NES-languages which have personal prefixes appended to the verb are the Taman languages, that is, Tama and Mararit. However, these suffixes, namely *nV-* for the 1st person, *V-* for the 2nd person, and ∅- (zero suffix) for the 3rd person,[^75] are distinct from the subject pronouns, which are optional as shown in the following examples.[^76] In the second sentence, the subject pronoun is here for emphasis and could be translated “as for me.”

[^75]:  These prefixes (where *V* stands for a variable vowel) are the same for the singular and plural persons.
[^76]: The data are cited from the unpublished Tama grammar of Pierre Palayer.

{{< gloss "(48)" >}}
{r} **Tama**
{g} *dʊ́t*,big|*n-ànᵻ́*,[1sg]({sc})-be|
{r}  “I am big.”
{{< /gloss >}}

{{< gloss "(49)" >}}
{g} *wâ*,[1sg]({sc})|*tàmʊ́t*,Tama|*n-ànᵻ́*,[1sg]({sc})-be|
{r}  “I am a Tama.”
{{< /gloss >}}

This structure seems an innovation of the Taman group within the NES languages. Generally speaking, the personal affixes appended to the verb in Nara, Nubian, and Taman strongly differ from each other and cannot be reconstructed in Proto-NES. It seems that the original person marking combined independent pronouns (which are clearly related in the daughter languages) and verbal plural suffixes, which have been studied above. This system still operates in the Nyima languages. The Meroitic system — at least in the passages of the royal inscriptions under examination — seems close to the Proto-NES and Nyima system, but has innovated by displacing the subject pronoun before the verb. This innovation created a specific OSV word order for sentences including a subject pronoun, whereas the original SOV order was preserved in sentences with nominal subject.

## Another Person Marker in Meroitic Royal Texts? {#iii5}

Instead of *(y)e-,* an alternative prefix *w-* appears before the verbal forms of *er-k* “take, capture,” *kb* “seize, and *bqo* “take control” within the royal texts REM 1044, 1003, and 0094. It never occurs with *ked* “kill,” as can be seen in the examples below.[^ex77]

[^ex77]: In (50), the reading of the first signs was made possible thanks to excellent photos and interpretation by Gilda Ferrandino in her doctoral thesis, *Studio dei testi reali meroitici,* p. 65 and pl. 29.1. For the archaic sign conventionally transcribed *H,* see Rilly, *La langue du Royaume de Méroé,* p. 353. In all likelihood, the form *kbxte* comes from *kb-bx-te* after haplography, as the object seems to be a plural and, accordingly, should be marked in the verb by the suffix *bx*.

    In (51), the word *tdxsene* includes the noun phrase *t-dx-* meaning “child (of a mother)” but the following sequence *-se-ne* is obscure. It ultimately might be a proper name, Tadakhesene, with an ending *-ne* that is common in the Meroitic personal names.

    Examples (52) and (53) differ only in the spellings of *(y)emoqe* “belongings (?)”and *(e)qebese* “their’.

    In (54), a direct genitive *Aqtoye mtekdi 2* “the two daughters of Aqatoye” should be expected for unalienable possession (cf. Rilly, *La langue du Royaume de Méroé,* pp. 525–527). However, the inscription REM 0094, engraved for the Blemmyan kinglet Khamaradoye after the fall of Meroe, is very late (c. 420 CE) and includes some strange features that could have resulted from language contact with Old Nubian and Blemmyan (Old Beja dialect), in which no distinction was made between alienable and unalienable possession (for Beja, see Vanhove, *Le bedja,* p. 40).

{{< gloss "(50)" >}}
{r} **Meroitic**
{g} *heHle*,?|*qoleb :*,[3pl]({sc})|*ahtero-l*,?|*am*,?|***w***-*k*[*b*]-*bx-te*,[pm]({sc})-seize-[vnm-tam]({sc})|
{r}  “? seized ? them ???” (REM 1044/68–70)
{{< /gloss >}}

{{< gloss "(51)" >}}
{g} *qorte*,palace(?).[gen]({sc})|*dxe-leb :*,child-[det-pl]({sc})|*wide-bese*,brother-[3pl.gen]({sc})|*aroqitm*,Aruqitama|*tdxsene*,Tadakhesene(?)|***w***-*er-k*,[pm]({sc})-take-[plc]({sc})|
{r} “? captured the children of the palace (and) their brothers Aruqitama (and) Tadakhesene(?)”
(syntax uncertain; REM 1044/152–155)
{{< /gloss >}}

{{< gloss "(52)" >}}
{g} *kdi-se-l-w :*, woman-each-[det-acc]({sc})|*abr-se-l-w :*,man-each-[det-acc]({sc})|*yemoqe :*,belongings(?)|*eqebese-wit :*,[3pl.gen-det]({sc})(?)|***w***-*kb-te*,[pm]({sc})-seize-[tam]({sc})|
{r} “? seized each man, each woman (and) their belongings(?)” (REM 1003/23–24)
{{< /gloss >}}

{{< gloss "(53)" >}}
{g} *kdi-se-l-w :*, woman-each-[det-acc]({sc})|*abr-se-l-w :*,man-each-[det-acc]({sc})|*emoqe :*,belongings(?)|*eqebese-wit :*,[3pl.gen-det]({sc})(?)|***w***-*kb-te*,[pm]({sc})-seize-[tam]({sc})|
{r} “? seized each man, each woman (and) their belongings(?)” (REM 1003/31–35)
{{< /gloss >}}

{{< gloss "(54)" >}}
{g} *wedi*,?|*dxe*,child|*mte-kdi*,young-woman|*Aqtoye : -se*,Aqatoye-[gen]({sc})|*2*,2|***w***-*bqo-b-te*,[pm]({sc})-take.control-[vnm-tam]({sc})|
{r} “? took control of ??? the two young daughters of Aqatoye” (REM 0094/24)
{{< /gloss >}}

There is no doubt that the prefixed element *w-,* which is paradigmatically parallel to the morpheme *(y)e-,* is also a person subject marker. We should expect it to mark a different person, which can only be the 1st plural or the 3rd singular or plural, since there is no interlocutor in these sections of the royal inscriptions. Unfortunately, the context of these passages with *w-* does not provide much information, chiefly because of our scanty knowledge of Meroitic, but also because of the poor preservation of some parts of the stelae REM 1044 and 1003. However, it seems that these passages are the continuity of the sentences where the subject is in the first person, either explicitly or implicitly. The passage below precedes (51) in Taneyidamani’s stela (REM 1044/141–155). The lines that follow are unfortunately badly eroded.  

{{< gloss "(55)" >}}
{r} *Ahotone qorte : drteyose-l :* ***e***-*kede-to :*
{r} “I killed Akhutune, the ??? of the palace(?).
{r} *Nhror wide-l :* ***e***-*kede-to :*
{r} I killed (his) brother Nakharura.
{r} *kdi : ste-bese : dnetro :*
{r} I ??? their mother [lit. 'woman-tutor'].
{r} *sxseli : holno-leb : asxdose : tedd : qoleb : axro tewideb-wit :* ***e***-*ked-b-to :*
{r} I killed ??? them, namely the ???, the ???.
{r} *krtedse : xrpxe-se-mlo-l : tk-to :*
{r} I seized the good ??? governor.
{r} *qorte : dxe-leb : wide-bese : Aroqitm : Tdxsene :* ***w***-*erk :*
{r} ? captured the children of the palace(?) (and) their brothers Aruqitama and Tadakhesene(?).” (= ex. 51)
{{< /gloss >}}

Three of these sentences include the subject pronoun marker *e-* “I” in the verbal compounds *e-kede-to* (twice) and *e-ked-b-to.* In two other sentences, the prefixed pronoun is absent, but implicit, in *dnetro*(?) and *tk-to.* It is difficult to account for the subject shift in the last sentence (51), where the prefixed pronoun *w-* replaces *e-*. No solution is fully satisfactory, but the most acceptable is to assume that the antecedent of the prefixed pronoun is one of the nouns of the same sentence that would be placed as its topic. These topicalized constructions are well documented in Meroitic.[^x34] They can also be found, under Meroitic influence, in the Egyptian texts of the late Napatan royal inscriptions, as in this example from king Nastasen’s stela (ll. 12–13, after *FHN* II: p. 478):    

[^x34]: Rilly, *La langue du Royaume de Méroé,* pp. 547–548.

{{< gloss "(56)" >}}
{r} **Egyptian**
{r} *jr=w  šn jr=j rmt-ꜥꜣ, ḥ(m)-ntr Jmn dr=w*
{r} “They made obeisance to me, (to wit) all the notables and priests of Amun
{r} *jry=w smꜣ jr=j, rꜣ nb*
{r} They blessed me, (to wit) every mouth.”
{{< /gloss >}}

If so, the tentative translation of (51) suggested above must be thoroughly corrected. A singular object is expected, because there is no plural object marker at the end of the verbal compound. Maybe the translation should be “(as for) the children of the palace (?) (and) their brother Aruqitama, they captured Tadakhesene.” If this solution is syntactically acceptable, it is less so morphologically. A plural marker would be expected, like in *qe-be-se* “of them” ([3.2](#ii2) above). In addition, an element *w-* is attested in the late text REM 0094 as a variant of the singular 3rd person pronoun *qo/qe* “he/she, this” (cf. [3.1](#ii1)). Instead of *qe-se, qo-se* "his/her” (lit. “of him/her”), a form *w-se,* with variants *we-se,* and even *w-si,* in the same text, is attested: *semle: w-si* “his wife,” *ste: wese* “his mother” (line 26). Finally, no cognate can be found in other NES-languages, all of which have for “they” at least traces of a plural element *\*-gV.* In conclusion, the prefixed element *w-* in verbal compounds remains unexplained and needs further examination.  

# The Second Person Markers {#iv}

Many Meroitic texts include prayers to the gods. They are chiefly present, of course, in the funerary inscriptions, which begin with an invocation to the deities of the underworld and finish with several “benedictions,” in which a fictive enunciator beseeches them to provide the deceased with water, bread, and a good meal in the afterlife. Similarly, in the temples and on a few stelae, the depictions of the kings and their family in front of the gods are accompanied by captions, most of them in Meroitic hieroglyphic script. They also include prayers, uttered by a fictive enunciator again, that invite the deities to shower their gifts (life, strength, health, etc.) upon the ruler.

In all these inscriptions, the requests to the gods use verbal moods that fit with wishes, namely imperative or optative. The forms are in the singular in the temples because there is a specific prayer for each deity. They are in the plural in funerary inscriptions because they are addressed to Isis and Osiris together. Unlike in Egyptian and Napatan texts, the gods are never answering. Such sentences as “I gave you all life and all power,” which are so common in Napatan texts and could give us details about the first and second person pronouns, are unfortunately missing from the Meroitic religious texts. However, a small stela found in 1999 has miraculously provided the genitive of the 2nd person pronouns singular and plural. Finally, recent researches on the Meroitic names of person have shown that they sometimes comprised short sentences, which in two cases include a second person singular pronoun.

## Second Person Verbal Suffixes in Optatives and Imperatives {#iv1}

The final prayers of the funerary texts, which Griffith termed “benedictions,” amount to thirteen different types, classified with uppercase letters from A to L, plus a formula “X” added by Hofmann.[^82] The general scheme for benedictions A to D, by far the most frequent, is presented in (57).[^83]

[^82]:  Griffith, *Karanòg,* pp. 42–53; Hofmann, *Material für eine meroitische Grammatik,* pp. 198–200; synthesis in Rilly, *La langue du Royaume de Méroé,* pp. 163–183 and Rilly, *Le méroïtique et sa famille linguistique,* pp. 68–74. A further type of benediction was used in a stela recently found in Sedeinga, Exc. No II S 055, cf. Rilly \& Francigny, “Excavations of the French Archaeological Mission in Sedeinga, Campaign 2011,” pp. 70–71. It remains unattested elsewhere.
[^83]: For benedictions A and B, see also (11)–(14) above.

{{< gloss "(57)" >}}
{r} Formula A
{g} *ato*,water|*mhe*,plentiful|*pVsV-/yi-*,[caus]({sc})|*he*,drink|*-x(e)/bx(e)*,[vnm.sg/pl]({sc})|*-k(e)te*,[opt.2pl]({sc})|
{r} “May you [pl]({sc}) make her/him/them drink plentiful water”
{r} Formula B
{g} *at*,bread|*mhe*,plentiful|*pVsV-/yi-*,[caus]({sc})|*xr*,eat|*-x(e)/bx(e)*,[vnm.sg/pl]({sc})|*-k(e)te*,[opt.2pl]({sc})|
{r} “May you [pl]({sc}) make her/him/them eat plentiful bread
{r} Formula C
{g} *x(re)*,meal|*mlo*,good|*(pVsV-/yi-)*,[caus]({sc})|*hol/tx*,present|*-x(e)/bx(e)*,[vnm.sg/pl]({sc})|*-k(e)te*,[opt.2pl]({sc})|
{r} “May you [pl]({sc}) present her/him/them (or have her/him/them presented) with a good meal”
{r} Formula D
{g} *x(re)*,meal|*lh-l*,large-[det]({sc})|*(pVsV-/yi-)*,[caus]({sc})|*hol/tx*,present|*-x(e)/bx(e)*,[vnm.sg/pl]({sc})|*-k(e)te*,[opt.2pl]({sc})|
{r} “May you [pl]({sc}) present her/him/them (or have her/him/them presented) with a large meal”
{{< /gloss >}}

The prefixed elements *pVsV-* or *yi-,* which obviously have a causative value but are not yet fully understood, have been studied above in [4.3](#iii3). The element *-x(e)* in the singular, *-bx(e)* in the plural, is a verbal number marker that has been analysed in section [3.3](#ii3). As the funerary benedictions are basically prayers to the gods, imperative or optative in the 2nd person plural are expected. The verbal TAM ending here is *-k-te* or *-ke-te* with a plural suffix *-k(e).* The singular TAM ending is *-te,* as seen in examples (19), (29)-(31), each of which contains a prayer to a single god. Cross-linguistically, the singular imperative is generally a simple verbal stem, e.g., English *see!,* Latin *vide!,* and Middle Egyptian *m3!* This is also true for the living NES languages: Nobiin *nàl!,* Midob *kóod!,* etc.[^84] For this reason, the verbal form with ending *-te,* which is used in the royal blessings and funerary benedictions, must be regarded as an optative rather than an imperative. However, an optional particle *-se,* which is added to the verbal compound in several funerary inscriptions,[^85] has an Old Nubian parallel in the command marker -ⲥⲟ or -ⲥⲱ.[^x35] Be it related or borrowed, this particle shows the semantic proximity of the Meroitic optative with the Old Nubian imperative.

[^x35]: Van Gerven Oei, *A Reference Grammar of Old Nubian,* §4.2.
[^84]: In the Nubian group, for Nobiin: Werner, *Grammatik des Nobiin,* p. 145; for Andaandi: Armbruster, *Dongolese Nubian,* pp. 194–195; for Midob: Werner, *Tìdn-áal,* pp. 58–59. In the Nara group, for Higir: Thompson, "Nera,” p. 467; for Mogoreeb: Elsadig, *Major Word Categories in Nara,* p. 66. For Tama: Palayer's unpublished grammar, §4.3; for Sungor: Lukas, “Die Sprache der Sungor in Wadai,” pp. 192, 198–199; for Mararit: El-Nazir, *Major Word Categories in Mararit,* pp. 57–58. For Ama: Stevenson, *Grammar of the Nyimang Language,* pp. 106, 110 and Stevenson, Rottland \& Jakobi, “The Verb in Nyimang and Dinik,” p. 30; for Afitti: ibid., p. 33. In all these languages, the singular imperative is generally the simple stem of the verb. However, a suffix *-i* is found for some verbs in Nubian, Taman, and Nyima. Suppletive forms for basic verbs are attested in Nara, Taman, and Nyima.
[^85]:  The particle *-se* may have an emphatic role, such as *donc* in French *dis-moi donc!* or the use of the auxiliary *do* in the English counterpart *do tell me!.* The resulting verbal compound is *pVsV-k(e)-te-se,* often reduced to *pVsV-k(e)-se* with regressive assimilation (see (40) above); cf. Hintze, *Beiträge zur meroitischen Grammatik,* p. 75 and Rilly, *La langue du Royaume de Méroé,* p. 563.

The imperative proper, in all likelihood, is the verbal form devoid of TAM markers which is used instead of the optative in several funerary texts. As shown in the following examples, it occurs either in one or two of the three main benedictions A, B, and C (a further example of *varietas*), or in all of them. Example (58) is drawn from REM 0369, an offering table from Shablul engraved for a single deceased. Example (59) is cited from a stela found in the same cemetery, REM 0381, and engraved for two persons, hence the plural verbal marker at the end of verbal compounds.[^86]

[^86]:  The verbal plural marker *-bxe* here appears as *-b,* without the objective case marker. See (43) and its comment above.

{{< gloss "(58)" >}}
{r} **Meroitic**
{r} Benediction A
{g} *a*<*to*>,water|*mhe*,abundant|*pso-h :*,[caus]({sc})-drink.[imp.2]({sc})|
{r} “Make her/him drink plentiful water.”
{r} Benediction B
{g} *at*,bread|*mhe*,abundant|*psi-xr* [*:*],[caus]({sc})-eat.[imp.2]({sc})|
{r} “Make her/him eat plentiful bread.”
{r} Benediction C
{g} *x(re)*,meal|*mlo-l*,good-[det]({sc})|*hol :*,present.[imp.2]({sc})|
{r} “Present her/him with a good meal.”
{{< /gloss >}}

{{< gloss "(59)" >}}
{r} Benediction A
{g} *ato*,water|<*m*>*he*,abundant|*pso-he-b :*,[caus]({sc})-drink.[imp.2-vnm]({sc})|
{r} “Make her/him drink plentiful water.”
{r} Benediction B
{g} *at*,bread|*mhe*,abundant|*psi-xr-b :*,[caus]({sc})-eat.[imp.2-vnm]({sc})|
{r} “Make her/him eat plentiful bread.”
{{< /gloss >}}

In these imperative forms, there is virtually no plural marker. A final suffix *-k(e)* for the 2nd person plural is expected, but it is only attested in a very small number of funerary inscriptions.[^87] However, it seems that in some epitaphs, the two deities Isis and Osiris, to whom these prayers were addressed, were syntactically regarded as a single god, as shown by the use of a single vocative suffix for both, located after the second noun.[^x36] Moreover, in the final invocations that resume the initial call to the deities, Osiris is sometimes omitted.[^x37] Finally, Isis (or one the goddesses assimilated to her in the Meroitic funerary cults, namely Nephthys, Nut, or Maat), is often figured in the private offering tables and the funerary chapels, whereas Osiris is never present, at least in the non-royal contexts with with which here we are dealing.[^88] I surmise that the instances of the imperative are addressed to Isis. This would explain why the 2nd person singular, and not plural, is used.

[^x36]: Rilly, *La langue du Royaume de Méroé,* p. 297. Another solution for the lack of plural marker *-ke* is again the principle of economy, which seems to play an important role in Meroitic, as in Tama (see n. 72).
[^x37]: Ibid., p. 93.
[^87]: One clear example is REM 0380, an offering table from Shablul, where benediction B is written with final verb compound *pisixrke.* The form is complete, since it ends with a word divider, it is located in the middle of a line and followed by benediction C. Note that, in this inscription, benedictions A and C have regular optative forms in *-kete.* There may be more instances of [2pl]({sc}) imperative in the benedictions. In particular, it cannot be ruled out that all or part of the verbal compounds ending with *-ke-se* are not assimilated optative forms deriving from *-ke-te-se,* but imperative with plural suffix *-ke* followed by the emphatic particle *-se* (see n. 124).
[^88]:  In the Meroitic private funerary iconography, the male counterpart to Isis is Anubis, or more rarely Thoth. The local names of these Egyptian gods are unknown.

Furthermore, a not uncommon variant of the verbal suffix *-te,* found only in the late funerary benedictions, is *-to.*[^89] It is directly appended to the verbal stem and, unlike *-te,* is never preceded by the plural marker *-ke.* In REM 0368, an offering table from Shablul, there are four benedictions, A, B, C, D. The verb in benediction A has no suffix, so that it should be an imperative in the 2nd person singular. In the subsequent three benedictions, the verbs are in the optative with the final suffix *-to.* The four verbs, most likely, are all in the singular and convey prayers to Isis.

[^89]: Cf. Griffith, *Karanòg,* p. 48. The alternation *-te/-to* is apparently a phonetic, not morphological, feature. It also occurs in person names. Queen Amanishakheto’s name, for instance, is generally written *(A)mnisxeto,* but is spelled *(A)mnisxete* in REM 0706, 1055, 1293, and 1346.

{{< gloss "(60)" >}}
{r} Benediction A
{g} *ato*,water|*mhe*,abundant|*pso-he*,[caus]({sc})-drink.[imp.2]({sc})|
{r} “Make her/him drink plentiful water.”
{r} Benediction B
{g} *at*,bread|*mxe :*,abundant|*psi-xr-to*,[caus]({sc})-eat.[opt.2sg]({sc})|
{r} “May you make her/him eat plentiful bread.”
{r} Benediction C
{g} *x(re)*,meal|*mlo-l :*,good-[det]({sc})|*psi-tx-to*,[caus]({sc})-present-[opt.2sg]({sc})|
{r} “May you have her/him presented with a good meal.”
{r} Benediction D
{g} *x(re)*,meal|*lh-l :*,large-[det]({sc})|*psi-hol-to*,[caus]({sc})-present-[opt.2sg]({sc})|
{r} “May you have her/him presented with a large meal.”
{{< /gloss >}}
From the above, it appears that the markers of the Meroitic imperative and optative moods are as follows:

|            | [2sg]({sc})          | [2pl]({sc})           |  [impp]({sc})    |
| :---       | :---         | :---          | :--- |
| Imperative | -∅           | -k(e)         | (-se) |
| Optative   | -∅-te/-to    | -k(e)-te      | (-se) |

**~~Table 4. Meroitic imperative and optative suffixes.~~**

The use of the suffix *-k/-g* to express the plurality of actors in the imperative (and in other moods) is widespread in Nilo-Saharan languages and particularly frequent in the NES family. Although it may have the same origin as the verbal plural marker, it must not be confused with it. The exception here is Ama, where the same morpheme *-(ì)d̪ì* is used both verbal plural marker ([3.3.2](#ii32)) and marker of the plural imperative: *kílí* “hear!,” [pl]({sc}) *kíld̪ì* “hear ye!”[^90] In Nara, the plural imperative is marked with a suffix *-aga.* This morpheme is attested in the two major dialects, namely in Higir *ay* “make!,” [pl]({sc}) *ay-aga* “make ye!”[^x40] and in Mogoreeb, *aw* “make!,” [pl]({sc}) *aw-aga* “make ye!”[^x41] In Mararit (Taman group), the plural imperative is marked with a morpheme *-k-,* which can be prefixed or suffixed according to the verb classes: *sîn* “eat!,” [pl]({sc}) *kí-síŋ-gì* “eat ye!” (prefixed); *kɛ̀dɛ̀k* “cut!,” [pl]({sc}) *kɛ̀d-k-ɛ̀k* “cut ye!” (suffixed).[^91] In the Nubian group, the suffix *\*-k/-g* is perhaps preserved in Midob in a palatalized form *-ic*: *kóod* “see!,” [pl]({sc}) *kóod-íc* “see ye!,”[^x42] but the difference with the plural verbal marker, as in Ama, is not clear. The other branches of Nubian seem to have innovated separately. In Andaandi, the [2pl]({sc}) imperative is marked with a suffix *-we*[^x38] and with a suffix *-an* in Old Nubian and Nobiin.[^x39] However, Old Nubian has a morpheme *-ke* “you,” which Van Gerven Oei analyzes as a subject clitic.[^92] It is not used for the “positive” imperative like in Meroitic, but is part of the jussive -ⲛⲕⲉ, vetitive -ⲧⲁⲛⲕⲉ(ⲥⲟ), and affirmative -ⲗⲕⲉ/-ⲥⲕⲉ. This morpheme is probably related to the Meroitic suffix *-k(e)* used in the plural imperative.

[^x38]: Armbruster, *Dongolese Nubian,* pp. 194–195.
[^x39]: Van Gerven Oei, *A Reference Grammar of Old Nubian,* §10.1.5, Werner, *Grammatik de Nobiin,* pp. 145–146.
[^x40]: Thompson, "Nera,” p. 487.
[^x41]: Elsadig, *Major Word Categories in Nara,* p. 66.
[^x42]: Werner, *Tìdn-áal,* pp. 145–146.
[^90]: Recall that the dental stop *d̪* is a development of Proto-NES *\*g* which is specific to the Nyima group.
[^91]: El-Nazir, *Major Word Categories in Mararit,* pp. 57–58 (version updated for tones, 2019).
[^92]: Van Gerven Oei, *A Reference Grammar of Old Nubian,* §10.1.6.

## The Second Person Singular and Plural Pronouns {#iv2}

### Interpretation of the Pronominal Forms in REM 1293 {#iv21}

In 1999, the archaeological team of the Berlin Museum in Naga found a small stela (REM 1293) in the temple of Amun. It was nearly complete, but broken into three joining pieces. On the obverse, Queen Amanishakheto is depicted standing between god Apedemak and his wife, Amesemi. The Lion-god is seated on a throne whereas the goddess is standing behind the ruler. The two deities hold her elbows with their right hands in a gesture of legitimization.

On the reverse of the stela, an inscription in Meroitic cursive script is engraved on six lines. The first three lines include the following prayer.    

{{< gloss "(61)" >}}
{g} *apedemk :*,Apedemak|*dqri-te-l-i :*,Daqari-[loc-det-voc]({sc})|*amni*[*sxeto :*],Amanishakheto|*qor :* (< *qore-l*),ruler.[det]({sc})|*kdke-l :*,candace-[det]({sc})|*pwrit(e)*,life|*(a)rese :*,[2sg.gen]({sc})|*yel-x-te :*,give-[vnm-opt.2sg]({sc})|*pwrite*,life|*debse :*,[2pl.gen]({sc})|*el-x-te*,give-[vnm-opt.2sg]({sc})|
{r}  “O Apedemak (who is) in Daqari, to Amanishakheto, the ruler, the Candace, give the life from you [sg]({sc}), give the life from you [pl]({sc})!” (REM 1293)
{{< /gloss >}}

The god is here invited to shower his gifts upon the ruling queen, and chiefly the most precious of them, *pwrite* “life, vital strength.” Similar instances of this prayer for King Amanakhareqerama have previously been quoted in (29) and (30). The royal text REM 1293 is engraved with great care and a sense of aesthetics that is missing in so many private inscriptions. The different phrases are accurately separated by word dividers. Conspicuously, the phrases *pwritrese* and *pwrite debse* do not include a word divider after *pwrite.* Furthermore, in the first group, *pwrite* and its extension are agglomerated into a single unit. Due to the conventions of the Meroitic alphasyllabary (see [2](#i)), the second element must have been *arese,* with an initial /a/ which was not explicitly written, because it occurred in internal position in this contracted phrase. The noun *pwrite* was pronounced /bawarit/ with the zero value of the grapheme *e.* So, the sequence *pwrite + arese* was pronounced /bawaritaresə/ and was accordingly spelled *pwritrese,* with default vowel /a/ after *t.* Additionally, the second term could not be *\*rese* because the phoneme /r/, in Meroitic as well as in all the NES languages, cannot occur in initial position.[^x43]

[^x43]: Rilly, *Le méroïtique et sa famille linguistique,* p. 230.

The close connection between *pwrite* and its successive extensions, *arese* and *debse* is best explained if the latter are determiners. They both include the genitival postposition “of,” which also was part of the possessives *qe-se* “his/her” and *qe-be-se* “their” ([3.2](#ii2)). Consequently, in the sentence from REM 1293 cited above, the sequences *are-se* and *deb-se* must be considered as possessive adjectives, that is, genitival forms of two personal pronouns, *are* and *deb.* As the context is a prayer to a deity, the only possibility is the second person: “O Apedemak, give your life to the queen,” that is “give her the life (coming) from you.”

### Egyptian Parallels

This wording was already used in the Egyptian texts of the royal inscriptions engraved for the kings of the 25th Dynasty and their Napatan successors. Example (62) below is cited from the dedication engraved in the Temple of Mut, built by King Taharqo inside the cliff of Jebel Barkal (ca. 680 BCE). Example (63) is a text written on each side of the figure of goddess Mut in the same temple (after *FHN* I: p. 133). Example (64) is an excerpt from a stela of the Napatan king Anlamani (late 7th c. BCE) erected in the temple of Kawa (after *FHN* I: p. 322). In the three texts, the passages of interest to the question under study are in bold characters.

{{< gloss "(62)" >}}
{r} **Egyptian**
{r} *dd-mdw n Mwt, nb*<*.t*> *Tꜣ-Sty*
{r} “Words to be said by Mut, mistress of Nubia:
{r} *Jmn-Rꜥ nb ns.wt Tꜣ.wy ḥry-jb* <*m*> *Dw wꜥb*
{r} ‘O Amun-Re, Lord of the thrones of the Two-Lands who is in the Pure Mountain
{r} *sꜣ=k mry=k Thrq ꜥnḫ d.t*
{r} (as for) your beloved son, Taharqo, may he live forever,
{r} *dj=k* <*n*>*=f* ***ꜥnḫ dd wꜣs nb ḫr=j***
{r} you have given to him **all life, stability and power from me,**
{r} ***snb nb ḫr=j*** *mj Rꜥ d.t*
{r} **all health from me**, like Re, for ever’.” (Temple of Mut, inscription beside of the goddess standing behind Amun)
{{< /gloss >}}

{{< gloss "(63)" >}}
{r} *jr.n=f m mnw=f n mw-t=f Mwt*
{r} “He made (this) as his monument for his mother Mut,
{r} *nb*<*.t*> *p.t ḥnw.t Tꜣ-Sty*
{r} Lady of Heaven, Mistress of Nubia
{r} *qd=f pr=s: sꜥꜣ=f ḥw.t-ntr=s m mꜣw m jnr ḥd nfr rwd*
{r} he built her house and enlarged her temple anew in fine, white sandstone,
{r} *dj=s n=f* ***ꜥnh nb ḫr=s,***
{r} so that she might give him **all life from her,**
{r} ***dd nb ḫr=s, wꜣs nb ḫr***[***=s***]
{r} **all stability from her, and all power from [her]**.” (Temple of Mut, dedication to the goddess)
{{< /gloss >}}

{{< gloss "(64)" >}}
{r} *ḫꜥ Jmn-Rꜥ Gm-Jtn jw=f ꜥḫꜥ m-bꜣḫ=f*
{r} “Amun-Re of Gematon (Kawa) appeared as he (the king) stood before him,
{r} *dj ntr pn ḥr=f r=f*
{r} and this god turned his face to him
{r} *jr=f ꜣ.t ꜥꜣ.t ꜥḥꜥ ḥr sdm ḏd.wt=f nb*
{r} and spent a long time standing and listening to all that he said
{r} *dj=f n=f* ***ꜥnḫ dd wꜣs nb ḫr=f***
{r} and gave him **all life, stability, and power from him (Amun),**
{r} ***snb*** [***nb***] ***ḫr***[***=f***] ***ꜣw.t-jb nb ḫr=f***
{r} [**all**] **health from him, and all joy from him**.” (Enthronement stela of Anlamani (Kawa VIII/ 27–28))
{{< /gloss >}}

In all these passages, the Egyptian preposition *ḫr* is used: *ꜥnḫ nb ḫr=j* “all life from me,” *ꜥnḫ nb ḫr=f* “all life from him.” Its primary meaning is “near,” but it can be also used with the agent of a passive verb in which it is usually translated with “by,”[^x44] a closer meaning to the sense of this proposition in examples (62)–(64). In these passages, the deity connected with the gift of life is the source of this gift, but not necessarily the one who provides it. In (63) the goddess gives to the ruler the life which is coming from her, and in (64) Amun is also the source and the giver of life. By contrast, in (62) Mut is asking her husband Amun to give Taharqo the life coming from her.[^93]

[^x44]: Gardiner, *Egyptian Grammar,* pp. 42, 121.
[^93]:  The complex distribution of roles in the last sentence, which includes the three grammatical persons together, is rare in this genre of Egyptian texts. Some mistakes in the use of the Egyptian personal suffixes are attested in late Napatan stelae written in poor Egyptian by local scribes. By contrast, the texts engraved in the temple of Mut were prepared by Egyptian scribes working for Taharqo during the heyday of the Kushite power. Consequently, the use of personal suffixes in (32) must be considered correct and deliberate.

In the Meroitic stela from Naga, the context bears similarities to the situation in (32). There are also three persons, namely the ruler, Amanishakheto, the lion-god Apedemak and his wife Amesemi, all of them figured on the obverse of the stela. The great difference between the Egyptian and the Meroitic texts is the position of the enunciator. In (32), Mut is the enunciator (1st person) and speaks to Amun (2nd person) about the king (3rd person). In REM 1293, the enunciator, as is common in the Meroitic prayers, is a fictive individual, who is never present in the text, so that there are no 1st person markers. He speaks to Apedemak and possibly to Amesemi (2nd person) about the queen (3rd person). The gift of life is presented to the ruler by Apedemak and the source of this life is expressed, first, by the phrase *are-se* and second by the phrase *deb-se.* The latter obviously includes the pronominal plural marker *-b,* cf. *qe-be-se* “their,” lit. "of them, from them" ([3.2](#ii2))[^94] In conclusion, the only solution is to regard *are-se* as a 2nd person singular possessive referring here to Apedemak, and *de-b-se* as a 2nd person plural possessive referring to both Apedemak and Amesemi.

[^94]:  The Meroitic postposition *-se* can be appended to the name of the giver in inscriptions found on funerary offerings. In this case, *-se* is best translated as “from”; see Rilly, “Les chouettes ont des oreilles,” pp. 489–491.

### Personal Pronouns in Proto-Nubian

The two possessive pronouns discussed above suggest a basic form *are* for “you [sg]({sc})” and *de-b* for “you [pl]({sc})” These forms differ considerably from the pronouns I reconstructed in proto-NES, namely *\*i* for “you [sg]({sc})” and *\*i-gi* for “you [pl]({sc}).”[^x45] For Proto-Nubian, I suggested *\*i-r/\*i-n* [sg]({sc}) and *\*i-gi*/*\*u-gi* [pl]({sc}). It is beyond the scope of this article to explain in detail on which bases these proto-forms were put forward. Suffice it to say that the pronouns attested in the Taman and Nyima groups, alongside with the most conservative dialects of Nara, are very similar to each other and provided the main basis for my reconstruction. By contrast, the personal pronouns in the Nubian family show considerable variations that are difficult to reconcile. The two proto-forms I worked out were mostly based on the genitives of these pronouns, which have a better consistency among Nubian languages and with the other branches of the NES family.

[^x45]: Rilly, *Le méroïtique et sa famille linguistique,* p. 519, no. 184 and p. 528, no. 200.

During the 14th Nilo-Saharan Linguistics Colloquium held in 2019 in Vienna, Angelika Jakobi, the leading expert on Nubian, delivered a paper entitled “The Nubian Subject Pronouns.” She revisited the reconstruction of these morphemes in Proto-Nubian and suggested new proto-forms. For the 1st person singular and the 3rd person singular and plural, her reconstructions are not so different from mine. However, there are significant discrepancies for the 1st person plural and the 2nd person singular and plural. For the latter, she suggests *\*ed* “you [sg]({sc})” and *\*ud-i* “you [pl]({sc}).” These proto-forms are very close to the Birgid forms *edi* and *udi,* but quite different from the Midob counterparts *íin* and *ùŋŋú.* Of course, it is tempting to believe that Jakobi’s reconstruction is mainly based on Birgid. However, this language, in many respects, is the most conservative within the Nubian family, whereas Midob is one of the most innovative.[^95]

[^95]:  For conservative aspects in Birgid, see Rilly, *Le méroïtique et sa famille linguistique,* pp. 367–368.

In Old Nubian, we find ⲉⲓⲣ “you [sg]({sc})” and ⲟⲩⲣ "you [pl]({sc}),” in Nobiin, *ìr* and *úr* respectively, and Mattokki–Andaandi *er* and *ir.* I had previously interpreted the final *-r* as an original article appended to personal pronouns in Proto-Nubian.[^x46] In Midob and in Tama, the article is actually *-r,* but it was *-l* in Meroitic and early Old Nubian, so that it must also have been *-l* in Proto-Nubian. In addition, the Midob reflexes of the Proto-Nubian liquids are often unpredictable,[^y1] whereas they are stable in Nile Nubian. For these reasons, I now think that at least in Proto-Nubian, the final *-r* was part of the stem of these personal pronouns.

[^x46]: Ibid., p. 383.
[^y1]: Ibid., p. 254.

On the other hand, Nubian languages have a propensity for intervocalic /r/ to shift to /d/. Many words for which the Proto-Nubian etymon included the sonorant *\*r* in intervocalic position, are written in Old Nubian with a delta, which later shifted back to /r/ in Nobiin, its modern descendant. As shown in **Table 5** below, Birgid and sometimes, Midob, can also have /d/ from Proto-Nubian *\*r.*


| Gloss      | Proto-Nubian   | Old Nubian       | Nobiin      | Birgid |
| :---       | :---           | :---             | :---        | :---   |
| black      | \*ur(r)-i      | ⲟⲩⲇⲙ             | úrúm        | úudè |
| great      | \*ŋoor         | ⳟⲟⲇ "Lord"       | Nóor "Lord" | -gor "old" |
| 24 hours   | \*ugur         | ⲟⲁ̄ⲣ/ⲟ̄ⲁ̄ⲇⲉ "night" | áwá, [pl]({sc}) àwàrìi "night" | (nergi) |
| six        | \*gorji        | ⲅⲟⲣⳝⲟ            | górjò        | korʃi |
| sorghum    | \*usi          | ⲙⲁⲇⲉ             | márée       | (uze) |
| sword[^96] |                | ⲡⲁⲇⲁⳡ            | fáráɲ       | (ʃíbídí) |
| white      | \*arr-e        | ⲁ̄ⲇⲱ             | KD aro[^97] | éelé (M. áddè)[^98] |

**~~Table 5. Alternation between intervocalic /r/ and /d/ in Nubian.~~**

[^96]: The Old Nubian and Nobiin forms are reflexes of Proto-NES *\*mbar-e* “spear.” The Birgid word is borrowed from Old Dongolawi *\*sibit,* ultimately from Egyptian *šf.t* “knife,” probably through a still unattested Meroitic word.
[^97]:  "White" is in Old Nubian ⳟⲟⲩⲗⲟⲩ, Nobiin *nùlù.* The adjective ⲁ̄ⲇⲱ is an Old Dongolawi word used in an Old Nubian letter. The modern form which is given here, *aro,* is Mattokki–Andaandi.
[^98]:  The reflex /l/ in Birgid is unexpected. It could actually be a flap [ɾ], which is acoustically very close to [l] but is cross-linguistically a frequent allophone of /d/ in intervocalic position, particularly in American English. However, it was transcribed as *l* by both McMichael and Thelwall (cf. Rilly, *Le méroïtique et sa famille linguistique,* p. 425). Accordingly, the Midob form, which has an undisputable *d,* has been added here.

As this vacillation between /r/ and /d/ is shared by languages that belong to different branches of the Nubian family, it was in all likelihood present in Proto-Nubian. As a result, the proto-form *\*ed* for “you [sg]({sc}),” which is suggested by Jakobi, is certainly possible. Likewise, it is possible that already in Proto-Nubian, a variant *\*er* was present.

In my previous reconstruction of Proto-Nubian, I assumed that the plural marker of the subject pronouns “we,” “you [pl]({sc}),” and “they” was *\*-gi* and consequently suggested *\*agi* for “we” and *\*igi* ~ *\*ugi* for “you [pl]({sc}).” That assumption was based on parallels with Taman and Nyima, where this morpheme is easily reconstructable. However, I could not account for the consonant /d/ in the Birgid reflexes *adi* and *udi.*[^99] If the Proto-Nubian pronoun of the second person singular is *\*ed,* the Birgid reflexes become perfectly regular and the Proto-Nubian plural marker is definitely *\*i.* This could be a development of Proto-NES *\*-gi,* which implies that *\*g* was already lost in Proto-Nubian, like in modern English *night* and *brought.* In conclusion, if Proto-Nubian “you [sg]({sc})” was indeed *\*ed,* a plural form *\*ud-i* is a consistent reconstruction. The initial vowel *\*u* instead of the expected *\*e* still has to be explained, but it is substantiated by the Old Nubian, Ajang,[^100] and Birgid reflexes.

[^99]: Rilly, *Le méroïtique et sa famille linguistique,* pp. 250–251 and n. 7.
[^100]: Jakobi, “Verbal Number and Transitivity in Karko,” t. 5.

This alternation between /d/ and /r/ is obvious when comparing Meroitic and Nubian. Several Meroitic words related to Nubian have /d/ where Nubian has /r/. This is for instance the case for the words for “brother,” in Meroitic *wide* and in Proto-Nubian *wer-i.*[^101] In addition, the Meroitic phoneme /d/ has two different realizations: alveolar [d] in initial position and after another consonant, retroflex [ɖ] in intervocalic position.[^x47] The retroflex consonant was acoustically so close to [r] that Egyptians and Greeks transcribed this sound with the grapheme “r.” That is why the capital of the kingdom, spelled *Medewi* in Meroitic, was written *Mrw.t* by the Egyptians and Μερόη by the Greeks.

[^x47]: Rilly, *Le méroïtique et sa famille linguistique,* p. 18.
[^101]: Ibid., pp. 367–368.

Consequently, the two Meroitic pronouns *are* and *deb* for the second person singular and plural, are reliable cognates of the Proto-Nubian forms *\*ed* and *\*ud-i.* The singular *are* was pronounced /ar/ ([5.2.1](#iv21)) and strongly resembles its Dongolawi counterpart *er.* The plural form *deb* was pronounced /deba/ and must derive from an older form *\*adeb.* For prosodic reasons, the initial vowel was weakened and finally dropped.[^102] Thus, the vacillation between /d/ and /r/, which was evidenced in the Nubian group, was also present in Meroitic, with /r/ in the singular and /d/ in the plural. Another possibility would be to that the original pronoun was *\*areb,* pronounced /areba/. This form would also have undergone the same apheresis, but, as /r/ can never be initial in Meroitic, it would have shifted to /d/, the closest stop to this vibrant. Finally, recall that /ba/ is the regular Meroitic reflex of Proto-SON *\*-gu,* which is known as plural marker for demonstratives in the eastern branch of the NES family.[^103] In this respect, the formation of the plural form in Meroitic differs not only from Proto-Nubian, where a plural marker *\*i* was used, but also from Proto-NES, where this morpheme was *\*gi*.

[^102]: Rilly, *La langue du Royaume de Méroé,* pp. 29–30, 289–291.
[^103]: Rilly, *Le méroïtique et sa famille linguistique,* p. 389. The eastern branch comprises Meroitic, Nubian, and Nara ([1](#intro)).

### The Second Person Singular Subject Pronoun in Personal Names {#iv24}

Most Meroitic personal names, and particularly the rulers’, are complex compound words. This resulted in names being unique most of the time, and it may actually have been the purpose of this complexity and length. Among the royal names, only Arkamani was used twice, a sharp contrast to the seven Mentuhoteps and the eleven Ramesseses of the Egyptian history. These Kushite royal names seem to have been the birth-names of the rulers, to which the name of a god, most frequently Amun, was possibly — but not systematically — added at the time of their ascension to the throne. In some of them, “Amun” is fully integrated into the syntax of the compound, so that it may originally have been present, be it an actual birth-name or a completely new name given to the ruler. For instance, Amannote-erike means “the one whom Amon of Thebes has begotten” and it is obvious that in this case, the god name was not added at a later stage. Many Kushite royal names are theophoric and probably fall within the Egyptian naming tradition. For example, “Natakamani” probably means “Amun is strong” and is the Meroitic counterpart of Egyptian Nakht-Amun or Amun-Nakht.

However, several royal names seem to follow a local tradition of naming an individual from physical features or temperament and can therefore be considered genuine birth-names. A stunning example of this tradition among private individuals is the name of the mother of a deceased woman from Sedeinga. She was called *Xmlowiteke,* which means “she who likes a good meal.”[^104] It can be either the birth-name of a greedy baby or a nickname given later during her lifetime. In the royal sphere, a name like Aspelta falls in the same tradition. The name of this Napatan king, written in Meroitic, was recently identified by the author among the graffiti of Great Enclosure in Musawwarat es-Sufra. It was written *Isplto*.[^x48] If the first segment *Is-* is the Meroitic cognate of Old Nubian ⲉⲓⲥ- “other,”[^105] it could mean “another is given” and refer, for example, to the birth of a second son, a possible heir to the throne. This name would be appropriate for a ruler like Aspelta, who succeeded his brother Anlamani at a very young age.

[^x48]: Rilly, “Graffiti for Gods and Kings.”"
[^104]:  This name occurs in the inscribed lintel II T 302 d2, found in 2017: see Rilly \& Francigny, “Closer to the Ancestors,” p. 70.
[^105]:  Nobiin *íccí,* Andaandi *ecce-l.* The verb *pl(e)-* "give, offer" is attested in the funerary bendiction D (Rilly, *La langue du Royaume de Méroé,* p. 173).

This naming tradition, in spite of the increasing influence of Islam, still exists in some parts of Sudan. In her study of the personal names among the Midob, a Nubian-speaking population of Northern Darfur, Abeer Bashir gives several examples of personal names whose meaning is connected with physical or social particularities, or with events that happened at the time these individuals were born:[^ex66]

[^ex66]: Bashir, “Address and Reference Terms in Midob,” pp. 136–137.

{{< gloss "(66)" >}}
{r} **Midob**
{r} *Óndìtè* ← *óndì* “camel” + *tè* “own” = “rich, lit. owner of a large herd of camels”
{r} *Úccí* ← *údí* “black” + suffix *-(i)cc* =  “person of black skin”
{r} *Ábágàlò* ← *ábá* “grandmother” + *gálò* “lost” = “who has lost his/her grandmother”
{{< /gloss >}}

Interestingly, two royal names belonging to this category of “contextual” names include a first element *are* which is obviously the same as the 2nd person pronoun identified above. They are the names of Queen Amanirenas (*Amnirense*) and king Amanakhareqerema (*Amnxreqerem*).[^106] The god names *Mni* “Amun” and *Amnxe* “Amanakh” were added to their original names when they received the royal crown of Kush.[^107] Their former names were *Arense* and *Areqerem* respectively. The vowel /a/ is never written in internal position (here after *Amni-* or *Amnax-*). However, it must have been present at the beginning of *Arense* and *Areqerem,* because, as addressed above in [5.2.1](#iv21) when analysing the compound *pwritrese* “the life from you,” /r/ can never be initial in Meroitic and its related languages.

[^106]:  Queen Amanirenas reigned around the end of the first c. BCE and the beginning of the first c. CE, Amanakhareqerema at the end of the first c. CE. For their reigns, see Rilly, “Histoire du Soudan, des origines à la chute du sultanat Fung,” pp. 242–252, 286–291 and Kuckertz, "Amanakhareqerema.”
[^107]: Amanakh, written *Amnx(e)* or *Mnx(e),* was obviously a hypostasis of Amun, but his identity remains a mystery. The name is not dubious; it appears in the names of king Amanakhabale and of many princes and queens. However, it is never independently attested and no Egyptian parallel is known so far.

The first element, *are* “you [sg]({sg})” is followed by the sequences “-nase” (written *nse*) in the first name and “-qerema” (written *qerem*) in the second. They display striking resemblances with the Nubian adjectives “tall” and "black.” In Old Nubian, these are ⳟⲁⲥⲥ- and ⲟⲩⲇⲙ- respectively, in Nobiin *nàssí* and *úrúm,* and in Andaandi *nosso* and *urumme*. In addition, the correspondence in initial position between Meroitic *qe/qo* /kʷu/ and Nubian /u/ is well attested, for instance between Meroitic *qore* “king” and Old Nubian ⲟⲩⲣⲟⲩ. The birth-name of the queen, namely *(A)rense* "Are-nase" would therefore mean “you are tall” and the birth-name of the king, namely *(A)reqerem* "Are-qerema" “you are black.” The elision of the copula (*-o* was expected in final position) is noteworthy, but this morpheme has so far been attested only with 3rd person constructions.[^109] The names were possibly given to them soon after they were born and described the physical appearance they had at this young age. When they ascended to the throne, these names were not considered incompatible with royal status: tall stature and black skin are, for example, features that were commonly associated with Osiris, the mythical first king of Egypt. The names of Amun or his hypostasis Amanakh were just added to their birth-names, according to the custom mentioned above.

[^108]:  The Old Nubian word ⲟⲩⲣⲟⲩ is neither borrowed from Meroitic nor from Late Egyptian *(p-)uro.* Its stem can be found in many other words, like ⲟⲩⲣⲁⲛ “chief” and is probably the word ⲟⲩⲣ “head” (Rilly, *Le méroïtique et sa famille linguistique,* p, 364). In Meroitic itself, alternative forms with initial *w-* instead of *q-* can be found locally (Rilly, *La langue du Royaume de Méroé,* pp. 39–42).
[^109]: The absence of copula (final *-o* expected) or of any verb “to be” (stem *ne-*) is certainly puzzling, but as this is the first time a sentence with a probable second person subject pronoun is attested, one cannot expect to find the same syntactic features as in sentences where the subject is a 3rd person and not a pronoun.
[^x109]: Rilly, *Le méroïtique et sa famille linguistique,* pp. 475, 486.

## The Prefixed Second Person Singular Marker in the Verbal Complex {#iv3}

We have previously seen that there were in Meroitic two types of person markers encoding the subject of the verb. First, independent pronouns such as *qo* “he, she” or *are* “you [sg]({sc}),” attested so far only in non-verbal clauses, and second, prefixed elements which are appended to the verbal compound, such as *ye-* “I” and *w-* “he/she(?),” in verbal clauses. For the 2nd person singular, a morpheme *d-*, which has remained unexplained for twenty years, is very likely the prefixed person marker that matches the independent pronoun are “you [sg]({sc}).”

In the 2000 issue of the *Meroitic Newsletter,* I published an article to show that a small corpus of Meroitic inscriptions on papyrus, leather strips, and ostraca, which were hitherto regarded as private letters, were actually protection spells.[^110] They were purchased by pilgrims from the temples, especially the temple of Amun in Qasr Ibrim, where the major part of these texts were found by the British team of the Egypt Exploration Society. I termed them “Amuletic Oracular Decrees,” after the name of the same type of texts attested in Egypt in the early first millennium BCE. Because of the rich vocabulary they include, describing all kind of misfortunes from which their owner will be protected, the translation of these inscriptions is still in an early stage. However, the scheme of the introductive parts of the texts is clear. They are divided in two groups according the prefixes of the verbal forms, *y(i)-* or *d-*.

[^110]: Rilly, “Deux exemples de décrets amulétiques oraculaires en méroïtique" and *La langue du Royaume de Méroé,* pp. 216–226.

{{< gloss "(67)" >}}
{r} **Meroitic**
{r} **Prefix** ***y(i)-*** (REM 0345, 1096, 1152(?), 1317/1168 (?), 1319, 1321, 1325, 1326)
{r} Formula A
{g} name-*i*,[pn-voc]({sc})|*wte-li*,life-[det]({sc})|*pke-li*,[n-det]({sc})|*y-irohe-se-l-o-wi*,[pm-vc-det-cop-emp]({sc})|
{r} Formula B
{r} God names and epithets
{r} Formula C
{g} *mlowi*,health|*y-ni*,[pm-vc]({sc})|*bnebeseni*,?|
{{< /gloss >}}

{{< gloss "(68)" >}}
{r} **Prefix** ***d-*** (REM 0361, 1174(?), 1236, 1322, 1323, 1324)
{r} Formula A
{g} noun-*l*,[n-det]({sc})|*wte-li*,life-[det]({sc})|*pke-li*,[n-det]({sc})|*d-irohe-se-l-o-wi*,[pm-vc-det-cop-emp]({sc})|
{r} Formula B
{r} God names and epithets
{r} Formula C
{g} *mlowi*,health|*d-n-se-l-o*,[pm-vc-det-cop]({sc})|*bnebeseni*,?|
{{< /gloss >}}

The decrees always begin with the mention of the beneficiaries in the vocative. They can be called either by their name or by their title. The verbal compound in formula A (*yirohe-se-l-o-wi/d-irohe-se-l-o-wi*) is partly obscure, but it is not an optative or an imperative ([5.1](#iv1)). It is a periphrastic form — probably with an aspectual or modal value — since it includes the determiner *-l* used as nominalizer, followed by the copula. Accordingly, an explicit personal marker is expected, more precisely a [2sg]([sc]), because of the vocative. Many texts are so damaged that it is impossible to know whether the initial vocative phrase included a name or a title, but each time it is preserved, the formulae with initial *d-* occur after the titles and those with initial *y(i)-* after the proper names. This initial *d-* is very likely the expected 2nd person subject prefix, a short version of the independent pronoun *are/\*ade* “you [sg]({sc})” or the singular of *de-b* “you [pl]({sc}),” without the plural suffix *-b.*

The verb used in formula A is *arohe,* which, in these oracular decrees, probably means “take under someone’s protection.”[^111] It can also signify “take control,” hence “take prisoner” in military contexts (see (20)). From the two nouns groups present in formula A, only *wte-li* "life(time)" is known. A very tentative translation of formula A with prefix *d-* would be “Oh you, the XXX, you shall (?) be protected for your lifetime and your ???.” The other prefix *y(i)-* remains an enigma. It is not certain that it can be also regarded as a personal marker. Since *yi-* is a late spelling for initial /i/, it may be present in the form of the sign *i* in the verbal compound *d-i-(a)rohe-se-l-o-wi.* In that case, *yiroheselowi* would be a variant of *d-irohe-se-l-o-wi* unmarked for person.

[^111]: The Old Nubian verb ⲁ̄ⲣⲟⲩ-ⲁⲅⲁⲣ “protect” is probably related to the Meroitic verb *arohe,* rather than borrowed, if the link suggested by Browne with ⲁ̄ⲣⲟⲩ “rain” is correct (Browne, *Old Nubian Dictionary,* p. 19).

# Conclusion

In conclusion, a general table of the personal markers that have been identified or merely hypothesised in this article is given below. The reader must keep in mind that some of those results are still tentative. However, they illustrate the significant advances that the linguistic comparison has recently made possible in the decipherment of the Meroitic texts.

|                                  | [1sg]({sc})      | [2sg]({sc})           | [3sg]({sc})       | [1pl]({sc})      | [2pl]({sc})      | [3pl]({sc})      |
| :---                             | :---     | :---          | :---      | :---     | :---     | :---     |
| **Independent Subject Pronoun**  | ?        | are (< \*ade) | qo        | ?        | deb      | qoleb    |
| **Prefixed Person Marker**       | (y)e-    | d-            | w-(?)     | ?        | ?        | ?        |
| **Possessive Pronoun**           | ?        | arese         | (a)qese   | ?        | debse    | (a)qebese |
| **Imperative Person Marker**     | –        | -∅            | –         | –        | -k(e)    | – |
| **Optative Person Marker**      | ?        | -∅-te         | ?         | ?        | -k(e)-te | ? |

**~~Table 6. Meroitic Person Markers~~**

|                | [sg]({sc})           | [pl]({sc})         |                       
| :---           | :---          | :---        |
| **Subject**    | -∅            | -b |
| **Object**     | -x(e)         | -bx(e) |

**~~Table 7. Meroitic Verbal Number Markers~~**

# Abbreviations

* […]: signs missing
* [*x*]: signs reconstructed
* *:* (colon): Meroitic word divider
* 1, 2, 3: 1st, 2nd, 3rd person marker
* [acc]({sc}): accusative
* [adj]({sc}): adjective
* [asp]({sc}): aspect marker
* [app]({sc}): applicative voice
* [cop]({sc}): copula
* [cont]({sc}): continuous (tense)
* [dat]({sc}): dative
* [dec]({sc}): declarative
* [det]({sc}): determiner
* [disc]({sc}): discursive (direct discourse marker)
* [du]({sc}): dual
* [emp]({sc}): so-called “emphatic particle” after the copula in Meroitic (*-wi*)
* [caus]({sc}): causative
* *FHN*: Eide et al., eds., *Fontes Historiae Nubiorum*
* [fin]({sc}): final element
* [frq]({sc}): frequentative
* [fut]({sc}): future tense
* [gen]({sc}): genitive (genitival postposition)
* [imp]({sc}): imperative
* [impp]({sc}): imperative particle (*-se*)
* IPA: International Phonetic Alphabet
* [ipfv]({sc}): imperfective
* [loc]({sc}): locative
* [n]({sc}): noun
* [o]({sc}): object
* [obj]({sc}): objective (= accusative/dative) marker
* [opt]({sc}): optative
* [pl]({sc}): plural
* [plc]({sc}): pluractional
* [prt1]({sc}): preterite 1
* [pm]({sc}): personal marker
* [pn]({sc}): person name
* [purp]({sc}): purposive
* REM: *Répertoire d’épigraphie méroïtique*
* [s]({sc}): subject
* [sg]({sc}): singular
* [tam]({sc}): tense, aspect, and mood markers
* [ver]({sc}): veridical
* [vnm]({sc}): verbal number marker
* [voc]({sc}): vocative suffix
* [vc]({sc}): verbal compound

# Bibliography

Armbruster, Charles. H. *![Dongolese Nubian: A Grammar.](bib:1513d4f3-3175-4ade-8e5e-b8e4738c3f11)* Cambridge: Cambridge University Press, 1960.  

Bashir, Abeer. ![“Address and Reference Terms in Midob (Darfur Nubian).”](bib:a03136b3-82d7-443d-874b-1c2168633274) *Dotawo: A Journal of Nubian Studies* 2 (2015): pp. 133–153.

Bossong, Georg. ![“Differential Object Marking in Romance and Beyond.”](bib:ff0fbcab-ec56-4e58-bb95-ffe3f22dd188) In *New Analyses in Romance Linguistics: Selected Papers from the XVIII Linguistic Symposium on Romance Languages, Urbana-Champaign, April 7–9, 1988,* edited by D. Wanner and D. A. Kibbee. Amsterdam: John Benjamins, 1991: pp. 143–170.

Browne, Gerald M. ![*Old Nubian Dictionary.*](bib:d9505774-ee71-4ab7-b076-96f26507ca47) Leuven: Peeters, 1996.

Carrier, Claude. ![“La stèle méroïtique d’Abratoye (Caire, J.E. n° 90008).”](bib:2ea61f1c-6ba6-4972-90a7-7a1740a571f1) *Meroitic Newsletter* 28 (2001): pp. 21–53.

Comrie, Bernard. ![*Language Universals and Linguistic Typology.*](bib:d80a3429-b176-4187-a774-35d473867ba3) Chicago: University of Chicago Press, 1981.

Cotte, Pierre. *Langage et linéarité.* Villeneuve d’Ascq: Presses universitaires du Septentrion, 1999.  

Creissels, Denis. ![*Syntaxe générale, une introduction typologique,* vol. 1: *Catégories et constructions.*](bib:bb96ade9-c486-46f0-b4c6-6518e9b4fb2a) Paris: Lavoisier, 2006.  

Creissels, Denis. ![*Syntaxe générale, une introduction typologique,* vol. 2: *La phrase.*](bib:983248b6-1e48-4634-8197-e51530dc182c) Paris: Lavoisier, 2006.  

Dimmendaal, Gerrit J. ![“Pluractionality and the Distribution of Number Marking across Categories.”](bib:96dbf206-7b8d-4392-883f-815930e01b33) In *Number: Constructions and Semantics. Case Studies From Africa, Amazonia, India & Oceania,* edited by Anne Storch and Gerrit J. Dimmendaal. Amsterdam: John Benjamins, 2014: pp. 57–76.

Dimmendaal, Gerrit J. ![“Tama.”](bib:d413fec6-b609-47a4-98f6-24b8a6d51c6d) In *Coding Participant Marking: Construction Types in Twelve African Languages,* edited by Gerrit J. Dimmendaal. Amsterdam: John Benjamins, 2009: pp. 305–333.

Eide, Tormod, Tomas Hägg, Richard Holton Pierce & László Török, eds. ![*Fontes Historiae Nubiorum: Textual Sources for the History of the Middle Nile Between the 8th Century BC and the 6th AD,* vol. I: *From the Eighth to the Mid-Fifth Century BC.*](bib:d29777ee-36f9-40ee-90c7-d998025c6037) Bergen: University of Bergen, Department of Classics, 1994.

Eide, Tormod, Tomas Hägg, Richard Holton Pierce & László Török, eds. ![*Fontes Historiae Nubiorum: Textual Sources for the History of the Middle Nile Between the 8th Century BC and the 6th AD,* vol. II: *From the Eighth to the Mid-Fifth Century BC.*](bib:5dde9b0f-bace-4502-b444-3776e2a0ecd1) Bergen: University of Bergen, Department of Classics, 1996.

Eide, Tormod, Tomas Hägg, Richard Holton Pierce & László Török, eds. ![*Fontes Historiae Nubiorum: Textual Sources for the History of the Middle Nile Between the 8th Century BC and the 6th AD,* vol. III: *From the First to the Sixth Century AD.*](bib:b3ac6690-51c7-4d9a-8656-81a3ffcffce0) Bergen: University of Bergen, Department of Classics, 1998.

El-Guzuuli, El-Shafie. !["The Uses and Orthography of the Verb 'Say' in Andaandi.”](bib:839d4394-15d4-44f8-a2ef-fb03df375d99) *Dotawo: A Journal of Nubian Studies* 2 (2015): pp. 91–107.

El-Nazir, Mustafa. *Major Word Categories in Mararit.* MA Thesis, University of Cologne, 2016.

Elsadig, Omda. *Major Word Categories in Nara.* MA Thesis, University of Cologne, 2016.

Ferrandino, Gilda. ![*Studio dei testi reali meroitici (III a.C.-IV d.C.). Approccio interdisciplinare per la comprensione dell’evoluzione di una cultura dell’Africa Subsahariana.*](bib:0626af57-e40a-4f1d-bf03-db0d8fa92468) PhD Thesis, L’Orientale University, Naples, 2016.

Gardiner, Alan H. ![*Egyptian Grammar: Being an Introduction to the Study of Hieroglyphs.*](bib:727afc5b-fdfa-4dc2-96ce-9b10de481f9b) 3rd edition. Cambridge: Cambridge Universite Press, 1957.

Gerven Oei, Vincent W.J. van. *A Reference Grammar of Old Nubian.* Leuven: Peeters, forthcoming.

Gerven Oei, Vincent W.J. van & El-Shafie El-Guzuuli. ![*The Miracle of Saint Mina.*](bib:c74149ed-2fb7-45ad-b5c2-63b1e14d57ff) Tirana: Uitgeverij, 2013.

Griffith, Francis Ll. ![*Karanòg: The Meroitic Inscriptions of Shablûl and Karanog.*](bib:c3e86d86-b969-4992-815d-054f9a6c0eac) Eckley B. Coxe Jr. Expedition to Nubia 6. Philadelphia: University of Pennsylvania, 1911.

Griffith, Francis Ll. ![“Meroitic Studies IV: The Great Stela of Prince Akinizaz (Continued).”](bib:8ad008e4-4dd1-44af-8ef6-514c6492382e) *Journal of Egyptian Archaeology* 4, nos. 2–3 (1917): pp. 159–173.

Haspelmath, Martin. ![“The Serial Verb Construction: Comparative Concept and Cross-linguistic Generalizations.”](bib:ffb02ad9-624d-4368-a33d-337d4b26cad6) *Language and Linguistics* 17, no. 3 (2016): pp. 291–319. [doi]({sc}): [10.1177/2397002215626895](https://doi.org/10.1177/2397002215626895).

Hintze, Fritz. *Beiträge zur meroitischen Grammatik.* Meroitica 3. Berlin: Akademie Verlag, 1979.

Hintze, Fritz. ![“Some Problems of Meroitic Philology.”](bib:bbc9d35d-def5-485b-afcf-0139ee6daac8) In *Sudan im Altertum: 1. Internationale Tagung für meroitistische Forschungen in Berlin 1971,* edited by Fritz Hintze. Meroitica  1 (1973): pp. 321–336.  

Hofmann, Inge. ![*Material für eine meroitische Grammatik.*](bib:e14847bd-2562-46d2-9fe4-05a8b266a1d7) Veröffentlichungen der Institute für Afrikanistik und Ägyptologie der Universität Wien 16. Vienna: Afro-Pub, 1981.

Jacquesson, François. ![*Les personnes. Morphosyntaxe et sémantique.*](bib:13676fec-abcc-4816-9a56-b4de42864eac) Paris: CNRS Éditions, 2008.  

Jakobi, Angelika. *Kordofan Nubian: A Synchronic and Diachronic Study.* Unpublished manuscript, 2001.

Jakobi Angelika. “The Nubian Subject Pronouns.” Paper presented to the 14th Nilo-Saharan Linguistics Colloquium, Vienna (hand-out), 2019.

Jakobi, Angelika. ![“Verbal Number and Transitivity in Karko (Kordofan Nubian).”](bib:c2e94b42-901e-44a4-a143-6bde5e2271cf) *Sprachtypologie und Universalienforschung* 70 (2017): pp. 117–142.

Jakobi, Angelika, Ali Ibrahim & Gumma Ibrahim Gulfan, “Verbal Number and Grammatical Relations in Tagle.” In *Proceedings of the 2nd Nuba Mountain Languages Conference, Paris 2014,* edited by Nicolas Quint and Stefano Manfredi. Forthcoming.

Khalil, Mohamed K. ![“The Verbal Plural Marker in Nobiin.”](bib:d49f8a89-7fff-4de7-bab6-b8ce57cb6db6) *Dotawo: A Journal of Nubian Studies* 2 (2015): pp. 59–71.

Kitchen, Kenneth A. *Ramesside Inscriptions Translated and Annotated: Notes and Comments, II.* Oxford: Wiley-Blackwell, 1999.  

Kuckertz, J. “Amanakhareqerema: A Meroitic King of the 1st Century AD.” *Der antike Sudan, Mitteilungen der Sudanarchäologischen Gesellschaft zu Berlin e.V* 29 (2018): pp. 119–144.  

Loprieno, Antonio. “The ‘King’s Novel’.” In *Ancient Egyptian Literature: History and Forms,* edited by Antonio Loprieno. Leiden: Brill, 1996: pp. 277–295.  

Lukas, Johannes. ![“Die Sprache der Sungor in Wadai (aus Nachtigal’s Nachlaß).”](bib:0cc6938e-b4fe-446d-9c40-5267dbee60c8) *Mitteilungen der Ausland-Hochschule an der Universität Berlin, dritte Abteilung. Afrikanische Studien* 41 (1938): pp. 171–246.

Millet, Nicholas B. ![“The Kharamadoye Inscription.”](bib:d32392b5-5c09-4584-b2f0-1650ccc8fae4) *Meroitic Newsletter* 13 (1973): pp. 31–49.

Millet, Nicholas B. ![“The Kharamandoye Inscription (MI 94) Revisited.”](bib:58187d0d-da04-4e6f-bf69-d98e1b47ce4d) *Meroitic Newsletter* 30 (2003): pp. 57–72.

Norton, Russell. ![“Number in Ama Verbs.”](bib:1892def2-7fbf-46ac-88ad-8dbb288c7e5a) *Occasional Papers in the Study of Sudanese Languages* 10 (2012): pp. 75–93.

Peust, Carsten. *Das Napatanische. Ein Ägyptischer Dialekt aus dem Nubien des späten ersten vorchristlichen Jahrtausends. Texte, Glossar, Grammatik.* Göttingen: Peust & Gutschmid, 1999.  

Reinisch, Leo. ![*Die Barea-Sprache.*](bib:56923e0c-c71c-4f98-ba96-755a2fae8842) Vienna: Wilhelm Braumüller, 1874.

Rilly, Claude. ![“Deux exemples de décrets amulétiques oraculaires en méroïtique: les ostraca REM 1317/1168 et REM 1319 de Shokan.”](bib:b42c2b81-9813-4fef-b9b7-dc1d5e17e9c6) *Meroitic Newsletter* 27 (2000): pp. 99–118.

Rilly, Claude. “Graffiti for Gods and Kings: The Meroitic Secondary Inscriptions of Musawwarat Es-Sufra: A Preliminary Study.” *Der Antike Sudan* 31 (forthcoming).

Rilly, Claude. “Histoire du Soudan, des origines à la chute du sultanat Fung.” In *Histoire et Civilisations du Soudan. De la préhistoire à nos jours,* edited by Olivier Cabon. Paris: Soleb, 2017: pp. 25–445.  

Rilly, Claude. ![*La langue du Royaume de Méroé: Un panorama de la plus ancienne culture écrite d'Afrique subsaharienne.*](bib:f5ca39d3-8981-4729-9d5d-a3d14a7e2b8b) Paris: Champion, 2007.

Rilly, Claude. ![*Le méroïtique et sa famille linguistique.*](bib:2ca95718-79e8-40cd-939a-5dd0e3bbd07e) Leuven: Peeters, 2010.

Rilly, Claude. ![“‘Les chouettes ont des oreilles’. L’inscription méroïtique hiéroglyphique d’el-Hobagi REM 1222.”](bib:256121f6-25bf-42b1-a585-347ad0959b5a) In *La pioche et la plume. Autour du Soudan, du Liban et de la Jordanie. Hommages archéologiques à Patrice Lenoble,* edited by Vincent Rondot, Frédéric Alpi & François Villeneuve. Paris: Presses de l'université Paris-Sorbonne, 2011: pp. 481–499.

Rilly, Claude. *Répertoire d’épigraphie méroïtique. Analyse des inscriptions publiées. Tome IV. REM 0001 à REM 0073.* Habilitation Thesis, École Pratique des Hautes Études. Paris, 2018.

Rilly, Claude. “The Meroitic Inscriptions of Temple Naga 200.” In Josefine Kuckertz, *Naga: Temple 200 – Wall Decoration.* Berlin: Ugarit Verlag, forthcoming: pp. 283–328.

Rilly, Claude. ![“The Wadi Howar Diaspora and Its Role in the Spread of East Sudanic Languages from the Fourth to the First Millenia BCE.”](bib:69f65bbb-d820-4147-aa87-a49ab63c594a) In *Reconstruction et classification généalogique: tendances actuelles,* edited by Konstantin Pozdniakov.  Paris: Faits de Langue, 2016: pp. 151–163.

Rilly, Claude. ![“Upon Hintze's Shoulders: Today's Challenges in the Translation of Meroitic.”](bib:cd26e243-b00e-4909-ba80-4d8aec90197a) *Der Antike Sudan* 28 (2017): pp. 25–33.

Rilly, Claude & Vincent Francigny. ![“Excavations of the French Archaeological Mission in Sedeinga, Campaign 2011.”](bib:83be83df-8ae9-404c-bae0-7a997522ba86) *Sudan & Nubia* 16 (2012): pp. 60–71.

Rilly, Claude & Vincent Francigny. ![“Closer to the Ancestors: Excavations of the French Mission in Sedeinga 2013–2017.”](bib:c0cca1b6-f1b5-44db-977a-d39fa2e96250) *Sudan & Nubia* 22 (2018): pp. 65–74.

Schenkel, Wolfgang. !“[Meroitisches und Barya-Verb: Versuch einer Bestimmung der Tempusbildung der Meroitischen.”](bib:3e5bce37-1c4a-4b0d-b501-6e3a4952a97c) *Meroitic Newsletter* 11 (1972): pp. 1–16.

Schenkel, Wolfgang. ![“Zur Struktur des Verbalkomplexes in den Schlußformel der meroitischen Totentexte.”](bib:dd904845-ed58-454c-9a2a-83ea244ba1c8) *Meroitic Newsletter* 12 (1973): pp. 2–22.

Spalinger, Anthony. “Königsnovelle and Performance.” In *Times, Signs and Pyramids: Studies in Honour of Miroslav Verner on the Occasion of His Seventieth Birthday,* edited by Vivienne G. Callender et al. Prague: Faculty of Arts, Charles University of Prague, 2011: pp. 351–374.  

Stevenson, Roland. ![*Grammar of the Nyimang Language (Nuba Mountains).*](bib:5d589571-e485-4ed7-8c2e-01b2091c0349) Unpublished typescript, 1938.

Stevenson, Roland, Franz Rottland & Angelika Jakobi. ![“The Verb in Nyimang and Dinik.”](bib:976903a7-940f-4513-913f-aa8c060cfed1) *Afrikanistische Arbeitspapiere* 32 (1992): pp. 5–64.

Thompson, E. David. ![“Nera.”](bib:e69dc118-553c-4e3b-9e42-0041275bc01c) In *The Non-Semitic Languages of Ethiopia,* edited by M. Lionel Bender. East Lansing: African Studies Center, Michigan State University, 1976: pp. 484–494.

Vanhove, Martine. ![*Le bedja.*](bib:83967421-5ec9-4700-bc1e-832762b73c4c) Leuven: Peeters, 2017.

Weiss, Doris. ![*Phonologie et morphosyntaxe du maba.*](bib:1cf0e83e-6814-4b62-b827-20f14854c680) PhD Thesis, Université Lumière-Lyon 2, 2009.

Werner, Roland. ![*Grammatik des Nobiin (Nilnubisch). Pho­no­logie, Tonologie und Morphologie.*](bib:d5354ede-90ab-4f7b-baa2-488cfbbf06ec) Hamburg: Helmut Buske, 1987.

Werner, Roland. ![*Tìdn-áal: A Study of Midob (Darfur-Nubian).*](bib:56735ece-24da-4960-9101-ba484f7e57f7) Berlin: Dietrich Reimer, 1993.

Zibelius, Karola. ![*Der Löwentempel von Naq‘a in der Butana (Sudan). IV: Die Inschriften.*](bib:4ce50a0a-2d4c-4b91-9f49-cbdfe84bc77b) Wiesbaden: Ludwig Reichert, 1983.  
