---
title: "Restoring “Nile-Nubian”: How to Balance Lexicostatistics and Etymology in Historical Research on Nubian Languages"
authors: ["georgestarostin.md"]
abstract: "The paper offers a critical analysis of the proposal to dismantle the genetic unity of the so-called Nile-Nubian languages by positioning one of its former constituents, the Nobiin language, as the earliest offshoot from the Common Nubian stem. Combining straightforward lexicostatistical methodology with more scrupulous etymological analysis of the material, I argue that the evidence in favor of the hypothesis that Nobiin is the earliest offshoot may and, in fact, should rather be interpreted as evidence for a strong lexical substrate in Nobiin, accounting for its accelerated rate of change in comparison to the closely related Kenuzi–Dongolawi (Mattokki–Andaandi) cluster."
keywords: ["comparative linguistics", "Nilo-Saharan", "glottochronology", "lexicostatistics", "Nubian", "West Nilotic"]
---

# Introduction

Although there has never been any serious disagreement on which languages constitute the Nubian family, its internal classification has been continuously refined and revised, due to such factors as the overall complexity of the processes of linguistic divergence and convergence in the "Sudanic" area of Africa; constant influx of new data that forces scholars to reevaluate former assumptions; and lack of scholarly agreement on what types of data provide the best arguments for language classification.

Traditionally, four main units have been recognized within Nubian[^1]:

* Nile-Nubian, consisting of the closely related Kenuzi–Dongolawi (Mattokki–Andaandi) dialect cluster and the somewhat more distant Nobiin (= Fadidja–Mahas) cluster;
* Kordofan Nubian, or Hill Nubian, consisting of numerous (and generally poorly studied, although the situation has significantly improved in the past decade) languages such as Dilling, Karko, Wali, Kadaru, etc.;
* Birgid (Birked, Birged), now-extinct , formerly spoken in Darfur;
* Midob (Meidob), also in Darfur.

This is, for instance, the default classification model adopted in Joseph Greenbergʼs general classification of the languages of Africa,[^2] and for a long time it was accepted in almost every piece of research on the history of Nubian languages.

[^1]: Bechhaus-Gerst, “Nile-Nubian Reconsidered,” p. 85.
[^2]: Greenberg, *The Languages of Africa,* p. 84.

More recently, however, an important and challenging hypothesis on a re-classification of Nubian has been advanced by Marianne Bechhaus-Gerst.[^3]  Having conducted a detailed lexicostatistical study of a representative batch of Nubian lects, she made the important observation that, while the percentage of common matches between the two main components of Nile-Nubian is indeed very high (70%), Kenuzi–Dongolawi consistently shows a much higher percentage in common with the other three branches of Nubian than Nobiin (**Table 1**).

[^3]: Bechhaus-Gerst, “Nile-Nubian Reconsidered”; Bechhaus-Gerst, *Sprachwandel durch Sprachkontakt am Beispiel des Nubischen im Niltal*; Bechhaus-Gerst, *The (Hi)story of Nobiin*.


|            | Midob | Birgid | Kadaru | Debri | Dilling | K/D |
| ---        | :---    | :---    | :---    | :---   | :---     | :--- |
| **K/D**    | 54%     | 48%     | 58%     | 57%    | 58%      | |   
| **Nobiin** | 40%     | 37%     | 43%     | 41%    | 43%      | 70% |

**~~Table 1. Part of the lexicostatistical matrix for Nubian[^t1]~~**

[^t1]: Bechhaus-Gerst, *Sprachwandel durch Sprachkontakt am Beispiel des Nubischen im Niltal,* p. 88.

In Bechhaus-Gerstʼs view, such a discrepancy could only be interpreted as evidence of Kenuzi–Dongolawi and Nobiin not sharing an intermediate common "Nile-Nubian" ancestor (if they did share one, its modern descendants should be expected to have more or less the same percentages of matches with the other Nubian subgroups). Instead, she proposed independent lines of development for the two dialect clusters, positioning Nobiin as not just a separate branch of Nubian, but actually the earliest segregating branch of Nubian. Consequently, in her standard historical scenario described at length in two monographs, there was not one, but two separate migrations into the Nile Valley from the original Nubian homeland (somewhere in South Kordofan/Darfur) — one approximately around 1,500 BCE (the ancestors of modern Nobiin-speaking people), and one around the beginning of the Common Era (speakers of Kenuzi–Dongolawi). As for the multiple exclusive similarities between Nobiin and Kenuzi–Dongolawi, these were explained away as results of "intensive language contact.”[^4] The lexicostatistical evidence was further supported by the analysis of certain phonetic and grammatical peculiarities of Nobiin that separate it from Kenuzi–Dongolawi; however, as of today it is the lexical specificity of Nobiin that remains at the core of the argument.

[^4]:  Bechhaus-Gerst, *The (Hi)story of Nobiin,* p. 22.

Bechhaus-Gerstʼs classificatory model, with its important implications not only for the history of Nubian peoples, but also for the theoretical and methodological development of historical and areal linguistics in general, remains somewhat controversial. While it has been embraced in the recent editions of such influential online language catalogs as [Ethnologue](https://www.ethnologue.com/subgroups/nubian) and [Glottolog](https://glottolog.org/resource/languoid/id/nubi1251) and is often quoted as an important example of convergent linguistic processes in Africa,[^5] specialists in the field often remain undecided,[^6] and it is concluded in the most recent handbook on African linguistics that "the internal classification of Nubian remains unclear.”[^7] One of the most vocal opponents of the new model is Claude Rilly, whose research on the reconstruction of Proto-Nubian (in conjunction with his work on the historical relations and genetic affiliation of Meroitic) and investigation into Bechhaus-Gerstʼs evidence has led him to an even stronger endorsement of the Nile-Nubian hypothesis than ever before.[^8]

[^5]:  E.g., Heine & Kuteva, "Convergence and Divergence in the Development of African Languages.”
[^6]:  E.g., Jakobi, "The Loss of Syllable-final Proto-Nu­bian Consonants.”
[^7]:  Güldemann, "Historical Linguistics and Genealogical Language Classification in Africa,” p. 283.
[^8]:  Rilly, *Le méroïtique et sa famille linguistique,* pp. 211–288; Rilly, "Language and Ethnicity in Ancient Sudan,” pp. 1180–1183. We will return to Rillyʼs arguments in the final section of this paper.

While in theory there is nothing impossible about the historical scenario suggested by Bechhaus-Gerst, in practice the idea that language A, rather distantly related to language B, could undergo a serious convergent development over an approximately 1,000-year long period (from the supposed migration of Kenuzi–Dongolawi into the Nile Valley and up to the attestation of the first texts in Old Nubian, which already share most of the important features of modern Nobiin), to the point where language A can easily be misclassified even by specialists as belonging to the same group as language B, seems rather far-fetched. At the very least, it would seem to make perfect sense, before adopting it wholeheartedly, to look for alternate solutions that might yield a more satisfactory explanation to the odd deviations found in the data.

Let us look again more closely (**Table 2**) at the lexicostatistical evidence, reducing it, for the sake of simple clarity, to percentages of matches observed in a "triangle" consisting of Kenuzi–Dongolawi, Nobiin, and one other Nubian language that is universally recognized as belonging to a very distinct and specific subbranch of the family — Midob. Comparative data are given from the older study by Bechhaus-Gerst and my own, more recent examination of the basic lexicon evidence.[^9]

[^9]:  Starostin, *Языки Африки,* pp. 24–95.

|            | Nobiin | Midob |
| ---        | :---    | :--- |
| **K/D**    | 70%    | 54% |
| **Nobiin** |        | 40% |

**~~Table 2a. Lexicostatistical relations between Nile-Nubian and Midob \(Bechhaus-Gerst\)[^t2a]~~**

|            | Nobiin | Midob |
| ---        | :---    | :--- |
| **K/D**    | 66%    | 57% |
| **Nobiin** |        | 51% |

**~~Table 2b. Lexicostatistical relations between Nile-Nubian and Midob \(Starostin\)[^t2b]~~**

[^t2a]: Bechhaus-Gerst, “Nile-Nubian Reconsidered”
[^t2b]: Starostin, *Языки Африки*.

The significant differences in figures between two instances of lexicostatistical calculations are explained by a number of factors (slightly divergent Swadesh-type lists; different etymologizations of several items on the list; exclusion of transparent recent loans from Arabic in Starostinʼs model). Nevertheless, the obvious problem does not go away in the second model: Midob clearly shares a significantly larger number of cognates with K/D than with Nobiin — a fact that directly contradicts the K/D–Nobiin proximity on the Nubian phylogenetic tree. The situation remains the same if we substitute Midob with any other non-Nile-Nubian language, such as Birgid or any of the multiple Hill Nubian idioms.

The important thing is that there are actually two possible	reasons for this discrepancy in the lexicostatistical matrix. One, endorsed by Bechhaus-Gerst, is that the K/D–Nobiin number is incorrectly increased by the addition of a large number of items that have not been inherited from a common ancestor, but actually borrowed from Nobiin into K/D. An alternate scenario, however, is that the active recipient was Nobiin, except that the donor was not K/D — rather, a certain percentage of Nobiin basic lexicon could have been borrowed from a third, possibly unidentified source, over a relatively short period of time, which resulted in lowering the percentage of Nobiin matches with *all* other Nubian languages.

Thus, for instance, if we assume (or, better still, somehow manage to prove) that Nobiin borrowed 6% of the Swadesh wordlist (i.e., 6 words on the 100-item list) from this third source, exclusion of these words from lexicostatistical calculation would generally normalize the matrix, increasing the overall percentage for the K/D–Nobiin and Nobiin–Midob pairs, but not for the K/D–Midob pair.

The tricky part in investigating this situation is determining the status of those Nobiin words on the Swadesh list that it does not share with K/D. If the phylogenetic structure of the entire Nubian group is such that Nobiin represents the very first branch to be split off from the main body of the tree, as in Bechhaus-Gerstʼs model (**fig. 1**), then we would expect a certain portion of the Swadesh wordlist in Nobiin to be represented by the following two groups of words:

* archaic Nobiin retentions that have been preserved in their original meaning in that subgroup only, replaced by innovations in the intermediate common ancestor of Midob, Birgid, K/D, and Hill Nubian;
* conversely, more recent Nobiin innovations that took place after the original separation of Nobiin; in this case, the Nobiin equivalent of the Swadesh meaning would also be opposed to the form reconstructible for the common ancestor of the remaining four branches, but would not reflect the original Proto-Nubian situation.

![The revised classification of Nubian according to Bechhaus-Gerst](../static/images/bechhaus.png "The revised classification of Nubian according to Bechhaus-Gerst")

**~~Fig. 1. The revised classification of Nubian according to Bechhaus-Gerst~~**

Indeed, we have a large share of Nobiin basic words that set it apart from every other Nubian languages (see the more than 30 items in [III](#iii) of the list below), but how can we distinguish retentions from innovations? If the word in question has no etymological cognates in any other Nubian language, then in most cases such a distinction is impossible.[^10] However, if the retention or innovation in question was not accompanied by the total elimination of the root morpheme, but rather involved a semantic shift, then investigating the situation from an etymo­logical point of view may shed some significant light on the matter. In general, the more lexico­statistical discrepancies we find between Nobiin and the rest of Nubian where the Nobiin item has a Common Nubian etymology, the better the case for the "early separation of Nobiin" hypothesis; the more "strange" words we find in Nobiin whose etymological parallels in the other Nubian languages are highly questionable or non-existent, the stronger the case for the "pre-Nobiin substrate" hypothesis.

[^10]:  One possible argument in this case would be to rely on data from external comparison. Thus, if we agree that Nubian belongs to the Northern branch of the Eastern Sudanic family, with the Nara language and the Taman group as its closest relatives (Rilly, *Le méroïtique et sa famille linguistique*; Starostin, *Языки Африки*), then, in those cases where Nobiin data is opposed to the data of all other Nubian languages, it is the word that finds better etymological parallels in Nara and Tama that should be logically regarded as the Proto-Nubian equivalent. However, in order to avoid circularity or the additional problems that one runs into while investigating chronologically distant language relationship, I intentionally restrict the subject matter of this paper to internal Nubian data only.

In order to resolve this issue, below I offer a concise and slightly condensed etymological analysis of the entire 100-item Swadesh wordlist for modern Nobiin.[^11] The lexical items are classified into three groups:

[^11]:  Reasons of volume, unfortunately, do not allow to go into sufficient details on many of the more complicated cases. A subset of 50 words, representing the most stable (on average) Swadesh items, has been analyzed in detail and published (in Russian) in Starostin, *Языки Африки,* pp. 224–295. A complete 100-item wordlist reconstructed for Proto-Nubian, with detailed notes on phonetics, semantics, and distribution, is scheduled to be added to the already available annotated 100-item wordlists for ten Nubian languages, published as part of [The Global Lexicostatistical Database](http://starling.rinet.ru/new100).

* 	I. Lexicostatistical matches (i.e., cases where the exact same lexical root is preserved in the exact same Swadesh meaning, without semantic shifts) between Nobiin and K/D. These are further divided into subcategories I.1: common Nubian roots, also found in the same meaning in all or some other branches of Nubian beyond Nile-Nubian; and I.2: exclusive isoglosses between Nobiin and K/D that may be either retentions from Proto-Nubian, lost in all other branches, or Nile-Nubian innovations replacing more archaic words. In either case, these data have no bearing on the issue of Nobiinʼs uniqueness (although isoglosses in I.2 may be used to strengthen the case for Nile-Nubian).
* 	II. Lexicostatistical matches between Nobiin and other Nubian branches (Midob, Birgid, Hill Nubian) that exclude K/D. Upon first sight, such isoglosses might seem to weaken the Nile-Nubian connection, but in reality they are not highly significant, as the K/D equivalents of the respective meanings may simply represent recent lexical innovations that took place already after the split of Nile-Nubian.
* 	III. Nobiin-exclusive lexicostatistical items that have a common Nubian etymology (III.1) or do not have any parallels in any of the other attested Nubian languages (III.2). This is the most significant group of cases, with items in subgroup III.1 testifying in favor of the early separation hypothesis (particularly if the lexicostatistical meaning in Nobiin can be shown to be archaic), and items in subgroup III.2 favoring the substrate explanation. Needless to say, it is the items in this group that will be receiving the most extensive commentary.[^12]

[^12]:  Note on the data sources: for reasons of volume, I do not include all available data in the etymologies. Nobiin (N) forms are quoted based on Werner's *Grammatik des Nobiin*; if the word is missing from Wernerʼs relatively short glossary, additional forms may be drawn upon from either older sources, such as Lepsius's *Nubische Grammatik*, or newer ones, e.g., Khalil's *Wörterbuch der nubischen Sprache* (unfortunately, Khalilʼs dictionary is unusable as a lexicostatistical source due to its unwarranted omission of Arabic borrowings and conflation of various early sources). The ancient forms of Old Nubian (ON) are taken from Gerald Browneʼs *Old Nubian Dictionary.*

  	Data on the other languages are taken from the most comprehensive published dictionaries, vocabularies, and/or wordlists and are quoted as follows: Kenuzi (K) — Hofmann, *Nubisches Wörterverzeichnis*; Dongolawi (D) — Armbruster, *Dongolese Nubian*; Midob (M) — Werner, *Tìdn-áal*; Birgid (B) — Thelwall, "A Birgid Vocabulary List”; Dilling (Dl) — Kauczor, *Die Bergnubische Sprache*. Hill Nubian data other than Dilling are used sparingly, only when it is necessary to specify the distribution of a given item; occasional forms from such languages as Kadaru, Debri, Karko, and Wali are quoted from wordlists published in Thelwall, "Lexicostatistical Relations between Nubian, Daju and Dinka" and Krell, *Rapid Appraisal Sociolinguisyic Survey among Ama, Karko, and Wali Language Groups*.

    Proto-Nubian forms are largely based on the system of correspondences that was originally laid out in Marianne Bechhaus-Gerstʼs reconstruction of Proto-Nubian phonology in "Sprachliche und his­torische Rekonstruktionen im Bereich des Nubischen unter beson­de­rer Berücksichtigung des Nilnubischen,” but with a number of emendations introduced in Starostin, *Языки Африки*. Since this study is more concerned with issues of cognate distribution than those of phonological reconstruction and phonetic interpretation, I will refrain from reproducing full tables of phonetic correspondences, but brief notes on peculiarities of reflexes of certain PN phonemes in certain Nubian languages will be given for those cases where etymological cognacy is not obvious or is disputable from the standard viewpoint of the neogrammarian paradigm.

# 100-Item Swadesh List for Nubian: The Data

## I. Nobiin/Kenuzi–Dongolawi Isoglosses

### I.1. General Nubian Isoglosses {#i1}

* “ashes”: N *ùbúr-tí*, K/D *ubur-ti* (= M *úfù-dì*, B *ubur-ti*, etc.).
*	“belly”: N *tùː*, K/D *tuː* (= M *tə̀ː*, B *tuː*, etc.).
* “bird”: N *kawar-ti*, K *kawir-te*, D *kawɪr-tɛ* (= M *àːbéd-dí*, B *kwar-ti*, etc.).
*	“bite”: N *àc-*, K/D *acc-* (= M *àcc-*, Dl *aɟ*, etc.).
*	“black”: N *úrúm*, K/D *urumm*- (= M *údí*, B *úːdè*, Dl *uri*, etc.). ◊ The Nile-Nubian form is an original nominal derivate (*\*ur-um* “darkness”) from the adjectival stem *\*ur*- “black.”
* “bone”: N *gìsìr*, K *kiːd*, D *kɪhɪːd* (= M *ə̀ːdí*, B *kìzídì*, etc.). ◊ Voiced *g-* in Nile-Nubian is irregular, possibly as a result of assimilation (< *\*kizir*) or contamination.[^13]
* “breast”: N *óg*, K/D *og* (= M *ə́ː*, B *ogi*, Dl *ɔki*, etc.).
* “claw/nail”: N *sun-ti*, K *sutti*, D *sun-tɪ* (= M *súŋún-dí*, B *sun-di*, etc.).
* “cold”: N *ór-kí*, K *oroːke-l*, D *oroːfɛ-l* (= Wali *ór-kō*, Debri *worr-uŋ*, etc.).
* “die”: N *dí-*, K/D *diː* (= M *tíː-*, B *ti-n-*, Dl *ti*, etc.).
* “drink”: N *ní-*, K/D *niː* (= M *tìː-*, B *ɲiː*, Dl *di*, etc.). ◊ From PN *\*ni-* with regular denasalization in M and Hill Nubian languages.
* “ear”: N *úkkí*, K/D *ulug* (= Dl *ulɟe*, M *úlgí*, etc.). ◊ From PN *\*ulg-i*. The Nobiin form goes back to ON *ul(u)g-* and shows a specific phonetic development (*\*-lg-* > *-kk-*); the latter, however, can in no way be construed as an archaism.
* (?) “eye”: N *máːɲ* (= ON *maɲ-*), D *mɪssɪ*, K *missi* (= M *pì-dì*). ◊ A complicated case. The K/D forms perfectly correspond to M *pì-dì*, going back to PN *\*miC-ti*, where *-C-* is one of several consonants capable of triggering the lenition *\*-t- > -s-* in K/D. If *\*-C- = \*-ɲ-*, then the forms are further comparable with N *máːɲ*, and we are either dealing with a one-time vocalic dissimilation *\*miɲ > \*maɲ* in N or two independent assimilations (*\*maɲ > miɲ-*) in M and K/D, respectively. Alternately, the N form may be completely unrelated to the K/D–M isogloss, in which case the word should be moved to group III.2, since a separate form like *\*maɲ* “eye” would have no Common Nubian etymology of its own.
* “fire”: N *íːg*, K *iːg*, D *ɪːg* (= Dl *ike*, Debri *ika*; probably also B *uzug*, M *ússí*). ◊ The forms in B and M are comparable if the original stem is to be reconstructed as *\*usi-gi*, with regular elimination of intervocalic *\*-s-* in Hill and Nile Nubian. The vocalism is still problematic, but even without the B and M forms, parallels in Hill Nubian clearly show that the Nile-Nubian items represent an inherited archaism.
* “foot”: N *óːy*, K *ossi*, D *oss(ɪ)* (= B *ose*, M *òttì*). ◊ All forms go back to PN *\*oy(-ti)*.
* “give”: N *tèː-r*, K *ti-r*, D *tɪ-r* (= M *tì-*, B *teː-n*, Dl *ti*, etc.).
* “green”: N *déssí*, K *desse ~ dosse*, D *dɛssɛ* (= M *tèssé*, B *teːze*, Dl *teɟe*).
* “hand”: N *èd-dì* (= ON *ey-*), K *iː*, D *ɪː* (= M *ə̀ssì*, B *essi*, Dl *iši*, etc.). ◊ All forms go back to PN *\*əsi ~ \*əsi-ti*.
* “head”: N *ùr*, K/D *ur* (= M *òr*, B *úr*, Dl *or*, etc.).
* “heart”: N *áy* (= ON *ai-l-*), K/D *aː* (= B *ai-di*, Dl *a-l*, etc.).
* “horn”: N *nìːšì*, K *nišši*, D *nɪšši* (= M *kə́ːcí*, B *ŋis-ti*, D *dɔ-ti*). ◊ All forms go back to PN *\*ŋəɟi*.[^horn]
* “I”: N *ày*, K/D *ay* (= M *ə́y*, Dl *ɛ*, etc.).
* “kill”: N *fáːy-èːr*, K *beː*, D *bɛː* (= M *pé-r-*, B *fi-laːle*).
* “knee”: N *kúr-tí*, K *kur-ti*, D *kur-tɪ* (= M *ùrú-d*, B *kur-ti*, etc.).
* “know”: N *ìrbé-èr* (= ON *i- ~ ia-r- ~ ie-r-*), K *iy-ir* (= M *ìːyá-*, D *i-er-*). ◊ The stem in modern Nobiin seems to be an extended form of the original stem, though the nature of the extension is not quite clear.
* “long”: N *nàssí*, K *nosso*, D *noso* (= M *tàssè*, B *nizze*, Dl *dɔɟi*, etc.). ◊ Goes back to PN *\*nossi*, although vocalic correspondences are somewhat irregular.
* “louse”: N *issi*, K *issi*, D *ɪssɪ* (= M *ìːdì*, Dl *iti-d*, etc.).
* “moon”: N *ùn-áttí*, K *un-atti ~ an-atti*, D *un-attɪ* (= Dl *nɔn-ti*, Wali *ūm-tù* etc.). ◊ The Nile-Nubian root is *\*un-*; there are some problems with Hill Nubian forms, such as explaining the initial *n-* in Dl, but overall, there is no reason to doubt the common origin of all these items.
* “neck”: N *íyyí*, K *eyye*, D *ɛyyɛ* (= Kadaru *eː*). ◊ Not clear if M *éːr* “neck” also belongs here (with a suffix?), but the Kadaru form is sufficient by itself to trace the word back to PN *\*eyi*.
* “not”: N *-mùːn*, K/D *-mun-* (= Dl *-min*, B *-m-*, etc.). ◊ A common Nubian negative verbal stem (interestingly, not attested in M, which instead uses the suffixal morpheme *-áː-* for negation, something that could be construed as an archaism and used as a serious argument against early separation of Nobiin).
* “one”: N *wèːr ~ wèːl*, K *weːr*, D *wɛːr* (= M *pàr-*, B *meːl-*, Dl *be*, etc.).
* “person”: N *íd* (= M *ír*, Dl *id*, etc.). ◊ The old Nubian root is largely replaced by Arabisms in K/D (K *zoːl*, D *adɛm*), but the word *ɪd* is still used in D as an archaism or in various idiomatic formations.
* “rain”: N *áwwí*, K *a-nn-essi* (< *\*aru-n-essi* “rain-waterʼ), D *aru* (= M *áré*, B *aːle*, Dl *are*, etc.). ◊ The development *\*-r- > -w-* in N is regular before *\*-i*.[^14]
* “red”: N *géːl*, K *geːle*, D *gɛːlɛ* (= M *kéːlé*, B *keːle*, Dl *kele*, etc.).
* “sand”: N *síw*, K *siːw*, D *sɪu* (= Dl *šu-d*, Debri *šu-du*, etc.).
* “see”: N *nèːl*, K/D *nal* (= M *kə̀l-*, B *ell-*, Dl *gel*, Kadaru *ŋeli*, etc.). ◊ All forms go back to PN *\*ŋali-*.
* “sit”: (a) N *àːg-*, K/D *aːg* (= M *àːg-*, Dl *ak-i*, etc.); (b) N *tìːg-*, K *teːg*, D *tɛːg* (= M *tə́g-*). ◊ Two roots with very close semantics, both easily reconstructible back to PN.
* “sleep”: N *nèːr-*, K *neːr*, D *nɛːr* (= M *kèrà-*, B *neːri*, Dl *ɟer*, etc.). ◊ All forms go back to PN *\*ɲɛːr-*.
* “star”: N *wìnɟì*, K *wissi*, D *wɪssɪ* (= M *òɲè-dì*, B *waːɲ-di*, Kadaru *wonɔ-ntu*, etc.). ◊ There are some problems with the reconstruction, but it is possible that all forms go back to PN *\*wiɲ- ~ \*waɲ-*; at the very least, *\*wiɲ-ti* “star” is definitely reconstructible for Proto-Nile-Nubian.
* “sun”: N *màšà* (= ON *mašal-*), K *masil*, D *masɪl* (= M *pàssàr*). ◊ The isogloss with M confirms PN status, although some phonetic peculiarities (such as the irregular *-š-* in N) as well as the attestation of the term *maša ~ masa* in Meroitic, where it denotes a supreme deity[^sun] indirectly suggest a possible areal isogloss; if so, an alternate candidate for PN “sun” would be *\*eːs-* > B *iːzi*, Dl *eɟ* “sun,” further related to M *èːsì* “heat; midday,” K *eːs* id., D *ɛːs* “afternoon.” In either case, N still aligns with K/D rather than anything else.
* you (sg.): N *ì-r*, K *e-r*, D *ɛ-r* (= M *íː-n*, B *e-di*, Dl *a*, Karko *yā*, etc.). ◊ Although all the forms are related (going back to PN *\*i-*), N is noticeably closer to K/D in terms of morphological structure (with the direct stem marker *\*-r*).
* “tongue”: N *nàr*, K *ned*, D *nɛd* (= M *kàda-ŋì*, B *nat-ti*, Dl *ɟale*, Debri *ɲal-do*, etc.). ◊ All forms go back to PN *\*ɲal(T)*-.[^tongue] Interestingly, the ON equivalent tame- (no parallels in other languages) is completely different — the only case on the list where ON differs not only from N, but from all other Nubian languages as well.
* “tooth”: N *nìːd*, K *nel*, D *nɛl* (= M *kə̀d-dì*, B *ɲil-di*, Dl *ɟili*, etc.). ◊ All forms reflect PN *\*ɲəl-*.
* “two”: N *úwwó*, K *owwi*, D *owwɪ* (= M *ə́d-dí*, B *ul-ug*, Dl *ore*, etc.). ◊ All forms go back to PN *\*awri*; the unusual cluster *\*-wr-* is responsible for the unusual development *\*-r- > -w-* already in Proto-Nile-Nubian (rather than just in N), and is actually seen explicitly in the extinct and very poorly attested Haraza Nubian: *auri-yah* “two.”[^15]
* “walk (go)”: N *ɟúù-*, K/D *ɟuː* (= M *sə́-r-*, Dl *šu*, etc.). ◊ All forms go back to PN *\*cuː-*.
* “warm (hot)”: N *ɟùg*, K/D *ɟug-ri* (= M *sùːw*). ◊ From PN *\*cug-*.
* “who”: N *nàːy*, K *niː*, D *nɪː* (= M *kə̀ː-rén*, B *neː-ta*, Dl *de*, etc.). ◊ All forms go back to PN *\*ŋə(y)*.

[^13]: Bechhaus-Gerst, "Nile-Nubian Reconsidered,” p. 94 lists this as one of two examples illustrating the alleged archaicity of Old Nubian and Nobiin in retaining original PN *\*g-*, together with ON *gouwi* "shield.” However, in both of these cases K/D also show *k-* (cf. K/D *karu* "shield”), which goes against regular correspondences for PN *\*g-* (which should yield K/D *g-*, see "red”), meaning that it is Nobiin and not the other languages that actually have an innovation here.
[^horn]: Reconstruction somewhat uncertain, but initial *\*ŋ-* is fairly clearly indicated by the correspondences; see detailed discussion in Starostin, *Языки Африки,* pp. 56–57.
[^14]:  Bechhaus-Gerst, "Nile-Nubian Reconsidered,” p. 93 counts this as an additional slice of evidence for early separation of N, but since this is an innovation rather than an archaism, there are no arguments to assert that the innovation did not take place recently (already after the separation of N from K/D).
[^sun]: Hofmann, *Material für eine Meroitische Gram­ma­tik,* 86.
[^tongue]: See the detailed discussion on this phonetically unusual root in Starostin, *Языки Африки,* p. 80.
[^15]: Bell, "Documentary Evidence on the Haraza Nubian Language,” p. 10.

### I.2. Exclusive Nile-Nubian Isoglosses {#i2}

* “all”: N *màlléː*, K *malleː*, D *mallɛ*.
*	“big”: N *dàwwí*, K/D *duː-l*.
*	“burn”: N *ɟùgé-èr*, K/D *ɟug*.
*	“egg”: N *kúmbúː*, D *kumbu*. ◊ Replaced in K by the recent compound innovation *gas-katti* (where the first root probably = *gaːsi* “heavy, hard, rough”), but clearly reconstructible for Nile-Nubian on the whole.
*	“feather”: N *šipir*,[^feather] D *sɪbɪr*.
*	“leaf”: N *úkkí*, K/D *ulug*. ◊ Same word as “ear.”
*	“man”: N *ògɟí-l*, K *ogiɟ*, D *ogɪɟ*.
*	“many”: N *díyyí*, K *dig-riː*, D *díyyí*. ◊ In ON usually attested as *diː-*, once as *dig-* (reflecting dialectal differences between N and K/D).
*	“nose”: N *sòrìŋ*, K *sorin*, D *sorɪɲ*.
* “smoke”: N *túllí*, D *tulla*. ◊ This may be a recent innovation in both languages; cf. the morphological discrepancy, the fact that the stem in N is a better match for K *tulli* “chewing tobacco,” and the lack of attestation in ON. Obvious similarity with Nuer *toːl*, Dinka *tol* “smoke” suggests an old areal isogloss.
* “that”: N *mán*, K/D *man*.
* “this”: N *in*, K *in*, D *ɪn*. ◊ The subsystems of deictic pronouns in M, B, and Hill Nubian are much less cohesive than in Nile-Nubian and do not allow for reliable reconstructions of any PN items that would be different from Nile-Nubian.
* “what”: N *mìn*, K *min*, D *mɪn*. ◊ It is quite possible that the Nile-Nubian situation here is innovative, since all other branches agree on *\*na(i)-* as a better equivalent for PN “what?”: M *nèː-n*, B *na-ta*, Dl *na*, Karko *nái*, etc.[^16]
* “woman”: N *ìd-éːn*, K *eːn*, D *ɛːn*. ◊ Technically, this is not a fully exclusive Nile-Nubian isogloss — cf. B *eːn* “woman.” However, the main root for “woman” in Nubian is *\*il-* (ON *il-*, M *ìd-dì < il-ti*, Dl *eli*, Karko *îl*, etc.); *\*eːn* is the common Nubian word for “mother,” which has, most likely, independently shifted to “woman” in general in modern Nile-Nubian languages and in B. N is particularly innovative in that respect, since it uses a compound formation: *ìd* “person” + *éːn* “mother.”

[^feather]: Khalil, *Wörterbuch der nubischen Spra­che,* p. 124.
[^16]: In Starostin, *Языки Африки,* p. 92 I suggest that, since the regular reflex of PN *\*n-* in Hill Nubian is *d-*, both Nile-Nubian *\*min* and all the *na(i)*-like forms may go back to a unique PN stem *\*nwV-*; if so, the word should be moved to [I.1](#i1), but in any case this is still a common Nile-Nubian isogloss.

## II. Nobiin / Non-K/D Isoglosses

### II.1. Potential K/D innovations {#ii1}

* “bark”: *àːcì* (= M *àccì-dì*). ◊ Possibly < PN *\*aci* “bark, chaff.” As opposed to K/D *gabad* (no parallels in other languages).
* “fly”: *wáːy-ìr* (= B *maː-r*). ◊ May reflect PN *\*way-* “to fly” (*\*w- > m-* is regular in B). However, the corresponding form in D is *war* “to jump, leap, spring,” and typologically the development “jump” → “fly” is far more common than the reverse. Opposed to K *firr*, D *fɪrr* “to fly” with no parallels outside of Nile-Nubian.
* “liver”: N *dìbèː* (= M *tèmmèɟí*). ◊ In D, the old word has been replaced by the Arabic borrowing *kɪbdaːd*. The isogloss between N and M allows to reconstruct PN *\*dib-* “liver.”
* (?) “night”: N *áwá* (= ON *oar-*). ◊ A rare case where K/D are clearly more innovative than N: K/D *ugu*ː “night” occasionally has the additional meaning “24 hours,” and further comparison with ON *uk-r- ~ uk-l-* “day,” K *ug-reːs*, D *ug-rɛːs*, N *ùg-réːs*, M *ùːd* (< *\*ugu-d*) id. suggests that “24 hours; day-night cycle” was the original meaning. On the other hand, N *áwá* is comparable with M *òːd* (< *\*awa-d*?) and could very well be the original PN equivalent.
* “skin”: N *náwá* (< *\*nawar*, cf. pl. *nàwàr-íː*; = B *noːr*, Dl *dor*, etc.). ◊ Opposed to K *aɟin*, D *aɟɪn* “skin, leather.”

### II.2. Potential Synonymy in the Protolanguage

* “come”: *kí-ìl* (= M *ìː-*, B *ki*). ◊ The K/D equivalent is *taː* “to come,” related to Hill Nubian forms (Dl *ta*, Debri *tɔ-rɛ*, Kadaru *ti-ri*, etc.). Old Nubian texts feature numerous instances of both *ki-* and *ta-* in the meaning “to come,” with the semantic difference between them poorly under­stood; in any case, it is likely that both *\*ki-* and *\*ta-* have to be reconstructed for PN as synonyms (possibly suppletives), with subsequent simplification in daughter branches, meaning that neither the situation in Nobiin nor in K/D may be regarded as a straightforward innovation.

## III. Nobiin-exclusive Items {#iii}

### III.1. Nobiin-exclusive Items with a Nubian Etymology {#iii1}

* “blood”: N *díːs* (= ON *dis-*). ◊ Related to K *des*, D *dɛs*, M *tèssì* “oil; liquid fat; butter”; the meaning in N is clearly innovative, since the original PN root for “blood” is well distributed across non-Nile-Nubian lineages (M *ə̀ggə́r*, B *igir*, Dl *ogor*, etc.).
*	(?) “earth”: N *gùr* (= ON *gul- ~ gud-*). ◊ The same word is also found in D as *guː* “earth, ground, floor” and in K as *guː* “field, acre; earth (surface).” According to Werner, in modern Nobiin the meaning “earth = soil” is also expressed by the same root,[^earth] whereas ON *iskit-* “earth; dust” > Nobiin *ìskíːd* corresponds to the narrower meaning “dust” in Wernerʼs dictionary.[^earth2] It is perfectly possible, however, that this is all simply a byproduct of inaccurate semantic glossing and that the situation in Nobiin is actually exactly the same as in K/D. In this case, the word has to be moved to [I.2](#i2) (or [I.1](#i1), if B *izzi-di* “earth” also belongs here).
*	“hear”: N *úkké-èr* (= ON *ulg-ir- ~ ulg-ar- ~ ulk-ir-*). ◊ Transparent derivation from *ulug* “ear.” The old verbal root “hear” is present in K/D (K *giɟ-ir*, D *gɪɟ-ir*) and Hill Nubian (Dl *ki-er-* etc.) < PN *\*gi(ɟ)-*. The situation in Old Nubian/Nobiin is seemingly innovative.
* “meat”: N *áríɟ*. ◊ Probably a recent innovation, since the ON equivalent for “flesh, meat” is *gad-*, with a likely etymological parallel in M *kàdì* “meat without bones.” As for *áríɟ*, the shape of this word is reminiscent of an adjectival derivate (cf. *fáríɟ* “thick, heavyʼ), making it comparable with K *aːre*, D *aːrɛ* “inside, interior.” The most common Nubian equivalent for “meat,” however, is *\*kosi ~ \*kosu* > K/D *kusu*, M *òsò-ŋí*, B *kozi*, Dl *kwaɟe*, etc.
* (?) “root”: N *ɟúː*. ◊ Perhaps related to D *ɟuː* “nether stone for grinding,” K *ɟuː* “hand mill” (if the original meaning was “bottom, foundation”), but the semantic link is weak. Notably, the word is not attested in ON where the equivalent for “root” is *dulist-* (no etymology). The most common form for “root” in Nubian is *\*ir-* (M *ír-dí*, Dl *ir-tad*, etc.).
* “say”: N *íːg-ìr* (= ON *ig-ir* “tell”). ◊ Same as D *iːg* “tell, narrate”; in N, this seems to have become the main equivalent for “say.” Other ON words with similar meanings include the verbs *pes-* (direct speech marker), *il-* (“speak,” “tell”) and *we-* (very rare, probably a K/D dialectism); the latter is the common Nubian equivalent for “say” (cf. K *weː*, D *wɛː*, Dl *fe*, Kadaru *wei*, etc.).
* “swim”: N *kúcc-ìr*. ◊ Not attested in ON; phonetically corresponds to D *kuɟ-* “to be above,” *kuɟ-ur-* “to place above, set above,” *kuc-cɛg-* “to mount, ride.” If the etymology is correct, the semantic development can only be unidirectional (“to be on top/on the surface” → “to swim”) and the meaning in N is clearly secondary. That said, the word “swim” in general is highly unstable in Nubian languages (almost every idiom has its own equivalent).
* “tree”: N *kóy* (= ON *koir-*). ◊ Comparable with D *koɪd* “a k. of jujube (*Ziziphus spina-christi*)”; if the etymology is correct, a secondary generalization of the meaning to “tree (gen.)” in N would perfectly agree with the fact that a much better candidate for PN “tree” is *\*pər* > Dl *hor*, Dair *or*, Wali *fʊ́r*, K *ber* “wood,” D *bɛr* “wood” (the meaning “tree” in K/D, as in N, is expressed by an innovation: K *ɟowwi*, D *ɟoːwwɪ*, formerly “*Acacia nilotica*”).
* “we”: N *ù:* (= ON *u-*). ◊ ON has two [1pl]({sc}) pronouns: *u-* and *e-r-*, the distinction between which is still a matter of debate; Browne, Werner, and others have suggested an old differentiation along the lines of inclusivity, but there is no general consensus on which of the two pronouns may have been inclusive and which one was exclusive. In any case, the two forms are in complementary distribution in modern Nile-Nubian languages: N only has *ùː*, K/D only have *a-r-*. On the external level, K/D forms are better supported (cf. M. *àː-dí*, B *a-di*), but forms cognate with N *ùː* are also occasionally found in Hill Nubian, e.g., Wali *ʊ̌ʔ*.[^we] Without sidetracking into in-depth discussion, it should be acknowledged that *ùː* may well be a PN archaism retained in N.

[^earth]: Werner, *Grammatik des Nobiin,* p. 357.
[^earth2]: The meanings “sand; dust” are also indicated as primary for Nobiin *iskid ~ iskit* in Khalil, *Wörterbuch der nubischen Spra­che,* p. 48.
[^we]: Krell, *Rapid Appraisal Sociolinguistic Survey among Ama, Karko, and Wali Language Groups*, p. 40.

### III.2. Nobiin-exclusive Items without a Nubian Etymology {#iii2}

* “dog”: N *múg* (= ON *mug-*). ◊ Not related to PN *\*bəl* (K *wel*, D *wɛl*, M *pə̀ːl*, B *mɛl*, DL *bol*, etc.); no parallels in other Nubian languages.
* “dry”: N *sámá*. ◊ Not related to K *soww-od*, D *soww-ɛd* “dry” or their cognates in Hill Nubian (Debri *šua-du*, etc.).
* (?) “eat”: N *kàb-* (= ON *kap-*). ◊ ON shows dialectal variety: besides the more common *kap-*, there is also at least one hapax case of ON *kal-* “eat” = K/D *kal*. It is not entirely clear if the two roots are indeed unrelated: a scenario where ON *kap-*, N *kàb-* < Nile-Nubian *\*kal-b-* (cf. such derived stems as D *kal-bu-* pass. “be eaten,” *kal-bɛːr* “eat to satisfaction”) cannot be ruled out. However, it would run into additional phonetic and morphological problems. From an external point of view, only K/D *kal* < PN *\*kɔl* has sufficient etymological backup; cf. Dl *kol*, M *ə̀l-* id. Regardless of etymologization, N *kàb-* is clearly innovative.
* “fat”: N *sìlèː*. ◊ Not attested in ON; no parallels in any other languages.
* “fish”: N *ángíssí*. ◊ Replaces ON *watto-*; neither of the two words has any clear parallels in K/D or any other Nubian languages. A possible, though questionable, internal etymology is “living in water” (from *aɲ-* “to live” + *\*essi* “water,” see notes on “water” below).
* “full”: N *mídd-ìr* (= ON *medd- ~ midd-* “to be full/ready”). ◊ Possibly from an earlier *\*merid-* (this form is actually attested a few times in ON sources). The item is quite unstable in the Nubian group on the whole; the PN equivalent remains obscure.
* (?) “good”: N *màs.* ◊ This word does not have a Nubian etymology; however, the older equivalent *gèn* (= ON *gen-*), mainly used in the modern language in the comparative sense (“better”), is clearly cognate with D *gɛn* “good, healthy” and further with such Hill Nubian items as Dl *ken*, Debri *kɛŋ* “good,” etc., going back to PN *\*gen-*. Were the semantic criteria to be relaxed, this item should have been moved to [I.1](#i1).
* “hair”: N *šìgír-tí*. ◊ Not attested in ON. The form is similar to K *siːr* “hair,” but phonetic correspondences would be irregular (*\*-g-* should not be deleted in K). On the contrary, D *dɪl-tɪ* “hair” perfectly corresponds to M *tèː-dì*, B *dill-e*, Dl *tel-ti*, etc. and is reconstructible as PN *\*del-* or *\*dɛl-*. Forms in N and K would seem to be innovations — perhaps the result of separate borrowings from a common non-Nubian source.
* “lie (down)”: N *fìyy-ìr* (= ON *pi-*). ◊ No parallels in other languages.
* “mountain”: N *mùléː*. ◊ Probably a recent innovation, since the ON equivalent is *naɟ-*. No parallels in other languages. Opposed to M *òːr*, B *kúːr*, Dl *kulí*, Karko *kúrù,* etc. < PN *\*kur-* (in K/D this word was replaced by borrowings from Arabic).
* “name”: N *tàŋìs* (= ON *taŋis-*). ◊ No parallels in other languages. The most common Nubian equivalent for “name” is K *erri*, D *ɛrrɪ*, M *ə́rí*, B *erei*, Dl *or,* etc. < PN *\*əri*.
* “new”: N *míríː* (= ON *miri-*). ◊ No parallels in other languages. The common Nubian root for “new” is K *eːr*, D *ɛr*, B *eːr*, Dl *er* < PN *\*ɛːr*.
* “road”: N *dáwwí* (= ON *dawi- ~ dawu-*). ◊ Although it is likely that *dáwwí* < *\*dari* (see “rain” above), the word is hardly directly related to K *darub*, D *darɪb*[^17] since the latter is transparently borrowed from Arabic *darb-*. A separate early borrowing into ON from the same source cannot be excluded, but it is also possible that the word has a completely different origin.
* “seed”: N *kóɟìr* (= ON *koɟir-*). ◊ No parallels in other languages. The common Nubian root for “seed” is *\*ter-* (K *teːri*, D *tɛːrɪ*, Dl *ter-ti*).
* “small”: N *kùdúːd*. ◊ No parallels in other languages, but the word is generally unstable throughout the entire family.
* “stand”: N *ménɟ-ìr*. ◊ Attested only once in ON (as *meɟɟ-*), where the usual equivalent for “stand” is *noɟ(ɟ)-*. The corresponding K/D stem is K *teːb*, D *tɛːb*, but a better candidate for PN “stand” is the isogloss between M *tèkk-ér-* and Dl *tek-er* < PN *\*tek-*.
* “stone”: N *kìd* (= ON *kit-*). ◊ No parallels in other languages. The common Nubian root for “stone” is *\*kul-* (K/D *kulu*, M *ùllì*, B *kul-di*).
* “tail”: N *ɟèlèw*. ◊ No parallels in other languages. The common Nubian root for “tail” is *\*ɛːb* (K *eːw*, D *ɛːu*, M *èːmí*, Dl *ɛb*, etc.). The old vocabulary of Lepsius still gives aw as an alternate equivalent,[^18] meaning that *ɟèlèw* is clearly an innovation of unclear origin. (Possibly a concatenation of *\*ɛːb* with some different first root?).
* “water”: N *ámán* (= ON *aman-*). ◊ No parallels in other languages. The common Nubian root for “water” is *\*əs-ti* (K *essi*, D *ɛssɪ*, M *ə́ːcí*, B *eɟi*, Dl *ɔti*, etc.). The innovative, rather than archaic, character of N *ámán* is clearly seen from the attestation of such idiomatic formations as *ès-kàlèː ~ às-kàlèː* “water wheel” and *màːɲ-éssí* “tear” (lit. “eye-water”); see also notes on the possible internal etymologization of “fish” above. The word *ámán* has frequently been compared to the phonetically identical common Berber equivalent for “water,” *\*ama-n*,[^19] but the inability to find any additional Nobiin–Berber parallels with the same degree of phonetic and semantic similarity make the comparison less reliable than one could hope for.
* “white”: N *nùlù* (= ON *nulu-*). ◊ No parallels in other languages. The common Nubian root for “white” is *\*ar-* (K/D *ar-o*, M *àdd-é*, B *eːl-e*, Dl *ɔr-i*, etc.).

[^17]: As per Bechhaus-Gerst, "Nile-Nubian Reconsidered,” p. 93.
[^18]: Lepsius, *Nubische Grammatik,* p. 274.
[^19]: Where *\*-n* is a productive plural marker, cf. Bechhaus-Gerst, "Sprachliche und his­torische Rekonstruktionen im Bereich des Nubischen unter beson­de­rer Berücksichtigung des Nilnubischen,” p. 109.

### III.3. Nobiin-exclusive Recent Borrowings {#iii3}

* “cloud”: N *géːm* < Arabic *ʁayma-*. Replaces ON *niɟɟ-*, a common Nubian root (= D *niccɪ*, M *tèccì-dì*, B *naːsi-di*, etc.).
* “yellow”: N *asfar* < Arabic *ʼaṣfar*. The word in general is highly unstable in Nubian and not reconstructible for PN.

## Analysis of the Data

Based on the presented data and the etymological discussion accompanying (or not accompanying) individual pieces of it, the following observations can be made:

1. 	Altogether, [III.2](#iii2) contains twenty items that are not only lexicostatistically unique for Nobiin, but also do not appear to have any etymological cognates whatsoever in any other Nubian languages. This observation is certainly not conclusive, since it cannot be guaranteed that some of these parallels were missed in the process of analysis of existing dictionaries and wordlists, or that more extensive lexicographical research on such languages as Midob or Hill Nubian in the future will not turn out additional parallels. At present, however, it is an objective fact that the percentage of such words in the Nobiin basic lexicon significantly exceeds the corresponding percentages for any other Nubian language (even Midob, which, according to general consensus, is one of the most highly divergent branches of Nubian). Most of these words are attested already in ON, which is hardly surprising, since the majority of recent borrowings into Nobiin have been from Arabic and are quite transparent as to their origin (see [III.3](#iii3)).
2. 	Analysis of [III.1](#iii1) shows that in the majority of cases where the solitary lexicostatistical item in Nobiin does have a Common Nubian etymology, semantic comparison speaks strongly in favor of innovation, i.e., semantic shift in Nobiin: “blood” ← “fat,” “hear” ← “ear,” “meat” ← “inside,” “say” ← “tell,” “swim” ← “be on the surface,” “tree” ← “jujube”; a few of these cases may be debatable, but the overall tendency is clear. This observation in itself does not contradict the possibility of early separation of Nobiin, but the near-total lack of words that could be identified as reflexes of Proto-Nubian Swadesh equivalents of the respective meanings in this particular group clearly speaks against this historical scenario.
3. It is worth mentioning that the number of isoglosses that Nobiin shares with other branches of Nubian to the exclusion of K/D ([II.1](#ii1)) is extremely small, especially when compared to the number of exclusive Nile-Nubian isoglosses between Nobiin and K/D. However, this observation neither contradicts nor supports the early separation hypothesis (since we are not assuming that Nobiin should be grouped together with B, M, or Hill Nubian).

# Conclusions

Based on this brief analysis, I suggest that rejection of the Nile-Nubian hypothesis in favor of an alternative historical scenario as proposed by Bechhaus-Gerst is not recommendable, since it runs into no less than two independent historical oddities/anomalies:

1. assumption of a huge number of basic lexical borrowings from Kenuzi–Dongolawi into Nobiin (even including such elements as demonstrative and interrogative pronouns, typically resistant to borrowing);
2. assumption of total loss of numerous Proto-Nubian basic lexical roots in all branches of Nubian except for Nobiin (19–21 possible items in [III.2](#iii2)). Such conservatism would be highly suspicious; it is also directly contradicted by a few examples such as “water” (q.v.) which clearly indicate that Nobiin is innovative rather than conservative.

By contrast, the scenario that retains Nobiin within Nile-Nubian, but postulates the existence of a "pre-Nobiin" substrate or adstrate only assumes one historical oddity, similar to (1) above — the (presumably rapid) replacement of a large chunk of the Nobiin basic lexicon by words borrowed from an unknown substrate. However, it must be noted that the majority of words in [III.2](#iii2) are nouns, rather than verbs or pronouns, and this makes the idea of massive borrowing more plausible than in the case of presumed borrowings from K/D into Nobiin.[^20]

[^20]: For a good typological analogy from a relatively nearby region, cf. the contact situation between Northern Songhay languages and Berber languages as described, e.g., in Souag, *Grammatical Contact in the Sahara.*

This conclusion is in complete agreement with the tentative identification of a "pre-Nile- Nubian substrate" in Nobiin by Claude Rilly,[^21] who, based on a general distributional analysis of Nubian lexicon, claims to identify no fewer than fifty-one Nobiin lexical items derived from that substrate, most of them belonging to the sphere of basic lexicon. It remains to be ascertained if all of Rillyʼs fifty-one items are truly unique in Nobiin (as I have already mentioned above, some of these Nobiin isolates might eventually turn out to be retentions from Proto-Nubian if future data on Hill Nubian and Midob happens to contain etymological parallels), but the fact that Rilly and the author of this paper arrived at the same conclusion independently of each other by means of somewhat different methods looks reassuring.

[^21]:  Rilly, *Le méroïtique et sa famille linguistique,* pp. 285–289.

If the Nile-Nubian branch is to be reinstated, and the specific features of Nobiin are to be explained by the influence of a substrate that did not affect its closest relative (K/D), this leaves us with two issues to be resolved — (a) chronology (and geography) of linguistic events, and (b) the genetic affiliation of the "pre-Nile-Nubian substrate" in question.

The aspect of chronology has previously been discussed in glottochronological terms.[^22] In both of these sources the application of the glottochronological method as introduced by Morris Swadesh and later recalibrated by Sergei Starostin allowed to generate the following classification and datings (**fig. 2**):

[^22]:  Starostin, *Языки Африки,* pp. 34–36; Vasilyey & Starostin, "Лексикостатистическая классификация нубийских языков.”

![Phylogenetic tree for the Nubian languages](../static/images/classification.png "Phylogenetic tree for the Nubian languages")

**~~Fig. 2. Phylogenetic tree for the Nubian languages with glottochronological datings (generated by the StarlingNJ method)[^23]~~**

[^23]: For a detailed description of the StarlingNJ distance-based method of phylogenetic classification and linguistic dating, see Kassian, "Towards a Formal Genealogical Classification of the Lezgian Languages (North Caucasus).”

If we take the glottochronological figures at face value, they imply the original separation of Proto-Nile-Nubian around three — three and a half thousand years ago, and then a further split between the ancestors of modern Nobiin and K/D around two to two and a half thousand years ago. Interestingly enough, these events are chronologically correlatable with the two main events in the history of Nile-Nubian languages according to Bechhaus-Gerst, but not quite in the way that she envisions it: her "early separation of Nobiin" becomes the early separation of Nobiin and K/D, and her "later separation of K/D" becomes "final split between Nobiin and K/D.” The interaction between Nobiin and the mysterious "pre-Nile-Nubian substrate" must have therefore taken place some time in the 1st millennium CE (after the split with K/D but prior to the appearance of the first written texts in Old Nubian). Nevertheless, at this point I would like to refrain from making any definitive conclusions on probable dates and migration routes, given the possibility of alternate glottochronological models.

The other issue — linguistic identification of the “pre-Nile-Nubian substrate” — is even more interesting, since its importance goes far beyond Nubian history, and its successful resolution may have direct implications for the reconstruction of the linguistic history of Africa in general. Unfortunately, at this moment one can only speculate about what that substrate might have been, or even about whether it is reasonable to speak about a single substrate or a variety of idioms that may have influenced the early independent development of Nobiin.

Thus, Rilly, having analyzed lexical (sound + meaning) similarities between his fifty-one "pre-Nile-Nubian substrate" elements and other languages spoken in the region today or in antiquity, reached the conclusion that the substrate in question may have contained two layers: one related to ancient Meroitic, and still another one coming from the same Northern branch of Eastern Sudanic languages to which Nubian itself is claimed to belong.[^24] An interesting example of the former would be, e.g., the resemblance between ON *mašal* “sun” and Meroitic *ms* “sun, sun god,” while the latter may be illustrated with the example of Nobiin *šìgír-tí* “hair” = Tama *sìgít* id. However, few of Rillyʼs other parallels are equally convincing — most of them are characterized by either significant phonetic (e.g., Nobiin *súː* vs. Nara *sàː* “milk”) or semantic (e.g., Nobiin *nóːg* “house” vs. Nara *lòg* “earth”) discrepancies, not something one would really expect from contact relations that only took place no earlier than two thousand years ago. Subsequent research has not managed to alleviate that problem: cf., e.g., the attempt to derive Nobiin *nùlù* “white” from proto-Northeast Sudanic *\*ŋesil* “tooth,”[^25] unconvincing due to multiple phonetic and semantic issues at the same time.

[^24]:  Rilly, *Le méroïtique et sa famille linguistique,* p. 285.
[^25]:  Rilly, "Language and Ethnicity in Ancient Sudan,” pp. 1181–1182.

In *Языки Африки,* an alternate hypothesis was put forward, expanding upon an earlier observation by Robin Thelwall,[^26] who, while conducting his own lexicostatistical comparison of Nubian languages with other potential branches of East Sudanic, had first noticed some specific correlations between Nobiin and Dinka (West Nilotic). Going through Nobiin data in [III.2](#iii2) yields at least several phonetically and semantically close matches with West Nilotic, such as:

* *túllí* “smoke” — cf. Nuer *toːl*, Dinka *tol* “smoke”;
* *kìd* “stone” — cf. Luo *kidi*, Shilluk *kit*, etc. “stone”;
* *ɟèlèw* “tail” — cf. Nuer *ɟual*, Dinka *yɔl*, Mabaan *yilɛ*, etc. “tail.”

Additionally, Nobiin *múg* “dog” is similar to East Nilotic *\*-ŋɔk-*[^27] and Kalenjin *\*ŋoːk*,[^28] assuming the possibility of assimilation (*\*ŋ- - m-* before a following labial vowel in Nobiin). These parallels, although still sparse, constitute by far the largest single group of matches between the "pre-Nile Nubian substrate" and a single linguistic family (Nilotic), making this line of future research seem promising for the future — although they neither conclusively prove the Nilotic nature of this substrate, nor eliminate the possibility of several substrate layers with different affiliation.

[^26]:  Thelwall, "Lexicostatistical Relations be­twe­en Nu­bian, Daju and Dinka,” pp. 273–274.
[^27]:  Vossem, *The Eastern Nilotes,* p. 354.
[^28]:  Rottland, *Die Südnilotischen Sprachen,* p. 390.

In any case, the main point of this paper is not so much to shed light on the origin of substrate elements in Nobiin as it is to show that pure lexicostatistics, when applied to complex cases of language relationship, may reveal anomalies that can only be resolved by means of a careful etymological analysis of the accumulated evidence. It is entirely possible that advanced character-based phylogenetic methods might offer additional insight into this problem, but ultimately it all comes down to resolving the problem by means of manual searching for cognates, albeit without forgetting about statistical grounding of the conclusions.

In this particular case, I believe that the evidence speaks strongly in favor of reinstating the Nile-Nubian clade comprising both Nobiin and Kenuzi–Dongolawi, although it must be kept in mind that a common linguistic ancestor and a common ethnic ancestor are not necessarily the same thing (e.g., the linguistic conclusion does not at all exclude the possibility that early speakers of Kenuzi–Dongolawi did shift to Proto-Nile-Nubian from some other language — not necessarily Nubian in origin itself).

# Abbreviations

* B — Birgid;
* D — Dongolawi;
* Dl — Dilling;
* K — Kenuzi;
* K/D — Kenuzi–Dongolawi;
* M — Midob;
* N — Nobiin;
* ON — Old Nubian;
* PN — Proto-Nubian.


# Bibliography

Armbruster, Charles H. ![*Dongolese Nubian: A Lexicon.*](bib:80085e08-a9b3-4099-b044-b1b7ebab73f0) Cambridge: Cambridge University Press, 1965.

Bechhaus-Gerst, Marianne. !["‘Nile-Nubianʼ Recon­sidered.”](bib:615083cc-73d6-4252-bdc4-a9e29adecd7e) In *Topics in Nilo-Saharan Linguistics,* edited by M. Lio­nel Be­n­der. Ham­burg: Helmut Buske, 1989: pp. 85–96.

Bechhaus-Gerst, Marianne. !["Sprachliche und his­torische Rekonstruktionen im Bereich des Nubischen unter beson­de­rer Berücksichtigung des Nilnubischen.”](bib:ef1e63ed-e757-493c-8782-11058023c697) *Sprache und Geschichte in Afrik* 6 (1985): pp. 7–134.

Bechhaus-Gerst, Marianne. *Sprachwandel durch Sprachkontakt am Beispiel des Nubischen im Niltal: Möglichkeiten und Grenzen einer diachronen Soziolinguistik.* Cologne: Rüdiger Köppe, 1996.

Bechhaus-Gerst, Marianne. ![*The (Hi)story of Nobiin: 1000 Years of Language Change.*](bib:de6d1b1f-d6ff-45e1-93e4-31cf934bb1ee) Frankfurt am Main: Peter Lang, 2011.

Bell, Herman. !["Documentary Evidence on the Haraza Nubian Language.”](bib:9926e196-3eea-4b7c-856c-6272d4386c75) *Su­dan Notes and Re­cords* 56 (1975): pp. 1–35.

Browne, Gerald M. ![*Old Nubian Dictionary.*](bib:d9505774-ee71-4ab7-b076-96f26507ca47) Leuven: Pee­ters, 1996.

Greenberg, Joseph H. ![*The Languages of Africa.*](bib:df1c2298-341c-4367-a9cf-37452f7e3068) Bloo­mington: Indiana University Press, 1966.

Güldemann, Tom. !["Historical Linguistics and Genealogical Language Classification in Africa.”](bib:71baea9a-2918-4b8e-afc4-cbcaa229ffba) In *The Languages and Linguistics of Africa,* edited by Tom Güldemann. Berlin: Mouton de Gruyter, 2018: pp. 58–444.

Heine, Bernd & Tania Kuteva. !["Convergence and Divergence in the Development of African Languages.”](bib:98d3ffa7-f296-42a4-9abf-7352a8771a21) In *Areal Diffusion and Genetic Inheritance: Problems in Comparative Linguistics,* edited by Alexandra Y. Aikhenvald and R.M.W. Dixon. Oxford: Oxford University Press, 2001: pp. 393–411.

Hofmann, Inge. ![*Material für eine meroitische Grammatik.*](bib:e14847bd-2562-46d2-9fe4-05a8b266a1d7) Veröffentlichungen der Institute für Afrikanistik und Ägyptologie der Universität Wien 16. Vienna: Afro-Pub, 1981.

Hofmann, Inge. ![*Nubisches Wörterverzeichnis: Nu­bisch-­deutsches und deutsch-nubisches Wörterverzeichnis nach dem Kenzi-Ma­te­ri­al des Samuêl Alî Hisên (1863–1927).*](bib:2dd02093-a526-4771-b25b-e936e163e9bc) Berlin: Dietrich Reimer Verlag, 1986.

Jakobi, Angelika. !["The Loss of Syllable-final Proto-Nu­bian Consonants.”](bib:536c8580-b91c-4fce-ae39-b8d643e30a65) In *Insights into Nilo-Saharan Language, History and Cul­ture,* edited by Al-Amin Abu-Manga, Leoma Gilley & Anne Storch. Cologne: Rüdi­ger Köppe, 2006: pp. 215–228.

Kassian, Alexei. !["Towards a Formal Genealogical Classification of the Lezgian Languages (North Caucasus): Testing Various Phylogenetic Methods on Lexical Data.”](bib:0511c96c-dcb5-459e-8b22-d6622d56acde) *PLoS ONE* 10, no. 2 (2015). [doi]({sc}): [10.1371/journal.pone.0116950](https://doi.org/10.1371/journal.pone.0116950).

Kauczor, P. Daniel. ![*Die Bergnubische Sprache (Dialekt von Ge­bel Deleṅ).*](bib:712b717f-39e9-42a9-9a87-67de1adfba08) Vienna: Alfred Hölder, 1920.

Khalil, Mokhtar M. ![*Wörterbuch der nubischen Spra­che (Fadidja/Maḥas Dialekt).*](bib:2a073b36-433c-4d18-9121-8d64db619318) Warsaw: Piotr O. Scholtz, 1996.

Krell, Amy. ![*Rapid Appraisal Sociolinguistic Survey among Ama, Karko, and Wali Language Groups (Southern Kordofan, Sudan).*](bib:850be0d9-f32b-4596-9e44-cda89241d83a) SIL International, 2012.

Lepsius, C. Richard. ![*Nubische Grammatik. Mit einer Einleitung über die Völker und Sprachen Afrikas.*](bib:828d8bd7-c62e-4808-a342-b7a6ca3d8b0d) Berlin: Wilhelm Hertz, 1880.

Rilly, Claude. !["Language and Ethnicity in Ancient Sudan.”](bib:2b8a5bc9-e853-4b36-92d3-a3a37bf76903) In *The Fourth Cataract and Beyond: Proceedings of the 12th International Conference for Nubian Studies,* edited by Julie Renée Anderson and Derek A. Welsby. British Museum Publications on Egypt and Sudan, 2014: pp. 1169–1188.

Rilly, Claude. ![*Le méroïtique et sa famille linguistique.*](bib:2ca95718-79e8-40cd-939a-5dd0e3bbd07e) Leuven: Peeters, 2010.

Rottland, Franz. ![*Die Südnilotischen Sprachen: Be­sch­rei­­bung, Vergleichung und Rekonstruktion.*](bib:4a552fb8-607a-4dc5-9d9a-c268075c2e87) Berlin: Dietrich Reimer Verlag, 1982.

Souag, Lameen. ![*Grammatical Contact in the Sahara: Arabic, Berber, and Songhay in Tabelbala and Siwa.*](bib:78f561ab-8b52-4c04-821c-f7ec704f9146) PhD Thesis, SOAS, University of London, 2010.

Starostin, George. ![*Языки Африки. Опыт построения лексикостатистической классификации. Том II: Восточносуданские языки*](bib:0ffcb0a8-a35f-40cf-b56f-b19ca2616ba6) [*Languages of Africa: An Attempt at a Lexicostatistical Classification, Vol. II: East Sudanic Languages*]. Moscow: Jazyki slavjanskoj kulʼtury, 2014.

Thelwall, Robin. !["A Birgid Vocabulary List and Its Links with Daju.”](bib:9ed84dac-bac2-4595-93ef-86cd0ea9b735) In *Gedenkschrift Gustav Nachtigall 1874–1974,* edited by Herbert Gansl­mayr and Hermann Jungraithmayr. Bremen: Übersee-Museum, 1977: pp. 197–210.

Thelwall, Robin. ![“Lexicostatistical Relations between Nubian, Daju and Dinka.”](bib:63cb7f06-ce5d-4ff3-9de0-93e92ae3f36a) In *Etudes Nubiennes, Colloque de Chantilly, 2–6 Juillet 1975,* edited by Jean Leclant and Jean Vercouttier. Cairo: IFAO, 1978: pp. 265–286.

Vasilyev, Mikhail & George Starostin. !["Лексикостатистическая классификация нубийских языков: к вопросу о нильско-нубийской языковой общности"](bib:18159601-88bc-4ac5-ab23-4b9b5c3ce6eb) ["Lexicostatistical Classification of the Nubian languages and the Issue of the Nile-Nubian Genetic Unity"]. *Journal of Language Relationship* 12 (2014): 51–72.

Voßen, Rainer. ![*The Eastern Nilotes: Linguistic and His­to­ri­cal Reconstructions.*](bib:7c6c8b50-41ee-4bb0-af6f-2b0a36c276f5) Berlin: Dietrich Reimer, 1982.

Werner, Roland. ![*Grammatik des Nobiin (Nilnubisch). Pho­no­logie, Tonologie und Morphologie.*](bib:d5354ede-90ab-4f7b-baa2-488cfbbf06ec) Hamburg: Helmut Buske, 1987.

Werner, Roland. ![*Tìdn-áal: A Study of Midob (Darfur Nu­bian).*](bib:56735ece-24da-4960-9101-ba484f7e57f7) Berlin: Dietrich Reimer, 1993.
